/* Generated by re2c 0.15.3 */
#include <stdlib.h>
#include "chunk.h"
#include "scanners.h"

bufsize_t _scan_at(bufsize_t (*scanner)(const unsigned char *), cmark_chunk *c,
                   bufsize_t offset) {
  bufsize_t res;
  unsigned char *ptr = (unsigned char *)c->data;

  if (ptr == NULL || offset > c->len) {
    return 0;
  } else {
    unsigned char lim = ptr[c->len];

    ptr[c->len] = '\0';
    res = scanner(ptr + offset);
    ptr[c->len] = lim;
  }

  return res;
}

// Try to match a scheme including colon.
bufsize_t _scan_scheme(const unsigned char *p) {
  const unsigned char *marker = NULL;
  const unsigned char *start = p;

  {
    unsigned char yych;
    yych = *p;
    if (yych <= '@')
      goto yy2;
    if (yych <= 'Z')
      goto yy4;
    if (yych <= '`')
      goto yy2;
    if (yych <= 'z')
      goto yy4;
  yy2:
    ++p;
  yy3 : { return 0; }
  yy4:
    yych = *(marker = ++p);
    if (yych <= '/') {
      if (yych <= '+') {
        if (yych <= '*')
          goto yy3;
      } else {
        if (yych <= ',')
          goto yy3;
        if (yych >= '/')
          goto yy3;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '9')
          goto yy5;
        if (yych <= '@')
          goto yy3;
      } else {
        if (yych <= '`')
          goto yy3;
        if (yych >= '{')
          goto yy3;
      }
    }
  yy5:
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych == '+')
          goto yy9;
      } else {
        if (yych != '/')
          goto yy9;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy7;
        if (yych >= 'A')
          goto yy9;
      } else {
        if (yych <= '`')
          goto yy6;
        if (yych <= 'z')
          goto yy9;
      }
    }
  yy6:
    p = marker;
    goto yy3;
  yy7:
    ++p;
    { return (bufsize_t)(p - start); }
  yy9:
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy6;
      } else {
        if (yych == '/')
          goto yy6;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy7;
        if (yych <= '@')
          goto yy6;
      } else {
        if (yych <= '`')
          goto yy6;
        if (yych >= '{')
          goto yy6;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy6;
      } else {
        if (yych == '/')
          goto yy6;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy7;
        if (yych <= '@')
          goto yy6;
      } else {
        if (yych <= '`')
          goto yy6;
        if (yych >= '{')
          goto yy6;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy6;
      } else {
        if (yych == '/')
          goto yy6;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy7;
        if (yych <= '@')
          goto yy6;
      } else {
        if (yych <= '`')
          goto yy6;
        if (yych >= '{')
          goto yy6;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy6;
      } else {
        if (yych == '/')
          goto yy6;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy7;
        if (yych <= '@')
          goto yy6;
      } else {
        if (yych <= '`')
          goto yy6;
        if (yych >= '{')
          goto yy6;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy6;
      } else {
        if (yych == '/')
          goto yy6;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy7;
        if (yych <= '@')
          goto yy6;
      } else {
        if (yych <= '`')
          goto yy6;
        if (yych >= '{')
          goto yy6;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy6;
      } else {
        if (yych == '/')
          goto yy6;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy7;
        if (yych <= '@')
          goto yy6;
      } else {
        if (yych <= '`')
          goto yy6;
        if (yych >= '{')
          goto yy6;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy6;
      } else {
        if (yych == '/')
          goto yy6;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy7;
        if (yych <= '@')
          goto yy6;
      } else {
        if (yych <= '`')
          goto yy6;
        if (yych >= '{')
          goto yy6;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy6;
      } else {
        if (yych == '/')
          goto yy6;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy7;
        if (yych <= '@')
          goto yy6;
      } else {
        if (yych <= '`')
          goto yy6;
        if (yych >= '{')
          goto yy6;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy6;
      } else {
        if (yych == '/')
          goto yy6;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy7;
        if (yych <= '@')
          goto yy6;
      } else {
        if (yych <= '`')
          goto yy6;
        if (yych >= '{')
          goto yy6;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy6;
      } else {
        if (yych == '/')
          goto yy6;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy7;
        if (yych <= '@')
          goto yy6;
      } else {
        if (yych <= '`')
          goto yy6;
        if (yych >= '{')
          goto yy6;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy6;
      } else {
        if (yych == '/')
          goto yy6;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy7;
        if (yych <= '@')
          goto yy6;
      } else {
        if (yych <= '`')
          goto yy6;
        if (yych >= '{')
          goto yy6;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy6;
      } else {
        if (yych == '/')
          goto yy6;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy7;
        if (yych <= '@')
          goto yy6;
      } else {
        if (yych <= '`')
          goto yy6;
        if (yych >= '{')
          goto yy6;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy6;
      } else {
        if (yych == '/')
          goto yy6;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy7;
        if (yych <= '@')
          goto yy6;
      } else {
        if (yych <= '`')
          goto yy6;
        if (yych >= '{')
          goto yy6;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy6;
      } else {
        if (yych == '/')
          goto yy6;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy7;
        if (yych <= '@')
          goto yy6;
      } else {
        if (yych <= '`')
          goto yy6;
        if (yych >= '{')
          goto yy6;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy6;
      } else {
        if (yych == '/')
          goto yy6;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy7;
        if (yych <= '@')
          goto yy6;
      } else {
        if (yych <= '`')
          goto yy6;
        if (yych >= '{')
          goto yy6;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy6;
      } else {
        if (yych == '/')
          goto yy6;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy7;
        if (yych <= '@')
          goto yy6;
      } else {
        if (yych <= '`')
          goto yy6;
        if (yych >= '{')
          goto yy6;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy6;
      } else {
        if (yych == '/')
          goto yy6;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy7;
        if (yych <= '@')
          goto yy6;
      } else {
        if (yych <= '`')
          goto yy6;
        if (yych >= '{')
          goto yy6;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy6;
      } else {
        if (yych == '/')
          goto yy6;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy7;
        if (yych <= '@')
          goto yy6;
      } else {
        if (yych <= '`')
          goto yy6;
        if (yych >= '{')
          goto yy6;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy6;
      } else {
        if (yych == '/')
          goto yy6;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy7;
        if (yych <= '@')
          goto yy6;
      } else {
        if (yych <= '`')
          goto yy6;
        if (yych >= '{')
          goto yy6;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy6;
      } else {
        if (yych == '/')
          goto yy6;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy7;
        if (yych <= '@')
          goto yy6;
      } else {
        if (yych <= '`')
          goto yy6;
        if (yych >= '{')
          goto yy6;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy6;
      } else {
        if (yych == '/')
          goto yy6;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy7;
        if (yych <= '@')
          goto yy6;
      } else {
        if (yych <= '`')
          goto yy6;
        if (yych >= '{')
          goto yy6;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy6;
      } else {
        if (yych == '/')
          goto yy6;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy7;
        if (yych <= '@')
          goto yy6;
      } else {
        if (yych <= '`')
          goto yy6;
        if (yych >= '{')
          goto yy6;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy6;
      } else {
        if (yych == '/')
          goto yy6;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy7;
        if (yych <= '@')
          goto yy6;
      } else {
        if (yych <= '`')
          goto yy6;
        if (yych >= '{')
          goto yy6;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy6;
      } else {
        if (yych == '/')
          goto yy6;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy7;
        if (yych <= '@')
          goto yy6;
      } else {
        if (yych <= '`')
          goto yy6;
        if (yych >= '{')
          goto yy6;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy6;
      } else {
        if (yych == '/')
          goto yy6;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy7;
        if (yych <= '@')
          goto yy6;
      } else {
        if (yych <= '`')
          goto yy6;
        if (yych >= '{')
          goto yy6;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy6;
      } else {
        if (yych == '/')
          goto yy6;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy7;
        if (yych <= '@')
          goto yy6;
      } else {
        if (yych <= '`')
          goto yy6;
        if (yych >= '{')
          goto yy6;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy6;
      } else {
        if (yych == '/')
          goto yy6;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy7;
        if (yych <= '@')
          goto yy6;
      } else {
        if (yych <= '`')
          goto yy6;
        if (yych >= '{')
          goto yy6;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy6;
      } else {
        if (yych == '/')
          goto yy6;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy7;
        if (yych <= '@')
          goto yy6;
      } else {
        if (yych <= '`')
          goto yy6;
        if (yych >= '{')
          goto yy6;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy6;
      } else {
        if (yych == '/')
          goto yy6;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy7;
        if (yych <= '@')
          goto yy6;
      } else {
        if (yych <= '`')
          goto yy6;
        if (yych >= '{')
          goto yy6;
      }
    }
    ++p;
    if ((yych = *p) == ':')
      goto yy7;
    goto yy6;
  }
}

// Try to match URI autolink after first <, returning number of chars matched.
bufsize_t _scan_autolink_uri(const unsigned char *p) {
  const unsigned char *marker = NULL;
  const unsigned char *start = p;

  {
    unsigned char yych;
    static const unsigned char yybm[] = {
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   128, 128, 128, 128, 128, 128, 128, 128, 128,
        128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128,
        128, 128, 128, 128, 0,   128, 0,   128, 128, 128, 128, 128, 128, 128,
        128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128,
        128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128,
        128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128,
        128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128,
        128, 128, 0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,
    };
    yych = *p;
    if (yych <= '@')
      goto yy41;
    if (yych <= 'Z')
      goto yy43;
    if (yych <= '`')
      goto yy41;
    if (yych <= 'z')
      goto yy43;
  yy41:
    ++p;
  yy42 : { return 0; }
  yy43:
    yych = *(marker = ++p);
    if (yych <= '/') {
      if (yych <= '+') {
        if (yych <= '*')
          goto yy42;
      } else {
        if (yych <= ',')
          goto yy42;
        if (yych >= '/')
          goto yy42;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '9')
          goto yy44;
        if (yych <= '@')
          goto yy42;
      } else {
        if (yych <= '`')
          goto yy42;
        if (yych >= '{')
          goto yy42;
      }
    }
  yy44:
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych == '+')
          goto yy48;
      } else {
        if (yych != '/')
          goto yy48;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy46;
        if (yych >= 'A')
          goto yy48;
      } else {
        if (yych <= '`')
          goto yy45;
        if (yych <= 'z')
          goto yy48;
      }
    }
  yy45:
    p = marker;
    goto yy42;
  yy46:
    ++p;
    yych = *p;
    if (yybm[0 + yych] & 128) {
      goto yy46;
    }
    if (yych <= 0xEC) {
      if (yych <= 0xC1) {
        if (yych <= '<')
          goto yy45;
        if (yych <= '>')
          goto yy85;
        goto yy45;
      } else {
        if (yych <= 0xDF)
          goto yy78;
        if (yych <= 0xE0)
          goto yy79;
        goto yy80;
      }
    } else {
      if (yych <= 0xF0) {
        if (yych <= 0xED)
          goto yy84;
        if (yych <= 0xEF)
          goto yy80;
        goto yy81;
      } else {
        if (yych <= 0xF3)
          goto yy82;
        if (yych <= 0xF4)
          goto yy83;
        goto yy45;
      }
    }
  yy48:
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy45;
      } else {
        if (yych == '/')
          goto yy45;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy46;
        if (yych <= '@')
          goto yy45;
      } else {
        if (yych <= '`')
          goto yy45;
        if (yych >= '{')
          goto yy45;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy45;
      } else {
        if (yych == '/')
          goto yy45;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy46;
        if (yych <= '@')
          goto yy45;
      } else {
        if (yych <= '`')
          goto yy45;
        if (yych >= '{')
          goto yy45;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy45;
      } else {
        if (yych == '/')
          goto yy45;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy46;
        if (yych <= '@')
          goto yy45;
      } else {
        if (yych <= '`')
          goto yy45;
        if (yych >= '{')
          goto yy45;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy45;
      } else {
        if (yych == '/')
          goto yy45;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy46;
        if (yych <= '@')
          goto yy45;
      } else {
        if (yych <= '`')
          goto yy45;
        if (yych >= '{')
          goto yy45;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy45;
      } else {
        if (yych == '/')
          goto yy45;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy46;
        if (yych <= '@')
          goto yy45;
      } else {
        if (yych <= '`')
          goto yy45;
        if (yych >= '{')
          goto yy45;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy45;
      } else {
        if (yych == '/')
          goto yy45;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy46;
        if (yych <= '@')
          goto yy45;
      } else {
        if (yych <= '`')
          goto yy45;
        if (yych >= '{')
          goto yy45;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy45;
      } else {
        if (yych == '/')
          goto yy45;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy46;
        if (yych <= '@')
          goto yy45;
      } else {
        if (yych <= '`')
          goto yy45;
        if (yych >= '{')
          goto yy45;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy45;
      } else {
        if (yych == '/')
          goto yy45;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy46;
        if (yych <= '@')
          goto yy45;
      } else {
        if (yych <= '`')
          goto yy45;
        if (yych >= '{')
          goto yy45;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy45;
      } else {
        if (yych == '/')
          goto yy45;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy46;
        if (yych <= '@')
          goto yy45;
      } else {
        if (yych <= '`')
          goto yy45;
        if (yych >= '{')
          goto yy45;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy45;
      } else {
        if (yych == '/')
          goto yy45;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy46;
        if (yych <= '@')
          goto yy45;
      } else {
        if (yych <= '`')
          goto yy45;
        if (yych >= '{')
          goto yy45;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy45;
      } else {
        if (yych == '/')
          goto yy45;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy46;
        if (yych <= '@')
          goto yy45;
      } else {
        if (yych <= '`')
          goto yy45;
        if (yych >= '{')
          goto yy45;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy45;
      } else {
        if (yych == '/')
          goto yy45;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy46;
        if (yych <= '@')
          goto yy45;
      } else {
        if (yych <= '`')
          goto yy45;
        if (yych >= '{')
          goto yy45;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy45;
      } else {
        if (yych == '/')
          goto yy45;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy46;
        if (yych <= '@')
          goto yy45;
      } else {
        if (yych <= '`')
          goto yy45;
        if (yych >= '{')
          goto yy45;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy45;
      } else {
        if (yych == '/')
          goto yy45;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy46;
        if (yych <= '@')
          goto yy45;
      } else {
        if (yych <= '`')
          goto yy45;
        if (yych >= '{')
          goto yy45;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy45;
      } else {
        if (yych == '/')
          goto yy45;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy46;
        if (yych <= '@')
          goto yy45;
      } else {
        if (yych <= '`')
          goto yy45;
        if (yych >= '{')
          goto yy45;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy45;
      } else {
        if (yych == '/')
          goto yy45;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy46;
        if (yych <= '@')
          goto yy45;
      } else {
        if (yych <= '`')
          goto yy45;
        if (yych >= '{')
          goto yy45;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy45;
      } else {
        if (yych == '/')
          goto yy45;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy46;
        if (yych <= '@')
          goto yy45;
      } else {
        if (yych <= '`')
          goto yy45;
        if (yych >= '{')
          goto yy45;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy45;
      } else {
        if (yych == '/')
          goto yy45;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy46;
        if (yych <= '@')
          goto yy45;
      } else {
        if (yych <= '`')
          goto yy45;
        if (yych >= '{')
          goto yy45;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy45;
      } else {
        if (yych == '/')
          goto yy45;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy46;
        if (yych <= '@')
          goto yy45;
      } else {
        if (yych <= '`')
          goto yy45;
        if (yych >= '{')
          goto yy45;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy45;
      } else {
        if (yych == '/')
          goto yy45;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy46;
        if (yych <= '@')
          goto yy45;
      } else {
        if (yych <= '`')
          goto yy45;
        if (yych >= '{')
          goto yy45;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy45;
      } else {
        if (yych == '/')
          goto yy45;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy46;
        if (yych <= '@')
          goto yy45;
      } else {
        if (yych <= '`')
          goto yy45;
        if (yych >= '{')
          goto yy45;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy45;
      } else {
        if (yych == '/')
          goto yy45;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy46;
        if (yych <= '@')
          goto yy45;
      } else {
        if (yych <= '`')
          goto yy45;
        if (yych >= '{')
          goto yy45;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy45;
      } else {
        if (yych == '/')
          goto yy45;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy46;
        if (yych <= '@')
          goto yy45;
      } else {
        if (yych <= '`')
          goto yy45;
        if (yych >= '{')
          goto yy45;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy45;
      } else {
        if (yych == '/')
          goto yy45;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy46;
        if (yych <= '@')
          goto yy45;
      } else {
        if (yych <= '`')
          goto yy45;
        if (yych >= '{')
          goto yy45;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy45;
      } else {
        if (yych == '/')
          goto yy45;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy46;
        if (yych <= '@')
          goto yy45;
      } else {
        if (yych <= '`')
          goto yy45;
        if (yych >= '{')
          goto yy45;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy45;
      } else {
        if (yych == '/')
          goto yy45;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy46;
        if (yych <= '@')
          goto yy45;
      } else {
        if (yych <= '`')
          goto yy45;
        if (yych >= '{')
          goto yy45;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy45;
      } else {
        if (yych == '/')
          goto yy45;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy46;
        if (yych <= '@')
          goto yy45;
      } else {
        if (yych <= '`')
          goto yy45;
        if (yych >= '{')
          goto yy45;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy45;
      } else {
        if (yych == '/')
          goto yy45;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy46;
        if (yych <= '@')
          goto yy45;
      } else {
        if (yych <= '`')
          goto yy45;
        if (yych >= '{')
          goto yy45;
      }
    }
    yych = *++p;
    if (yych <= '9') {
      if (yych <= ',') {
        if (yych != '+')
          goto yy45;
      } else {
        if (yych == '/')
          goto yy45;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= ':')
          goto yy46;
        if (yych <= '@')
          goto yy45;
      } else {
        if (yych <= '`')
          goto yy45;
        if (yych >= '{')
          goto yy45;
      }
    }
    yych = *++p;
    if (yych == ':')
      goto yy46;
    goto yy45;
  yy78:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy45;
    if (yych <= 0xBF)
      goto yy46;
    goto yy45;
  yy79:
    ++p;
    yych = *p;
    if (yych <= 0x9F)
      goto yy45;
    if (yych <= 0xBF)
      goto yy78;
    goto yy45;
  yy80:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy45;
    if (yych <= 0xBF)
      goto yy78;
    goto yy45;
  yy81:
    ++p;
    yych = *p;
    if (yych <= 0x8F)
      goto yy45;
    if (yych <= 0xBF)
      goto yy80;
    goto yy45;
  yy82:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy45;
    if (yych <= 0xBF)
      goto yy80;
    goto yy45;
  yy83:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy45;
    if (yych <= 0x8F)
      goto yy80;
    goto yy45;
  yy84:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy45;
    if (yych <= 0x9F)
      goto yy78;
    goto yy45;
  yy85:
    ++p;
    { return (bufsize_t)(p - start); }
  }
}

// Try to match email autolink after first <, returning num of chars matched.
bufsize_t _scan_autolink_email(const unsigned char *p) {
  const unsigned char *marker = NULL;
  const unsigned char *start = p;

  {
    unsigned char yych;
    static const unsigned char yybm[] = {
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   128, 0,   128, 128, 128, 128, 128, 0,   0,
        128, 128, 0,   128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128,
        128, 128, 0,   0,   0,   128, 0,   128, 0,   128, 128, 128, 128, 128,
        128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128,
        128, 128, 128, 128, 128, 128, 128, 0,   0,   0,   128, 128, 128, 128,
        128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128,
        128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128, 128,
        128, 0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,
    };
    yych = *p;
    if (yych <= '9') {
      if (yych <= '\'') {
        if (yych == '!')
          goto yy91;
        if (yych >= '#')
          goto yy91;
      } else {
        if (yych <= ')')
          goto yy89;
        if (yych != ',')
          goto yy91;
      }
    } else {
      if (yych <= '?') {
        if (yych == '=')
          goto yy91;
        if (yych >= '?')
          goto yy91;
      } else {
        if (yych <= 'Z') {
          if (yych >= 'A')
            goto yy91;
        } else {
          if (yych <= ']')
            goto yy89;
          if (yych <= '~')
            goto yy91;
        }
      }
    }
  yy89:
    ++p;
  yy90 : { return 0; }
  yy91:
    yych = *(marker = ++p);
    if (yych <= ',') {
      if (yych <= '"') {
        if (yych == '!')
          goto yy95;
        goto yy90;
      } else {
        if (yych <= '\'')
          goto yy95;
        if (yych <= ')')
          goto yy90;
        if (yych <= '+')
          goto yy95;
        goto yy90;
      }
    } else {
      if (yych <= '>') {
        if (yych <= '9')
          goto yy95;
        if (yych == '=')
          goto yy95;
        goto yy90;
      } else {
        if (yych <= 'Z')
          goto yy95;
        if (yych <= ']')
          goto yy90;
        if (yych <= '~')
          goto yy95;
        goto yy90;
      }
    }
  yy92:
    yych = *++p;
    if (yych <= '@') {
      if (yych <= '/')
        goto yy93;
      if (yych <= '9')
        goto yy96;
    } else {
      if (yych <= 'Z')
        goto yy96;
      if (yych <= '`')
        goto yy93;
      if (yych <= 'z')
        goto yy96;
    }
  yy93:
    p = marker;
    goto yy90;
  yy94:
    ++p;
    yych = *p;
  yy95:
    if (yybm[0 + yych] & 128) {
      goto yy94;
    }
    if (yych <= '>')
      goto yy93;
    if (yych <= '@')
      goto yy92;
    goto yy93;
  yy96:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy98;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych >= ':')
          goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy227;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy226;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy226;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy226;
        goto yy93;
      }
    }
  yy98:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy227;
      if (yych <= '/')
        goto yy93;
      goto yy226;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
        goto yy226;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy226;
        goto yy93;
      }
    }
  yy99:
    ++p;
    yych = *p;
    if (yych <= '@') {
      if (yych <= '/')
        goto yy93;
      if (yych <= '9')
        goto yy102;
      goto yy93;
    } else {
      if (yych <= 'Z')
        goto yy102;
      if (yych <= '`')
        goto yy93;
      if (yych <= 'z')
        goto yy102;
      goto yy93;
    }
  yy100:
    ++p;
    { return (bufsize_t)(p - start); }
  yy102:
    ++p;
    yych = *p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy104;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych >= ':')
          goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
    ++p;
    yych = *p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy106;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy105;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy105;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy105;
        goto yy93;
      }
    }
  yy104:
    ++p;
    yych = *p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy106;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy105:
    ++p;
    yych = *p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy108;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy107;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy107;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy107;
        goto yy93;
      }
    }
  yy106:
    ++p;
    yych = *p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy108;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy107:
    ++p;
    yych = *p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy110;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy109;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy109;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy109;
        goto yy93;
      }
    }
  yy108:
    ++p;
    yych = *p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy110;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy109:
    ++p;
    yych = *p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy112;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy111;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy111;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy111;
        goto yy93;
      }
    }
  yy110:
    ++p;
    yych = *p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy112;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy111:
    ++p;
    yych = *p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy114;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy113;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy113;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy113;
        goto yy93;
      }
    }
  yy112:
    ++p;
    yych = *p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy114;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy113:
    ++p;
    yych = *p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy116;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy115;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy115;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy115;
        goto yy93;
      }
    }
  yy114:
    ++p;
    yych = *p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy116;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy115:
    ++p;
    yych = *p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy118;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy117;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy117;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy117;
        goto yy93;
      }
    }
  yy116:
    ++p;
    yych = *p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy118;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy117:
    ++p;
    yych = *p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy120;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy119;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy119;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy119;
        goto yy93;
      }
    }
  yy118:
    ++p;
    yych = *p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy120;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy119:
    ++p;
    yych = *p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy122;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy121;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy121;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy121;
        goto yy93;
      }
    }
  yy120:
    ++p;
    yych = *p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy122;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy121:
    ++p;
    yych = *p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy124;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy123;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy123;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy123;
        goto yy93;
      }
    }
  yy122:
    ++p;
    yych = *p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy124;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy123:
    ++p;
    yych = *p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy126;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy125;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy125;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy125;
        goto yy93;
      }
    }
  yy124:
    ++p;
    yych = *p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy126;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy125:
    ++p;
    yych = *p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy128;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy127;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy127;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy127;
        goto yy93;
      }
    }
  yy126:
    ++p;
    yych = *p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy128;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy127:
    ++p;
    yych = *p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy130;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy129;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy129;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy129;
        goto yy93;
      }
    }
  yy128:
    ++p;
    yych = *p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy130;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy129:
    ++p;
    yych = *p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy132;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy131;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy131;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy131;
        goto yy93;
      }
    }
  yy130:
    ++p;
    yych = *p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy132;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy131:
    ++p;
    yych = *p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy134;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy133;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy133;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy133;
        goto yy93;
      }
    }
  yy132:
    ++p;
    yych = *p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy134;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy133:
    ++p;
    yych = *p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy136;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy135;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy135;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy135;
        goto yy93;
      }
    }
  yy134:
    ++p;
    yych = *p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy136;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy135:
    ++p;
    yych = *p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy138;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy137;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy137;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy137;
        goto yy93;
      }
    }
  yy136:
    ++p;
    yych = *p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy138;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy137:
    ++p;
    yych = *p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy140;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy139;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy139;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy139;
        goto yy93;
      }
    }
  yy138:
    ++p;
    yych = *p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy140;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy139:
    ++p;
    yych = *p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy142;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy141;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy141;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy141;
        goto yy93;
      }
    }
  yy140:
    ++p;
    yych = *p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy142;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy141:
    ++p;
    yych = *p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy144;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy143;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy143;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy143;
        goto yy93;
      }
    }
  yy142:
    ++p;
    yych = *p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy144;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy143:
    ++p;
    yych = *p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy146;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy145;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy145;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy145;
        goto yy93;
      }
    }
  yy144:
    ++p;
    yych = *p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy146;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy145:
    ++p;
    yych = *p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy148;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy147;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy147;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy147;
        goto yy93;
      }
    }
  yy146:
    ++p;
    yych = *p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy148;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy147:
    ++p;
    yych = *p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy150;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy149;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy149;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy149;
        goto yy93;
      }
    }
  yy148:
    ++p;
    yych = *p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy150;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy149:
    ++p;
    yych = *p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy152;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy151;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy151;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy151;
        goto yy93;
      }
    }
  yy150:
    ++p;
    yych = *p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy152;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy151:
    ++p;
    yych = *p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy154;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy153;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy153;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy153;
        goto yy93;
      }
    }
  yy152:
    ++p;
    yych = *p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy154;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy153:
    ++p;
    yych = *p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy156;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy155;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy155;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy155;
        goto yy93;
      }
    }
  yy154:
    ++p;
    yych = *p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy156;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy155:
    ++p;
    yych = *p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy158;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy157;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy157;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy157;
        goto yy93;
      }
    }
  yy156:
    ++p;
    yych = *p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy158;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy157:
    ++p;
    yych = *p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy160;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy159;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy159;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy159;
        goto yy93;
      }
    }
  yy158:
    ++p;
    yych = *p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy160;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy159:
    ++p;
    yych = *p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy162;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy161;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy161;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy161;
        goto yy93;
      }
    }
  yy160:
    ++p;
    yych = *p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy162;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy161:
    ++p;
    yych = *p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy164;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy163;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy163;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy163;
        goto yy93;
      }
    }
  yy162:
    ++p;
    yych = *p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy164;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy163:
    ++p;
    yych = *p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy166;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy165;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy165;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy165;
        goto yy93;
      }
    }
  yy164:
    ++p;
    yych = *p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy166;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy165:
    ++p;
    yych = *p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy168;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy167;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy167;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy167;
        goto yy93;
      }
    }
  yy166:
    ++p;
    yych = *p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy168;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy167:
    ++p;
    yych = *p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy170;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy169;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy169;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy169;
        goto yy93;
      }
    }
  yy168:
    ++p;
    yych = *p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy170;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy169:
    ++p;
    yych = *p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy172;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy171;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy171;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy171;
        goto yy93;
      }
    }
  yy170:
    ++p;
    yych = *p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy172;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy171:
    ++p;
    yych = *p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy174;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy173;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy173;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy173;
        goto yy93;
      }
    }
  yy172:
    ++p;
    yych = *p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy174;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy173:
    ++p;
    yych = *p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy176;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy175;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy175;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy175;
        goto yy93;
      }
    }
  yy174:
    ++p;
    yych = *p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy176;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy175:
    ++p;
    yych = *p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy178;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy177;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy177;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy177;
        goto yy93;
      }
    }
  yy176:
    ++p;
    yych = *p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy178;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy177:
    ++p;
    yych = *p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy180;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy179;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy179;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy179;
        goto yy93;
      }
    }
  yy178:
    ++p;
    yych = *p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy180;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy179:
    ++p;
    yych = *p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy182;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy181;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy181;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy181;
        goto yy93;
      }
    }
  yy180:
    ++p;
    yych = *p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy182;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy181:
    ++p;
    yych = *p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy184;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy183;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy183;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy183;
        goto yy93;
      }
    }
  yy182:
    ++p;
    yych = *p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy184;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy183:
    ++p;
    yych = *p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy186;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy185;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy185;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy185;
        goto yy93;
      }
    }
  yy184:
    ++p;
    yych = *p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy186;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy185:
    ++p;
    yych = *p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy188;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy187;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy187;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy187;
        goto yy93;
      }
    }
  yy186:
    ++p;
    yych = *p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy188;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy187:
    ++p;
    yych = *p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy190;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy189;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy189;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy189;
        goto yy93;
      }
    }
  yy188:
    ++p;
    yych = *p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy190;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy189:
    ++p;
    yych = *p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy192;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy191;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy191;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy191;
        goto yy93;
      }
    }
  yy190:
    ++p;
    yych = *p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy192;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy191:
    ++p;
    yych = *p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy194;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy193;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy193;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy193;
        goto yy93;
      }
    }
  yy192:
    ++p;
    yych = *p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy194;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy193:
    ++p;
    yych = *p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy196;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy195;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy195;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy195;
        goto yy93;
      }
    }
  yy194:
    ++p;
    yych = *p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy196;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy195:
    ++p;
    yych = *p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy198;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy197;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy197;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy197;
        goto yy93;
      }
    }
  yy196:
    ++p;
    yych = *p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy198;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy197:
    ++p;
    yych = *p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy200;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy199;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy199;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy199;
        goto yy93;
      }
    }
  yy198:
    ++p;
    yych = *p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy200;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy199:
    ++p;
    yych = *p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy202;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy201;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy201;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy201;
        goto yy93;
      }
    }
  yy200:
    ++p;
    yych = *p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy202;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy201:
    ++p;
    yych = *p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy204;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy203;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy203;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy203;
        goto yy93;
      }
    }
  yy202:
    ++p;
    yych = *p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy204;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy203:
    ++p;
    yych = *p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy206;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy205;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy205;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy205;
        goto yy93;
      }
    }
  yy204:
    ++p;
    yych = *p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy206;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy205:
    ++p;
    yych = *p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy208;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy207;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy207;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy207;
        goto yy93;
      }
    }
  yy206:
    ++p;
    yych = *p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy208;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy207:
    ++p;
    yych = *p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy210;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy209;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy209;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy209;
        goto yy93;
      }
    }
  yy208:
    ++p;
    yych = *p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy210;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy209:
    ++p;
    yych = *p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy212;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy211;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy211;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy211;
        goto yy93;
      }
    }
  yy210:
    ++p;
    yych = *p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy212;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy211:
    ++p;
    yych = *p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy214;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy213;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy213;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy213;
        goto yy93;
      }
    }
  yy212:
    ++p;
    yych = *p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy214;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy213:
    ++p;
    yych = *p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy216;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy215;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy215;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy215;
        goto yy93;
      }
    }
  yy214:
    ++p;
    yych = *p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy216;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy215:
    ++p;
    yych = *p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy218;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy217;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy217;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy217;
        goto yy93;
      }
    }
  yy216:
    ++p;
    yych = *p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy218;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy217:
    ++p;
    yych = *p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy220;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy219;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy219;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy219;
        goto yy93;
      }
    }
  yy218:
    ++p;
    yych = *p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy220;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy219:
    ++p;
    yych = *p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy222;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy221;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy221;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy221;
        goto yy93;
      }
    }
  yy220:
    ++p;
    yych = *p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy222;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy221:
    ++p;
    yych = *p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy224;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy223;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy223;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy223;
        goto yy93;
      }
    }
  yy222:
    ++p;
    yych = *p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy224;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy223:
    ++p;
    yych = *p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= '-')
          goto yy93;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy225;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy225;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy225;
        goto yy93;
      }
    }
  yy224:
    ++p;
    yych = *p;
    if (yych <= '@') {
      if (yych <= '/')
        goto yy93;
      if (yych >= ':')
        goto yy93;
    } else {
      if (yych <= 'Z')
        goto yy225;
      if (yych <= '`')
        goto yy93;
      if (yych >= '{')
        goto yy93;
    }
  yy225:
    ++p;
    yych = *p;
    if (yych == '.')
      goto yy99;
    if (yych == '>')
      goto yy100;
    goto yy93;
  yy226:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy229;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy228;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy228;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy228;
        goto yy93;
      }
    }
  yy227:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy229;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy228:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy231;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy230;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy230;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy230;
        goto yy93;
      }
    }
  yy229:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy231;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy230:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy233;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy232;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy232;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy232;
        goto yy93;
      }
    }
  yy231:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy233;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy232:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy235;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy234;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy234;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy234;
        goto yy93;
      }
    }
  yy233:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy235;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy234:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy237;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy236;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy236;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy236;
        goto yy93;
      }
    }
  yy235:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy237;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy236:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy239;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy238;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy238;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy238;
        goto yy93;
      }
    }
  yy237:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy239;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy238:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy241;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy240;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy240;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy240;
        goto yy93;
      }
    }
  yy239:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy241;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy240:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy243;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy242;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy242;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy242;
        goto yy93;
      }
    }
  yy241:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy243;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy242:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy245;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy244;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy244;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy244;
        goto yy93;
      }
    }
  yy243:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy245;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy244:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy247;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy246;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy246;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy246;
        goto yy93;
      }
    }
  yy245:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy247;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy246:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy249;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy248;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy248;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy248;
        goto yy93;
      }
    }
  yy247:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy249;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy248:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy251;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy250;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy250;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy250;
        goto yy93;
      }
    }
  yy249:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy251;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy250:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy253;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy252;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy252;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy252;
        goto yy93;
      }
    }
  yy251:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy253;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy252:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy255;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy254;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy254;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy254;
        goto yy93;
      }
    }
  yy253:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy255;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy254:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy257;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy256;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy256;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy256;
        goto yy93;
      }
    }
  yy255:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy257;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy256:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy259;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy258;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy258;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy258;
        goto yy93;
      }
    }
  yy257:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy259;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy258:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy261;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy260;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy260;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy260;
        goto yy93;
      }
    }
  yy259:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy261;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy260:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy263;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy262;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy262;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy262;
        goto yy93;
      }
    }
  yy261:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy263;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy262:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy265;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy264;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy264;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy264;
        goto yy93;
      }
    }
  yy263:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy265;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy264:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy267;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy266;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy266;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy266;
        goto yy93;
      }
    }
  yy265:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy267;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy266:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy269;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy268;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy268;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy268;
        goto yy93;
      }
    }
  yy267:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy269;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy268:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy271;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy270;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy270;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy270;
        goto yy93;
      }
    }
  yy269:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy271;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy270:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy273;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy272;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy272;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy272;
        goto yy93;
      }
    }
  yy271:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy273;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy272:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy275;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy274;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy274;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy274;
        goto yy93;
      }
    }
  yy273:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy275;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy274:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy277;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy276;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy276;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy276;
        goto yy93;
      }
    }
  yy275:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy277;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy276:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy279;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy278;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy278;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy278;
        goto yy93;
      }
    }
  yy277:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy279;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy278:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy281;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy280;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy280;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy280;
        goto yy93;
      }
    }
  yy279:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy281;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy280:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy283;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy282;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy282;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy282;
        goto yy93;
      }
    }
  yy281:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy283;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy282:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy285;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy284;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy284;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy284;
        goto yy93;
      }
    }
  yy283:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy285;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy284:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy287;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy286;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy286;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy286;
        goto yy93;
      }
    }
  yy285:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy287;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy286:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy289;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy288;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy288;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy288;
        goto yy93;
      }
    }
  yy287:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy289;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy288:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy291;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy290;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy290;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy290;
        goto yy93;
      }
    }
  yy289:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy291;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy290:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy293;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy292;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy292;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy292;
        goto yy93;
      }
    }
  yy291:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy293;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy292:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy295;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy294;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy294;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy294;
        goto yy93;
      }
    }
  yy293:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy295;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy294:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy297;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy296;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy296;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy296;
        goto yy93;
      }
    }
  yy295:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy297;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy296:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy299;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy298;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy298;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy298;
        goto yy93;
      }
    }
  yy297:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy299;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy298:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy301;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy300;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy300;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy300;
        goto yy93;
      }
    }
  yy299:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy301;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy300:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy303;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy302;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy302;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy302;
        goto yy93;
      }
    }
  yy301:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy303;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy302:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy305;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy304;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy304;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy304;
        goto yy93;
      }
    }
  yy303:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy305;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy304:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy307;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy306;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy306;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy306;
        goto yy93;
      }
    }
  yy305:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy307;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy306:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy309;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy308;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy308;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy308;
        goto yy93;
      }
    }
  yy307:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy309;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy308:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy311;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy310;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy310;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy310;
        goto yy93;
      }
    }
  yy309:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy311;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy310:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy313;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy312;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy312;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy312;
        goto yy93;
      }
    }
  yy311:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy313;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy312:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy315;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy314;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy314;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy314;
        goto yy93;
      }
    }
  yy313:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy315;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy314:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy317;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy316;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy316;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy316;
        goto yy93;
      }
    }
  yy315:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy317;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy316:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy319;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy318;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy318;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy318;
        goto yy93;
      }
    }
  yy317:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy319;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy318:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy321;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy320;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy320;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy320;
        goto yy93;
      }
    }
  yy319:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy321;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy320:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy323;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy322;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy322;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy322;
        goto yy93;
      }
    }
  yy321:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy323;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy322:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy325;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy324;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy324;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy324;
        goto yy93;
      }
    }
  yy323:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy325;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy324:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy327;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy326;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy326;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy326;
        goto yy93;
      }
    }
  yy325:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy327;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy326:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy329;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy328;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy328;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy328;
        goto yy93;
      }
    }
  yy327:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy329;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy328:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy331;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy330;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy330;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy330;
        goto yy93;
      }
    }
  yy329:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy331;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy330:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy333;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy332;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy332;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy332;
        goto yy93;
      }
    }
  yy331:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy333;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy332:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy335;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy334;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy334;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy334;
        goto yy93;
      }
    }
  yy333:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy335;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy334:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy337;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy336;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy336;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy336;
        goto yy93;
      }
    }
  yy335:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy337;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy336:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy339;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy338;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy338;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy338;
        goto yy93;
      }
    }
  yy337:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy339;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy338:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy341;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy340;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy340;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy340;
        goto yy93;
      }
    }
  yy339:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy341;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy340:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy343;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy342;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy342;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy342;
        goto yy93;
      }
    }
  yy341:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy343;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy342:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= ',')
          goto yy93;
        if (yych <= '-')
          goto yy345;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy344;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy344;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy344;
        goto yy93;
      }
    }
  yy343:
    yych = *++p;
    if (yych <= '9') {
      if (yych == '-')
        goto yy345;
      if (yych <= '/')
        goto yy93;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy93;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych >= '{')
          goto yy93;
      }
    }
  yy344:
    yych = *++p;
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych <= '-')
          goto yy93;
        goto yy99;
      } else {
        if (yych <= '/')
          goto yy93;
        if (yych <= '9')
          goto yy225;
        goto yy93;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy100;
        if (yych <= '@')
          goto yy93;
        goto yy225;
      } else {
        if (yych <= '`')
          goto yy93;
        if (yych <= 'z')
          goto yy225;
        goto yy93;
      }
    }
  yy345:
    ++p;
    if ((yych = *p) <= '@') {
      if (yych <= '/')
        goto yy93;
      if (yych <= '9')
        goto yy225;
      goto yy93;
    } else {
      if (yych <= 'Z')
        goto yy225;
      if (yych <= '`')
        goto yy93;
      if (yych <= 'z')
        goto yy225;
      goto yy93;
    }
  }
}

// Try to match an HTML tag after first <, returning num of chars matched.
bufsize_t _scan_html_tag(const unsigned char *p) {
  const unsigned char *marker = NULL;
  const unsigned char *start = p;

  {
    unsigned char yych;
    static const unsigned char yybm[] = {
        /* table 1 .. 8: 0 */
        0, 239, 239, 239, 239, 239, 239, 239, 239, 238, 238, 238, 238, 238, 239,
        239, 239, 239, 239, 239, 239, 239, 239, 239, 239, 239, 239, 239, 239,
        239, 239, 239, 238, 239, 234, 239, 239, 239, 239, 236, 239, 239, 239,
        239, 239, 207, 239, 239, 239, 239, 239, 239, 239, 239, 239, 239, 239,
        239, 239, 239, 238, 238, 174, 231, 239, 255, 255, 255, 255, 255, 255,
        255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
        255, 255, 255, 255, 255, 255, 239, 239, 111, 239, 239, 238, 239, 239,
        239, 239, 239, 239, 239, 239, 239, 239, 239, 239, 239, 239, 239, 239,
        239, 239, 239, 239, 239, 239, 239, 239, 239, 239, 239, 239, 239, 239,
        239, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
        /* table 9 .. 11: 256 */
        0, 0, 0, 0, 0, 0, 0, 0, 0, 64, 64, 64, 64, 64, 0, 0, 0, 0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 64, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
        160, 128, 0, 160, 160, 160, 160, 160, 160, 160, 160, 160, 160, 128, 0,
        0, 0, 0, 0, 0, 160, 160, 160, 160, 160, 160, 160, 160, 160, 160, 160,
        160, 160, 160, 160, 160, 160, 160, 160, 160, 160, 160, 160, 160, 160,
        160, 0, 0, 0, 0, 128, 0, 160, 160, 160, 160, 160, 160, 160, 160, 160,
        160, 160, 160, 160, 160, 160, 160, 160, 160, 160, 160, 160, 160, 160,
        160, 160, 160, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
    };
    yych = *p;
    if (yych <= '>') {
      if (yych <= '!') {
        if (yych >= '!')
          goto yy350;
      } else {
        if (yych == '/')
          goto yy351;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '?')
          goto yy352;
        if (yych >= 'A')
          goto yy353;
      } else {
        if (yych <= '`')
          goto yy348;
        if (yych <= 'z')
          goto yy353;
      }
    }
  yy348:
    ++p;
  yy349 : { return 0; }
  yy350:
    yych = *(marker = ++p);
    if (yybm[0 + yych] & 16) {
      goto yy426;
    }
    if (yych == '-')
      goto yy428;
    if (yych <= '@')
      goto yy349;
    if (yych <= '[')
      goto yy425;
    goto yy349;
  yy351:
    yych = *(marker = ++p);
    if (yych <= '@')
      goto yy349;
    if (yych <= 'Z')
      goto yy421;
    if (yych <= '`')
      goto yy349;
    if (yych <= 'z')
      goto yy421;
    goto yy349;
  yy352:
    yych = *(marker = ++p);
    if (yych <= 0x00)
      goto yy349;
    if (yych <= 0x7F)
      goto yy405;
    if (yych <= 0xC1)
      goto yy349;
    if (yych <= 0xF4)
      goto yy405;
    goto yy349;
  yy353:
    yych = *(marker = ++p);
    if (yybm[256 + yych] & 64) {
      goto yy357;
    }
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych != '-')
          goto yy349;
      } else {
        if (yych <= '/')
          goto yy359;
        if (yych >= ':')
          goto yy349;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy360;
        if (yych <= '@')
          goto yy349;
      } else {
        if (yych <= '`')
          goto yy349;
        if (yych >= '{')
          goto yy349;
      }
    }
  yy354:
    ++p;
    yych = *p;
    if (yybm[256 + yych] & 64) {
      goto yy357;
    }
    if (yych <= '=') {
      if (yych <= '.') {
        if (yych == '-')
          goto yy354;
      } else {
        if (yych <= '/')
          goto yy359;
        if (yych <= '9')
          goto yy354;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy360;
        if (yych >= 'A')
          goto yy354;
      } else {
        if (yych <= '`')
          goto yy356;
        if (yych <= 'z')
          goto yy354;
      }
    }
  yy356:
    p = marker;
    goto yy349;
  yy357:
    ++p;
    yych = *p;
    if (yybm[256 + yych] & 64) {
      goto yy357;
    }
    if (yych <= '>') {
      if (yych <= '9') {
        if (yych != '/')
          goto yy356;
      } else {
        if (yych <= ':')
          goto yy362;
        if (yych <= '=')
          goto yy356;
        goto yy360;
      }
    } else {
      if (yych <= '^') {
        if (yych <= '@')
          goto yy356;
        if (yych <= 'Z')
          goto yy362;
        goto yy356;
      } else {
        if (yych == '`')
          goto yy356;
        if (yych <= 'z')
          goto yy362;
        goto yy356;
      }
    }
  yy359:
    yych = *++p;
    if (yych != '>')
      goto yy356;
  yy360:
    ++p;
    { return (bufsize_t)(p - start); }
  yy362:
    ++p;
    yych = *p;
    if (yybm[256 + yych] & 128) {
      goto yy362;
    }
    if (yych <= ',') {
      if (yych <= '\r') {
        if (yych <= 0x08)
          goto yy356;
      } else {
        if (yych != ' ')
          goto yy356;
      }
    } else {
      if (yych <= '<') {
        if (yych <= '/')
          goto yy359;
        goto yy356;
      } else {
        if (yych <= '=')
          goto yy366;
        if (yych <= '>')
          goto yy360;
        goto yy356;
      }
    }
  yy364:
    ++p;
    yych = *p;
    if (yych <= '<') {
      if (yych <= ' ') {
        if (yych <= 0x08)
          goto yy356;
        if (yych <= '\r')
          goto yy364;
        if (yych <= 0x1F)
          goto yy356;
        goto yy364;
      } else {
        if (yych <= '/') {
          if (yych <= '.')
            goto yy356;
          goto yy359;
        } else {
          if (yych == ':')
            goto yy362;
          goto yy356;
        }
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '=')
          goto yy366;
        if (yych <= '>')
          goto yy360;
        if (yych <= '@')
          goto yy356;
        goto yy362;
      } else {
        if (yych <= '_') {
          if (yych <= '^')
            goto yy356;
          goto yy362;
        } else {
          if (yych <= '`')
            goto yy356;
          if (yych <= 'z')
            goto yy362;
          goto yy356;
        }
      }
    }
  yy366:
    ++p;
    yych = *p;
    if (yybm[0 + yych] & 1) {
      goto yy368;
    }
    if (yych <= 0xE0) {
      if (yych <= '"') {
        if (yych <= 0x00)
          goto yy356;
        if (yych >= '!')
          goto yy379;
      } else {
        if (yych <= '\'')
          goto yy377;
        if (yych <= 0xC1)
          goto yy356;
        if (yych <= 0xDF)
          goto yy370;
        goto yy371;
      }
    } else {
      if (yych <= 0xEF) {
        if (yych == 0xED)
          goto yy376;
        goto yy372;
      } else {
        if (yych <= 0xF0)
          goto yy373;
        if (yych <= 0xF3)
          goto yy374;
        if (yych <= 0xF4)
          goto yy375;
        goto yy356;
      }
    }
    ++p;
    yych = *p;
    if (yybm[0 + yych] & 1) {
      goto yy368;
    }
    if (yych <= 0xDF) {
      if (yych <= '\'') {
        if (yych <= 0x00)
          goto yy356;
        if (yych <= ' ')
          goto yy402;
        if (yych <= '"')
          goto yy379;
        goto yy377;
      } else {
        if (yych == '>')
          goto yy360;
        if (yych <= 0xC1)
          goto yy356;
        goto yy370;
      }
    } else {
      if (yych <= 0xEF) {
        if (yych <= 0xE0)
          goto yy371;
        if (yych == 0xED)
          goto yy376;
        goto yy372;
      } else {
        if (yych <= 0xF0)
          goto yy373;
        if (yych <= 0xF3)
          goto yy374;
        if (yych <= 0xF4)
          goto yy375;
        goto yy356;
      }
    }
  yy368:
    ++p;
    yych = *p;
    if (yybm[0 + yych] & 1) {
      goto yy368;
    }
    if (yych <= 0xE0) {
      if (yych <= '=') {
        if (yych <= 0x00)
          goto yy356;
        if (yych <= ' ')
          goto yy396;
        goto yy356;
      } else {
        if (yych <= '>')
          goto yy360;
        if (yych <= 0xC1)
          goto yy356;
        if (yych >= 0xE0)
          goto yy371;
      }
    } else {
      if (yych <= 0xEF) {
        if (yych == 0xED)
          goto yy376;
        goto yy372;
      } else {
        if (yych <= 0xF0)
          goto yy373;
        if (yych <= 0xF3)
          goto yy374;
        if (yych <= 0xF4)
          goto yy375;
        goto yy356;
      }
    }
  yy370:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy356;
    if (yych <= 0xBF)
      goto yy368;
    goto yy356;
  yy371:
    ++p;
    yych = *p;
    if (yych <= 0x9F)
      goto yy356;
    if (yych <= 0xBF)
      goto yy370;
    goto yy356;
  yy372:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy356;
    if (yych <= 0xBF)
      goto yy370;
    goto yy356;
  yy373:
    ++p;
    yych = *p;
    if (yych <= 0x8F)
      goto yy356;
    if (yych <= 0xBF)
      goto yy372;
    goto yy356;
  yy374:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy356;
    if (yych <= 0xBF)
      goto yy372;
    goto yy356;
  yy375:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy356;
    if (yych <= 0x8F)
      goto yy372;
    goto yy356;
  yy376:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy356;
    if (yych <= 0x9F)
      goto yy370;
    goto yy356;
  yy377:
    ++p;
    yych = *p;
    if (yybm[0 + yych] & 2) {
      goto yy377;
    }
    if (yych <= 0xEC) {
      if (yych <= 0xC1) {
        if (yych <= 0x00)
          goto yy356;
        if (yych <= '\'')
          goto yy388;
        goto yy356;
      } else {
        if (yych <= 0xDF)
          goto yy389;
        if (yych <= 0xE0)
          goto yy390;
        goto yy391;
      }
    } else {
      if (yych <= 0xF0) {
        if (yych <= 0xED)
          goto yy395;
        if (yych <= 0xEF)
          goto yy391;
        goto yy392;
      } else {
        if (yych <= 0xF3)
          goto yy393;
        if (yych <= 0xF4)
          goto yy394;
        goto yy356;
      }
    }
  yy379:
    ++p;
    yych = *p;
    if (yybm[0 + yych] & 4) {
      goto yy379;
    }
    if (yych <= 0xEC) {
      if (yych <= 0xC1) {
        if (yych <= 0x00)
          goto yy356;
        if (yych <= '"')
          goto yy388;
        goto yy356;
      } else {
        if (yych <= 0xDF)
          goto yy381;
        if (yych <= 0xE0)
          goto yy382;
        goto yy383;
      }
    } else {
      if (yych <= 0xF0) {
        if (yych <= 0xED)
          goto yy387;
        if (yych <= 0xEF)
          goto yy383;
        goto yy384;
      } else {
        if (yych <= 0xF3)
          goto yy385;
        if (yych <= 0xF4)
          goto yy386;
        goto yy356;
      }
    }
  yy381:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy356;
    if (yych <= 0xBF)
      goto yy379;
    goto yy356;
  yy382:
    ++p;
    yych = *p;
    if (yych <= 0x9F)
      goto yy356;
    if (yych <= 0xBF)
      goto yy381;
    goto yy356;
  yy383:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy356;
    if (yych <= 0xBF)
      goto yy381;
    goto yy356;
  yy384:
    ++p;
    yych = *p;
    if (yych <= 0x8F)
      goto yy356;
    if (yych <= 0xBF)
      goto yy383;
    goto yy356;
  yy385:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy356;
    if (yych <= 0xBF)
      goto yy383;
    goto yy356;
  yy386:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy356;
    if (yych <= 0x8F)
      goto yy383;
    goto yy356;
  yy387:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy356;
    if (yych <= 0x9F)
      goto yy381;
    goto yy356;
  yy388:
    ++p;
    yych = *p;
    if (yybm[256 + yych] & 64) {
      goto yy357;
    }
    if (yych == '/')
      goto yy359;
    if (yych == '>')
      goto yy360;
    goto yy356;
  yy389:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy356;
    if (yych <= 0xBF)
      goto yy377;
    goto yy356;
  yy390:
    ++p;
    yych = *p;
    if (yych <= 0x9F)
      goto yy356;
    if (yych <= 0xBF)
      goto yy389;
    goto yy356;
  yy391:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy356;
    if (yych <= 0xBF)
      goto yy389;
    goto yy356;
  yy392:
    ++p;
    yych = *p;
    if (yych <= 0x8F)
      goto yy356;
    if (yych <= 0xBF)
      goto yy391;
    goto yy356;
  yy393:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy356;
    if (yych <= 0xBF)
      goto yy391;
    goto yy356;
  yy394:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy356;
    if (yych <= 0x8F)
      goto yy391;
    goto yy356;
  yy395:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy356;
    if (yych <= 0x9F)
      goto yy389;
    goto yy356;
  yy396:
    ++p;
    yych = *p;
    if (yych <= '@') {
      if (yych <= '"') {
        if (yych <= '\r') {
          if (yych <= 0x00)
            goto yy356;
          if (yych <= 0x08)
            goto yy368;
          goto yy396;
        } else {
          if (yych == ' ')
            goto yy396;
          if (yych <= '!')
            goto yy368;
          goto yy356;
        }
      } else {
        if (yych <= ':') {
          if (yych == '\'')
            goto yy356;
          if (yych <= '9')
            goto yy368;
        } else {
          if (yych <= ';')
            goto yy368;
          if (yych <= '=')
            goto yy356;
          if (yych <= '>')
            goto yy360;
          goto yy368;
        }
      }
    } else {
      if (yych <= 0xDF) {
        if (yych <= '`') {
          if (yych <= 'Z')
            goto yy398;
          if (yych <= '^')
            goto yy368;
          if (yych >= '`')
            goto yy356;
        } else {
          if (yych <= 'z')
            goto yy398;
          if (yych <= 0x7F)
            goto yy368;
          if (yych <= 0xC1)
            goto yy356;
          goto yy370;
        }
      } else {
        if (yych <= 0xEF) {
          if (yych <= 0xE0)
            goto yy371;
          if (yych == 0xED)
            goto yy376;
          goto yy372;
        } else {
          if (yych <= 0xF0)
            goto yy373;
          if (yych <= 0xF3)
            goto yy374;
          if (yych <= 0xF4)
            goto yy375;
          goto yy356;
        }
      }
    }
  yy398:
    ++p;
    yych = *p;
    if (yych <= '>') {
      if (yych <= '&') {
        if (yych <= 0x1F) {
          if (yych <= 0x00)
            goto yy356;
          if (yych <= 0x08)
            goto yy368;
          if (yych >= 0x0E)
            goto yy368;
        } else {
          if (yych <= ' ')
            goto yy400;
          if (yych == '"')
            goto yy356;
          goto yy368;
        }
      } else {
        if (yych <= '/') {
          if (yych <= '\'')
            goto yy356;
          if (yych <= ',')
            goto yy368;
          if (yych <= '.')
            goto yy398;
          goto yy368;
        } else {
          if (yych <= ';') {
            if (yych <= ':')
              goto yy398;
            goto yy368;
          } else {
            if (yych <= '<')
              goto yy356;
            if (yych <= '=')
              goto yy366;
            goto yy360;
          }
        }
      }
    } else {
      if (yych <= 0xC1) {
        if (yych <= '_') {
          if (yych <= '@')
            goto yy368;
          if (yych <= 'Z')
            goto yy398;
          if (yych <= '^')
            goto yy368;
          goto yy398;
        } else {
          if (yych <= '`')
            goto yy356;
          if (yych <= 'z')
            goto yy398;
          if (yych <= 0x7F)
            goto yy368;
          goto yy356;
        }
      } else {
        if (yych <= 0xED) {
          if (yych <= 0xDF)
            goto yy370;
          if (yych <= 0xE0)
            goto yy371;
          if (yych <= 0xEC)
            goto yy372;
          goto yy376;
        } else {
          if (yych <= 0xF0) {
            if (yych <= 0xEF)
              goto yy372;
            goto yy373;
          } else {
            if (yych <= 0xF3)
              goto yy374;
            if (yych <= 0xF4)
              goto yy375;
            goto yy356;
          }
        }
      }
    }
  yy400:
    ++p;
    yych = *p;
    if (yych <= '@') {
      if (yych <= '&') {
        if (yych <= 0x1F) {
          if (yych <= 0x00)
            goto yy356;
          if (yych <= 0x08)
            goto yy368;
          if (yych <= '\r')
            goto yy400;
          goto yy368;
        } else {
          if (yych <= ' ')
            goto yy400;
          if (yych == '"')
            goto yy356;
          goto yy368;
        }
      } else {
        if (yych <= ';') {
          if (yych <= '\'')
            goto yy356;
          if (yych == ':')
            goto yy398;
          goto yy368;
        } else {
          if (yych <= '<')
            goto yy356;
          if (yych <= '=')
            goto yy366;
          if (yych <= '>')
            goto yy360;
          goto yy368;
        }
      }
    } else {
      if (yych <= 0xDF) {
        if (yych <= '`') {
          if (yych <= 'Z')
            goto yy398;
          if (yych <= '^')
            goto yy368;
          if (yych <= '_')
            goto yy398;
          goto yy356;
        } else {
          if (yych <= 'z')
            goto yy398;
          if (yych <= 0x7F)
            goto yy368;
          if (yych <= 0xC1)
            goto yy356;
          goto yy370;
        }
      } else {
        if (yych <= 0xEF) {
          if (yych <= 0xE0)
            goto yy371;
          if (yych == 0xED)
            goto yy376;
          goto yy372;
        } else {
          if (yych <= 0xF0)
            goto yy373;
          if (yych <= 0xF3)
            goto yy374;
          if (yych <= 0xF4)
            goto yy375;
          goto yy356;
        }
      }
    }
  yy402:
    ++p;
    yych = *p;
    if (yych <= '@') {
      if (yych <= '"') {
        if (yych <= '\r') {
          if (yych <= 0x00)
            goto yy356;
          if (yych <= 0x08)
            goto yy368;
          goto yy402;
        } else {
          if (yych == ' ')
            goto yy402;
          if (yych <= '!')
            goto yy368;
          goto yy379;
        }
      } else {
        if (yych <= ':') {
          if (yych == '\'')
            goto yy377;
          if (yych <= '9')
            goto yy368;
          goto yy398;
        } else {
          if (yych <= ';')
            goto yy368;
          if (yych <= '=')
            goto yy356;
          if (yych <= '>')
            goto yy360;
          goto yy368;
        }
      }
    } else {
      if (yych <= 0xDF) {
        if (yych <= '`') {
          if (yych <= 'Z')
            goto yy398;
          if (yych <= '^')
            goto yy368;
          if (yych <= '_')
            goto yy398;
          goto yy356;
        } else {
          if (yych <= 'z')
            goto yy398;
          if (yych <= 0x7F)
            goto yy368;
          if (yych <= 0xC1)
            goto yy356;
          goto yy370;
        }
      } else {
        if (yych <= 0xEF) {
          if (yych <= 0xE0)
            goto yy371;
          if (yych == 0xED)
            goto yy376;
          goto yy372;
        } else {
          if (yych <= 0xF0)
            goto yy373;
          if (yych <= 0xF3)
            goto yy374;
          if (yych <= 0xF4)
            goto yy375;
          goto yy356;
        }
      }
    }
  yy404:
    ++p;
    yych = *p;
  yy405:
    if (yybm[0 + yych] & 8) {
      goto yy404;
    }
    if (yych <= 0xEC) {
      if (yych <= 0xC1) {
        if (yych <= 0x00)
          goto yy356;
        if (yych <= '?')
          goto yy413;
        goto yy356;
      } else {
        if (yych <= 0xDF)
          goto yy406;
        if (yych <= 0xE0)
          goto yy407;
        goto yy408;
      }
    } else {
      if (yych <= 0xF0) {
        if (yych <= 0xED)
          goto yy412;
        if (yych <= 0xEF)
          goto yy408;
        goto yy409;
      } else {
        if (yych <= 0xF3)
          goto yy410;
        if (yych <= 0xF4)
          goto yy411;
        goto yy356;
      }
    }
  yy406:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy356;
    if (yych <= 0xBF)
      goto yy404;
    goto yy356;
  yy407:
    ++p;
    yych = *p;
    if (yych <= 0x9F)
      goto yy356;
    if (yych <= 0xBF)
      goto yy406;
    goto yy356;
  yy408:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy356;
    if (yych <= 0xBF)
      goto yy406;
    goto yy356;
  yy409:
    ++p;
    yych = *p;
    if (yych <= 0x8F)
      goto yy356;
    if (yych <= 0xBF)
      goto yy408;
    goto yy356;
  yy410:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy356;
    if (yych <= 0xBF)
      goto yy408;
    goto yy356;
  yy411:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy356;
    if (yych <= 0x8F)
      goto yy408;
    goto yy356;
  yy412:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy356;
    if (yych <= 0x9F)
      goto yy406;
    goto yy356;
  yy413:
    ++p;
    yych = *p;
    if (yych <= 0xE0) {
      if (yych <= '>') {
        if (yych <= 0x00)
          goto yy356;
        if (yych <= '=')
          goto yy404;
        goto yy360;
      } else {
        if (yych <= 0x7F)
          goto yy404;
        if (yych <= 0xC1)
          goto yy356;
        if (yych >= 0xE0)
          goto yy415;
      }
    } else {
      if (yych <= 0xEF) {
        if (yych == 0xED)
          goto yy420;
        goto yy416;
      } else {
        if (yych <= 0xF0)
          goto yy417;
        if (yych <= 0xF3)
          goto yy418;
        if (yych <= 0xF4)
          goto yy419;
        goto yy356;
      }
    }
  yy414:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy356;
    if (yych <= 0xBF)
      goto yy404;
    goto yy356;
  yy415:
    ++p;
    yych = *p;
    if (yych <= 0x9F)
      goto yy356;
    if (yych <= 0xBF)
      goto yy414;
    goto yy356;
  yy416:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy356;
    if (yych <= 0xBF)
      goto yy414;
    goto yy356;
  yy417:
    ++p;
    yych = *p;
    if (yych <= 0x8F)
      goto yy356;
    if (yych <= 0xBF)
      goto yy416;
    goto yy356;
  yy418:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy356;
    if (yych <= 0xBF)
      goto yy416;
    goto yy356;
  yy419:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy356;
    if (yych <= 0x8F)
      goto yy416;
    goto yy356;
  yy420:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy356;
    if (yych <= 0x9F)
      goto yy414;
    goto yy356;
  yy421:
    ++p;
    yych = *p;
    if (yych <= '/') {
      if (yych <= 0x1F) {
        if (yych <= 0x08)
          goto yy356;
        if (yych >= 0x0E)
          goto yy356;
      } else {
        if (yych <= ' ')
          goto yy423;
        if (yych == '-')
          goto yy421;
        goto yy356;
      }
    } else {
      if (yych <= '@') {
        if (yych <= '9')
          goto yy421;
        if (yych == '>')
          goto yy360;
        goto yy356;
      } else {
        if (yych <= 'Z')
          goto yy421;
        if (yych <= '`')
          goto yy356;
        if (yych <= 'z')
          goto yy421;
        goto yy356;
      }
    }
  yy423:
    ++p;
    yych = *p;
    if (yych <= 0x1F) {
      if (yych <= 0x08)
        goto yy356;
      if (yych <= '\r')
        goto yy423;
      goto yy356;
    } else {
      if (yych <= ' ')
        goto yy423;
      if (yych == '>')
        goto yy360;
      goto yy356;
    }
  yy425:
    yych = *++p;
    if (yych == 'C')
      goto yy461;
    if (yych == 'c')
      goto yy461;
    goto yy356;
  yy426:
    ++p;
    yych = *p;
    if (yybm[0 + yych] & 16) {
      goto yy426;
    }
    if (yych <= 0x08)
      goto yy356;
    if (yych <= '\r')
      goto yy450;
    if (yych == ' ')
      goto yy450;
    goto yy356;
  yy428:
    yych = *++p;
    if (yych != '-')
      goto yy356;
    yych = *++p;
    if (yych <= 0xE0) {
      if (yych <= '=') {
        if (yych != '-')
          goto yy432;
      } else {
        if (yych <= '>')
          goto yy356;
        if (yych <= 0xC1)
          goto yy432;
        if (yych <= 0xDF)
          goto yy433;
        goto yy434;
      }
    } else {
      if (yych <= 0xEF) {
        if (yych == 0xED)
          goto yy439;
        goto yy435;
      } else {
        if (yych <= 0xF0)
          goto yy436;
        if (yych <= 0xF3)
          goto yy437;
        if (yych <= 0xF4)
          goto yy438;
        goto yy432;
      }
    }
    yych = *++p;
    if (yych <= 0xE0) {
      if (yych <= '=') {
        if (yych == '-')
          goto yy449;
        goto yy432;
      } else {
        if (yych <= '>')
          goto yy356;
        if (yych <= 0xC1)
          goto yy432;
        if (yych <= 0xDF)
          goto yy433;
        goto yy434;
      }
    } else {
      if (yych <= 0xEF) {
        if (yych == 0xED)
          goto yy439;
        goto yy435;
      } else {
        if (yych <= 0xF0)
          goto yy436;
        if (yych <= 0xF3)
          goto yy437;
        if (yych <= 0xF4)
          goto yy438;
        goto yy432;
      }
    }
  yy431:
    ++p;
    yych = *p;
  yy432:
    if (yybm[0 + yych] & 32) {
      goto yy431;
    }
    if (yych <= 0xEC) {
      if (yych <= 0xC1) {
        if (yych <= 0x00)
          goto yy356;
        if (yych <= '-')
          goto yy440;
        goto yy356;
      } else {
        if (yych <= 0xDF)
          goto yy441;
        if (yych <= 0xE0)
          goto yy442;
        goto yy443;
      }
    } else {
      if (yych <= 0xF0) {
        if (yych <= 0xED)
          goto yy447;
        if (yych <= 0xEF)
          goto yy443;
        goto yy444;
      } else {
        if (yych <= 0xF3)
          goto yy445;
        if (yych <= 0xF4)
          goto yy446;
        goto yy356;
      }
    }
  yy433:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy356;
    if (yych <= 0xBF)
      goto yy431;
    goto yy356;
  yy434:
    yych = *++p;
    if (yych <= 0x9F)
      goto yy356;
    if (yych <= 0xBF)
      goto yy433;
    goto yy356;
  yy435:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy356;
    if (yych <= 0xBF)
      goto yy433;
    goto yy356;
  yy436:
    yych = *++p;
    if (yych <= 0x8F)
      goto yy356;
    if (yych <= 0xBF)
      goto yy435;
    goto yy356;
  yy437:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy356;
    if (yych <= 0xBF)
      goto yy435;
    goto yy356;
  yy438:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy356;
    if (yych <= 0x8F)
      goto yy435;
    goto yy356;
  yy439:
    yych = *++p;
    if (yych <= 0x7F)
      goto yy356;
    if (yych <= 0x9F)
      goto yy433;
    goto yy356;
  yy440:
    ++p;
    yych = *p;
    if (yybm[0 + yych] & 32) {
      goto yy431;
    }
    if (yych <= 0xEC) {
      if (yych <= 0xC1) {
        if (yych <= 0x00)
          goto yy356;
        if (yych <= '-')
          goto yy448;
        goto yy356;
      } else {
        if (yych <= 0xDF)
          goto yy441;
        if (yych <= 0xE0)
          goto yy442;
        goto yy443;
      }
    } else {
      if (yych <= 0xF0) {
        if (yych <= 0xED)
          goto yy447;
        if (yych <= 0xEF)
          goto yy443;
        goto yy444;
      } else {
        if (yych <= 0xF3)
          goto yy445;
        if (yych <= 0xF4)
          goto yy446;
        goto yy356;
      }
    }
  yy441:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy356;
    if (yych <= 0xBF)
      goto yy431;
    goto yy356;
  yy442:
    ++p;
    yych = *p;
    if (yych <= 0x9F)
      goto yy356;
    if (yych <= 0xBF)
      goto yy441;
    goto yy356;
  yy443:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy356;
    if (yych <= 0xBF)
      goto yy441;
    goto yy356;
  yy444:
    ++p;
    yych = *p;
    if (yych <= 0x8F)
      goto yy356;
    if (yych <= 0xBF)
      goto yy443;
    goto yy356;
  yy445:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy356;
    if (yych <= 0xBF)
      goto yy443;
    goto yy356;
  yy446:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy356;
    if (yych <= 0x8F)
      goto yy443;
    goto yy356;
  yy447:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy356;
    if (yych <= 0x9F)
      goto yy441;
    goto yy356;
  yy448:
    yych = *++p;
    if (yych == '>')
      goto yy360;
    goto yy356;
  yy449:
    yych = *++p;
    if (yych == '>')
      goto yy360;
    goto yy356;
  yy450:
    ++p;
    yych = *p;
    if (yych <= 0xC1) {
      if (yych <= 0x1F) {
        if (yych <= 0x00)
          goto yy356;
        if (yych <= 0x08)
          goto yy452;
        if (yych <= '\r')
          goto yy450;
      } else {
        if (yych <= '=') {
          if (yych <= ' ')
            goto yy450;
        } else {
          if (yych <= '>')
            goto yy360;
          if (yych >= 0x80)
            goto yy356;
        }
      }
    } else {
      if (yych <= 0xED) {
        if (yych <= 0xDF)
          goto yy454;
        if (yych <= 0xE0)
          goto yy455;
        if (yych <= 0xEC)
          goto yy456;
        goto yy460;
      } else {
        if (yych <= 0xF0) {
          if (yych <= 0xEF)
            goto yy456;
          goto yy457;
        } else {
          if (yych <= 0xF3)
            goto yy458;
          if (yych <= 0xF4)
            goto yy459;
          goto yy356;
        }
      }
    }
  yy452:
    ++p;
    yych = *p;
    if (yybm[0 + yych] & 64) {
      goto yy452;
    }
    if (yych <= 0xEC) {
      if (yych <= 0xC1) {
        if (yych <= 0x00)
          goto yy356;
        if (yych <= '>')
          goto yy360;
        goto yy356;
      } else {
        if (yych <= 0xDF)
          goto yy454;
        if (yych <= 0xE0)
          goto yy455;
        goto yy456;
      }
    } else {
      if (yych <= 0xF0) {
        if (yych <= 0xED)
          goto yy460;
        if (yych <= 0xEF)
          goto yy456;
        goto yy457;
      } else {
        if (yych <= 0xF3)
          goto yy458;
        if (yych <= 0xF4)
          goto yy459;
        goto yy356;
      }
    }
  yy454:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy356;
    if (yych <= 0xBF)
      goto yy452;
    goto yy356;
  yy455:
    ++p;
    yych = *p;
    if (yych <= 0x9F)
      goto yy356;
    if (yych <= 0xBF)
      goto yy454;
    goto yy356;
  yy456:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy356;
    if (yych <= 0xBF)
      goto yy454;
    goto yy356;
  yy457:
    ++p;
    yych = *p;
    if (yych <= 0x8F)
      goto yy356;
    if (yych <= 0xBF)
      goto yy456;
    goto yy356;
  yy458:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy356;
    if (yych <= 0xBF)
      goto yy456;
    goto yy356;
  yy459:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy356;
    if (yych <= 0x8F)
      goto yy456;
    goto yy356;
  yy460:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy356;
    if (yych <= 0x9F)
      goto yy454;
    goto yy356;
  yy461:
    yych = *++p;
    if (yych == 'D')
      goto yy462;
    if (yych != 'd')
      goto yy356;
  yy462:
    yych = *++p;
    if (yych == 'A')
      goto yy463;
    if (yych != 'a')
      goto yy356;
  yy463:
    yych = *++p;
    if (yych == 'T')
      goto yy464;
    if (yych != 't')
      goto yy356;
  yy464:
    yych = *++p;
    if (yych == 'A')
      goto yy465;
    if (yych != 'a')
      goto yy356;
  yy465:
    yych = *++p;
    if (yych != '[')
      goto yy356;
  yy466:
    ++p;
    yych = *p;
    if (yybm[0 + yych] & 128) {
      goto yy466;
    }
    if (yych <= 0xEC) {
      if (yych <= 0xC1) {
        if (yych <= 0x00)
          goto yy356;
        if (yych <= ']')
          goto yy475;
        goto yy356;
      } else {
        if (yych <= 0xDF)
          goto yy468;
        if (yych <= 0xE0)
          goto yy469;
        goto yy470;
      }
    } else {
      if (yych <= 0xF0) {
        if (yych <= 0xED)
          goto yy474;
        if (yych <= 0xEF)
          goto yy470;
        goto yy471;
      } else {
        if (yych <= 0xF3)
          goto yy472;
        if (yych <= 0xF4)
          goto yy473;
        goto yy356;
      }
    }
  yy468:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy356;
    if (yych <= 0xBF)
      goto yy466;
    goto yy356;
  yy469:
    ++p;
    yych = *p;
    if (yych <= 0x9F)
      goto yy356;
    if (yych <= 0xBF)
      goto yy468;
    goto yy356;
  yy470:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy356;
    if (yych <= 0xBF)
      goto yy468;
    goto yy356;
  yy471:
    ++p;
    yych = *p;
    if (yych <= 0x8F)
      goto yy356;
    if (yych <= 0xBF)
      goto yy470;
    goto yy356;
  yy472:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy356;
    if (yych <= 0xBF)
      goto yy470;
    goto yy356;
  yy473:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy356;
    if (yych <= 0x8F)
      goto yy470;
    goto yy356;
  yy474:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy356;
    if (yych <= 0x9F)
      goto yy468;
    goto yy356;
  yy475:
    ++p;
    yych = *p;
    if (yybm[0 + yych] & 128) {
      goto yy466;
    }
    if (yych <= 0xEC) {
      if (yych <= 0xC1) {
        if (yych <= 0x00)
          goto yy356;
        if (yych >= '^')
          goto yy356;
      } else {
        if (yych <= 0xDF)
          goto yy477;
        if (yych <= 0xE0)
          goto yy478;
        goto yy479;
      }
    } else {
      if (yych <= 0xF0) {
        if (yych <= 0xED)
          goto yy483;
        if (yych <= 0xEF)
          goto yy479;
        goto yy480;
      } else {
        if (yych <= 0xF3)
          goto yy481;
        if (yych <= 0xF4)
          goto yy482;
        goto yy356;
      }
    }
    ++p;
    yych = *p;
    if (yych <= 0xE0) {
      if (yych <= '>') {
        if (yych <= 0x00)
          goto yy356;
        if (yych <= '=')
          goto yy466;
        goto yy360;
      } else {
        if (yych <= 0x7F)
          goto yy466;
        if (yych <= 0xC1)
          goto yy356;
        if (yych <= 0xDF)
          goto yy484;
        goto yy485;
      }
    } else {
      if (yych <= 0xEF) {
        if (yych == 0xED)
          goto yy490;
        goto yy486;
      } else {
        if (yych <= 0xF0)
          goto yy487;
        if (yych <= 0xF3)
          goto yy488;
        if (yych <= 0xF4)
          goto yy489;
        goto yy356;
      }
    }
  yy477:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy356;
    if (yych <= 0xBF)
      goto yy466;
    goto yy356;
  yy478:
    ++p;
    yych = *p;
    if (yych <= 0x9F)
      goto yy356;
    if (yych <= 0xBF)
      goto yy477;
    goto yy356;
  yy479:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy356;
    if (yych <= 0xBF)
      goto yy477;
    goto yy356;
  yy480:
    ++p;
    yych = *p;
    if (yych <= 0x8F)
      goto yy356;
    if (yych <= 0xBF)
      goto yy479;
    goto yy356;
  yy481:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy356;
    if (yych <= 0xBF)
      goto yy479;
    goto yy356;
  yy482:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy356;
    if (yych <= 0x8F)
      goto yy479;
    goto yy356;
  yy483:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy356;
    if (yych <= 0x9F)
      goto yy477;
    goto yy356;
  yy484:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy356;
    if (yych <= 0xBF)
      goto yy466;
    goto yy356;
  yy485:
    ++p;
    yych = *p;
    if (yych <= 0x9F)
      goto yy356;
    if (yych <= 0xBF)
      goto yy484;
    goto yy356;
  yy486:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy356;
    if (yych <= 0xBF)
      goto yy484;
    goto yy356;
  yy487:
    ++p;
    yych = *p;
    if (yych <= 0x8F)
      goto yy356;
    if (yych <= 0xBF)
      goto yy486;
    goto yy356;
  yy488:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy356;
    if (yych <= 0xBF)
      goto yy486;
    goto yy356;
  yy489:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy356;
    if (yych <= 0x8F)
      goto yy486;
    goto yy356;
  yy490:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy356;
    if (yych <= 0x9F)
      goto yy484;
    goto yy356;
  }
}

// Try to (liberally) match an HTML tag after first <, returning num of chars
// matched.
bufsize_t _scan_liberal_html_tag(const unsigned char *p) {
  const unsigned char *marker = NULL;
  const unsigned char *start = p;

  {
    unsigned char yych;
    unsigned int yyaccept = 0;
    static const unsigned char yybm[] = {
        0,  64, 64, 64, 64, 64, 64, 64, 64,  64, 0,  64, 64, 64, 64, 64, 64, 64,
        64, 64, 64, 64, 64, 64, 64, 64, 64,  64, 64, 64, 64, 64, 64, 64, 64, 64,
        64, 64, 64, 64, 64, 64, 64, 64, 64,  64, 64, 64, 64, 64, 64, 64, 64, 64,
        64, 64, 64, 64, 64, 64, 64, 64, 128, 64, 64, 64, 64, 64, 64, 64, 64, 64,
        64, 64, 64, 64, 64, 64, 64, 64, 64,  64, 64, 64, 64, 64, 64, 64, 64, 64,
        64, 64, 64, 64, 64, 64, 64, 64, 64,  64, 64, 64, 64, 64, 64, 64, 64, 64,
        64, 64, 64, 64, 64, 64, 64, 64, 64,  64, 64, 64, 64, 64, 64, 64, 64, 64,
        64, 64, 0,  0,  0,  0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,  0,  0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,  0,  0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,  0,  0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,  0,  0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,  0,  0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,  0,  0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,
    };
    yych = *p;
    if (yych <= 0xE0) {
      if (yych <= '\n') {
        if (yych <= 0x00)
          goto yy493;
        if (yych <= '\t')
          goto yy495;
      } else {
        if (yych <= 0x7F)
          goto yy495;
        if (yych <= 0xC1)
          goto yy493;
        if (yych <= 0xDF)
          goto yy496;
        goto yy497;
      }
    } else {
      if (yych <= 0xEF) {
        if (yych == 0xED)
          goto yy499;
        goto yy498;
      } else {
        if (yych <= 0xF0)
          goto yy500;
        if (yych <= 0xF3)
          goto yy501;
        if (yych <= 0xF4)
          goto yy502;
      }
    }
  yy493:
    ++p;
  yy494 : { return 0; }
  yy495:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= '\n') {
      if (yych <= 0x00)
        goto yy494;
      if (yych <= '\t')
        goto yy507;
      goto yy494;
    } else {
      if (yych <= 0x7F)
        goto yy507;
      if (yych <= 0xC1)
        goto yy494;
      if (yych <= 0xF4)
        goto yy507;
      goto yy494;
    }
  yy496:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x7F)
      goto yy494;
    if (yych <= 0xBF)
      goto yy506;
    goto yy494;
  yy497:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x9F)
      goto yy494;
    if (yych <= 0xBF)
      goto yy505;
    goto yy494;
  yy498:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x7F)
      goto yy494;
    if (yych <= 0xBF)
      goto yy505;
    goto yy494;
  yy499:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x7F)
      goto yy494;
    if (yych <= 0x9F)
      goto yy505;
    goto yy494;
  yy500:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x8F)
      goto yy494;
    if (yych <= 0xBF)
      goto yy503;
    goto yy494;
  yy501:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x7F)
      goto yy494;
    if (yych <= 0xBF)
      goto yy503;
    goto yy494;
  yy502:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x7F)
      goto yy494;
    if (yych >= 0x90)
      goto yy494;
  yy503:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy504;
    if (yych <= 0xBF)
      goto yy505;
  yy504:
    p = marker;
    if (yyaccept == 0) {
      goto yy494;
    } else {
      goto yy510;
    }
  yy505:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy504;
    if (yych >= 0xC0)
      goto yy504;
  yy506:
    ++p;
    yych = *p;
  yy507:
    if (yybm[0 + yych] & 64) {
      goto yy506;
    }
    if (yych <= 0xEC) {
      if (yych <= 0xC1) {
        if (yych <= '\n')
          goto yy504;
        if (yych >= '?')
          goto yy504;
      } else {
        if (yych <= 0xDF)
          goto yy505;
        if (yych <= 0xE0)
          goto yy511;
        goto yy503;
      }
    } else {
      if (yych <= 0xF0) {
        if (yych <= 0xED)
          goto yy515;
        if (yych <= 0xEF)
          goto yy503;
        goto yy512;
      } else {
        if (yych <= 0xF3)
          goto yy513;
        if (yych <= 0xF4)
          goto yy514;
        goto yy504;
      }
    }
  yy508:
    yyaccept = 1;
    marker = ++p;
    yych = *p;
    if (yybm[0 + yych] & 64) {
      goto yy506;
    }
    if (yych <= 0xEC) {
      if (yych <= 0xC1) {
        if (yych <= '\n')
          goto yy510;
        if (yych <= '>')
          goto yy508;
      } else {
        if (yych <= 0xDF)
          goto yy505;
        if (yych <= 0xE0)
          goto yy511;
        goto yy503;
      }
    } else {
      if (yych <= 0xF0) {
        if (yych <= 0xED)
          goto yy515;
        if (yych <= 0xEF)
          goto yy503;
        goto yy512;
      } else {
        if (yych <= 0xF3)
          goto yy513;
        if (yych <= 0xF4)
          goto yy514;
      }
    }
  yy510 : { return (bufsize_t)(p - start); }
  yy511:
    ++p;
    yych = *p;
    if (yych <= 0x9F)
      goto yy504;
    if (yych <= 0xBF)
      goto yy505;
    goto yy504;
  yy512:
    ++p;
    yych = *p;
    if (yych <= 0x8F)
      goto yy504;
    if (yych <= 0xBF)
      goto yy503;
    goto yy504;
  yy513:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy504;
    if (yych <= 0xBF)
      goto yy503;
    goto yy504;
  yy514:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy504;
    if (yych <= 0x8F)
      goto yy503;
    goto yy504;
  yy515:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy504;
    if (yych <= 0x9F)
      goto yy505;
    goto yy504;
  }
}

// Try to match an HTML block tag start line, returning
// an integer code for the type of block (1-6, matching the spec).
// #7 is handled by a separate function, below.
bufsize_t _scan_html_block_start(const unsigned char *p) {
  const unsigned char *marker = NULL;

  {
    unsigned char yych;
    yych = *p;
    if (yych == '<')
      goto yy520;
    ++p;
  yy519 : { return 0; }
  yy520:
    yych = *(marker = ++p);
    switch (yych) {
    case '!':
      goto yy538;
    case '/':
      goto yy521;
    case '?':
      goto yy539;
    case 'A':
    case 'a':
      goto yy524;
    case 'B':
    case 'b':
      goto yy525;
    case 'C':
    case 'c':
      goto yy526;
    case 'D':
    case 'd':
      goto yy527;
    case 'F':
    case 'f':
      goto yy528;
    case 'H':
    case 'h':
      goto yy529;
    case 'I':
    case 'i':
      goto yy530;
    case 'L':
    case 'l':
      goto yy531;
    case 'M':
    case 'm':
      goto yy532;
    case 'N':
    case 'n':
      goto yy533;
    case 'O':
    case 'o':
      goto yy534;
    case 'P':
    case 'p':
      goto yy523;
    case 'S':
    case 's':
      goto yy535;
    case 'T':
    case 't':
      goto yy536;
    case 'U':
    case 'u':
      goto yy537;
    default:
      goto yy519;
    }
  yy521:
    yych = *++p;
    switch (yych) {
    case 'A':
    case 'a':
      goto yy524;
    case 'B':
    case 'b':
      goto yy525;
    case 'C':
    case 'c':
      goto yy526;
    case 'D':
    case 'd':
      goto yy527;
    case 'F':
    case 'f':
      goto yy528;
    case 'H':
    case 'h':
      goto yy529;
    case 'I':
    case 'i':
      goto yy530;
    case 'L':
    case 'l':
      goto yy531;
    case 'M':
    case 'm':
      goto yy532;
    case 'N':
    case 'n':
      goto yy533;
    case 'O':
    case 'o':
      goto yy534;
    case 'P':
    case 'p':
      goto yy723;
    case 'S':
    case 's':
      goto yy724;
    case 'T':
    case 't':
      goto yy536;
    case 'U':
    case 'u':
      goto yy537;
    default:
      goto yy522;
    }
  yy522:
    p = marker;
    goto yy519;
  yy523:
    yych = *++p;
    if (yych <= '>') {
      if (yych <= ' ') {
        if (yych <= 0x08)
          goto yy522;
        if (yych <= '\r')
          goto yy555;
        if (yych <= 0x1F)
          goto yy522;
        goto yy555;
      } else {
        if (yych == '/')
          goto yy557;
        if (yych <= '=')
          goto yy522;
        goto yy555;
      }
    } else {
      if (yych <= 'R') {
        if (yych == 'A')
          goto yy720;
        if (yych <= 'Q')
          goto yy522;
        goto yy719;
      } else {
        if (yych <= 'a') {
          if (yych <= '`')
            goto yy522;
          goto yy720;
        } else {
          if (yych == 'r')
            goto yy719;
          goto yy522;
        }
      }
    }
  yy524:
    yych = *++p;
    if (yych <= 'S') {
      if (yych <= 'D') {
        if (yych <= 'C')
          goto yy522;
        goto yy708;
      } else {
        if (yych <= 'Q')
          goto yy522;
        if (yych <= 'R')
          goto yy707;
        goto yy706;
      }
    } else {
      if (yych <= 'q') {
        if (yych == 'd')
          goto yy708;
        goto yy522;
      } else {
        if (yych <= 'r')
          goto yy707;
        if (yych <= 's')
          goto yy706;
        goto yy522;
      }
    }
  yy525:
    yych = *++p;
    if (yych <= 'O') {
      if (yych <= 'K') {
        if (yych == 'A')
          goto yy692;
        goto yy522;
      } else {
        if (yych <= 'L')
          goto yy691;
        if (yych <= 'N')
          goto yy522;
        goto yy690;
      }
    } else {
      if (yych <= 'k') {
        if (yych == 'a')
          goto yy692;
        goto yy522;
      } else {
        if (yych <= 'l')
          goto yy691;
        if (yych == 'o')
          goto yy690;
        goto yy522;
      }
    }
  yy526:
    yych = *++p;
    if (yych <= 'O') {
      if (yych <= 'D') {
        if (yych == 'A')
          goto yy677;
        goto yy522;
      } else {
        if (yych <= 'E')
          goto yy676;
        if (yych <= 'N')
          goto yy522;
        goto yy675;
      }
    } else {
      if (yych <= 'd') {
        if (yych == 'a')
          goto yy677;
        goto yy522;
      } else {
        if (yych <= 'e')
          goto yy676;
        if (yych == 'o')
          goto yy675;
        goto yy522;
      }
    }
  yy527:
    yych = *++p;
    switch (yych) {
    case 'D':
    case 'L':
    case 'T':
    case 'd':
    case 'l':
    case 't':
      goto yy554;
    case 'E':
    case 'e':
      goto yy667;
    case 'I':
    case 'i':
      goto yy666;
    default:
      goto yy522;
    }
  yy528:
    yych = *++p;
    if (yych <= 'R') {
      if (yych <= 'N') {
        if (yych == 'I')
          goto yy642;
        goto yy522;
      } else {
        if (yych <= 'O')
          goto yy641;
        if (yych <= 'Q')
          goto yy522;
        goto yy640;
      }
    } else {
      if (yych <= 'n') {
        if (yych == 'i')
          goto yy642;
        goto yy522;
      } else {
        if (yych <= 'o')
          goto yy641;
        if (yych == 'r')
          goto yy640;
        goto yy522;
      }
    }
  yy529:
    yych = *++p;
    if (yych <= 'S') {
      if (yych <= 'D') {
        if (yych <= '0')
          goto yy522;
        if (yych <= '6')
          goto yy554;
        goto yy522;
      } else {
        if (yych <= 'E')
          goto yy635;
        if (yych == 'R')
          goto yy554;
        goto yy522;
      }
    } else {
      if (yych <= 'q') {
        if (yych <= 'T')
          goto yy634;
        if (yych == 'e')
          goto yy635;
        goto yy522;
      } else {
        if (yych <= 'r')
          goto yy554;
        if (yych == 't')
          goto yy634;
        goto yy522;
      }
    }
  yy530:
    yych = *++p;
    if (yych == 'F')
      goto yy630;
    if (yych == 'f')
      goto yy630;
    goto yy522;
  yy531:
    yych = *++p;
    if (yych <= 'I') {
      if (yych == 'E')
        goto yy625;
      if (yych <= 'H')
        goto yy522;
      goto yy624;
    } else {
      if (yych <= 'e') {
        if (yych <= 'd')
          goto yy522;
        goto yy625;
      } else {
        if (yych == 'i')
          goto yy624;
        goto yy522;
      }
    }
  yy532:
    yych = *++p;
    if (yych <= 'E') {
      if (yych == 'A')
        goto yy616;
      if (yych <= 'D')
        goto yy522;
      goto yy615;
    } else {
      if (yych <= 'a') {
        if (yych <= '`')
          goto yy522;
        goto yy616;
      } else {
        if (yych == 'e')
          goto yy615;
        goto yy522;
      }
    }
  yy533:
    yych = *++p;
    if (yych <= 'O') {
      if (yych == 'A')
        goto yy609;
      if (yych <= 'N')
        goto yy522;
      goto yy608;
    } else {
      if (yych <= 'a') {
        if (yych <= '`')
          goto yy522;
        goto yy609;
      } else {
        if (yych == 'o')
          goto yy608;
        goto yy522;
      }
    }
  yy534:
    yych = *++p;
    if (yych <= 'P') {
      if (yych == 'L')
        goto yy554;
      if (yych <= 'O')
        goto yy522;
      goto yy600;
    } else {
      if (yych <= 'l') {
        if (yych <= 'k')
          goto yy522;
        goto yy554;
      } else {
        if (yych == 'p')
          goto yy600;
        goto yy522;
      }
    }
  yy535:
    yych = *++p;
    switch (yych) {
    case 'C':
    case 'c':
      goto yy577;
    case 'E':
    case 'e':
      goto yy580;
    case 'O':
    case 'o':
      goto yy579;
    case 'T':
    case 't':
      goto yy576;
    case 'U':
    case 'u':
      goto yy578;
    default:
      goto yy522;
    }
  yy536:
    yych = *++p;
    switch (yych) {
    case 'A':
    case 'a':
      goto yy563;
    case 'B':
    case 'b':
      goto yy562;
    case 'D':
    case 'd':
      goto yy554;
    case 'F':
    case 'f':
      goto yy561;
    case 'H':
    case 'h':
      goto yy560;
    case 'I':
    case 'i':
      goto yy559;
    case 'R':
    case 'r':
      goto yy558;
    default:
      goto yy522;
    }
  yy537:
    yych = *++p;
    if (yych == 'L')
      goto yy554;
    if (yych == 'l')
      goto yy554;
    goto yy522;
  yy538:
    yych = *++p;
    if (yych <= '@') {
      if (yych == '-')
        goto yy541;
      goto yy522;
    } else {
      if (yych <= 'Z')
        goto yy542;
      if (yych <= '[')
        goto yy544;
      goto yy522;
    }
  yy539:
    ++p;
    { return 3; }
  yy541:
    yych = *++p;
    if (yych == '-')
      goto yy552;
    goto yy522;
  yy542:
    ++p;
    { return 4; }
  yy544:
    yych = *++p;
    if (yych == 'C')
      goto yy545;
    if (yych != 'c')
      goto yy522;
  yy545:
    yych = *++p;
    if (yych == 'D')
      goto yy546;
    if (yych != 'd')
      goto yy522;
  yy546:
    yych = *++p;
    if (yych == 'A')
      goto yy547;
    if (yych != 'a')
      goto yy522;
  yy547:
    yych = *++p;
    if (yych == 'T')
      goto yy548;
    if (yych != 't')
      goto yy522;
  yy548:
    yych = *++p;
    if (yych == 'A')
      goto yy549;
    if (yych != 'a')
      goto yy522;
  yy549:
    yych = *++p;
    if (yych != '[')
      goto yy522;
    ++p;
    { return 5; }
  yy552:
    ++p;
    { return 2; }
  yy554:
    yych = *++p;
    if (yych <= ' ') {
      if (yych <= 0x08)
        goto yy522;
      if (yych <= '\r')
        goto yy555;
      if (yych <= 0x1F)
        goto yy522;
    } else {
      if (yych <= '/') {
        if (yych <= '.')
          goto yy522;
        goto yy557;
      } else {
        if (yych != '>')
          goto yy522;
      }
    }
  yy555:
    ++p;
    { return 6; }
  yy557:
    yych = *++p;
    if (yych == '>')
      goto yy555;
    goto yy522;
  yy558:
    yych = *++p;
    if (yych <= '/') {
      if (yych <= 0x1F) {
        if (yych <= 0x08)
          goto yy522;
        if (yych <= '\r')
          goto yy555;
        goto yy522;
      } else {
        if (yych <= ' ')
          goto yy555;
        if (yych <= '.')
          goto yy522;
        goto yy557;
      }
    } else {
      if (yych <= '@') {
        if (yych == '>')
          goto yy555;
        goto yy522;
      } else {
        if (yych <= 'A')
          goto yy574;
        if (yych == 'a')
          goto yy574;
        goto yy522;
      }
    }
  yy559:
    yych = *++p;
    if (yych == 'T')
      goto yy572;
    if (yych == 't')
      goto yy572;
    goto yy522;
  yy560:
    yych = *++p;
    if (yych <= '/') {
      if (yych <= 0x1F) {
        if (yych <= 0x08)
          goto yy522;
        if (yych <= '\r')
          goto yy555;
        goto yy522;
      } else {
        if (yych <= ' ')
          goto yy555;
        if (yych <= '.')
          goto yy522;
        goto yy557;
      }
    } else {
      if (yych <= 'D') {
        if (yych == '>')
          goto yy555;
        goto yy522;
      } else {
        if (yych <= 'E')
          goto yy570;
        if (yych == 'e')
          goto yy570;
        goto yy522;
      }
    }
  yy561:
    yych = *++p;
    if (yych == 'O')
      goto yy568;
    if (yych == 'o')
      goto yy568;
    goto yy522;
  yy562:
    yych = *++p;
    if (yych == 'O')
      goto yy566;
    if (yych == 'o')
      goto yy566;
    goto yy522;
  yy563:
    yych = *++p;
    if (yych == 'B')
      goto yy564;
    if (yych != 'b')
      goto yy522;
  yy564:
    yych = *++p;
    if (yych == 'L')
      goto yy565;
    if (yych != 'l')
      goto yy522;
  yy565:
    yych = *++p;
    if (yych == 'E')
      goto yy554;
    if (yych == 'e')
      goto yy554;
    goto yy522;
  yy566:
    yych = *++p;
    if (yych == 'D')
      goto yy567;
    if (yych != 'd')
      goto yy522;
  yy567:
    yych = *++p;
    if (yych == 'Y')
      goto yy554;
    if (yych == 'y')
      goto yy554;
    goto yy522;
  yy568:
    yych = *++p;
    if (yych == 'O')
      goto yy569;
    if (yych != 'o')
      goto yy522;
  yy569:
    yych = *++p;
    if (yych == 'T')
      goto yy554;
    if (yych == 't')
      goto yy554;
    goto yy522;
  yy570:
    yych = *++p;
    if (yych == 'A')
      goto yy571;
    if (yych != 'a')
      goto yy522;
  yy571:
    yych = *++p;
    if (yych == 'D')
      goto yy554;
    if (yych == 'd')
      goto yy554;
    goto yy522;
  yy572:
    yych = *++p;
    if (yych == 'L')
      goto yy573;
    if (yych != 'l')
      goto yy522;
  yy573:
    yych = *++p;
    if (yych == 'E')
      goto yy554;
    if (yych == 'e')
      goto yy554;
    goto yy522;
  yy574:
    yych = *++p;
    if (yych == 'C')
      goto yy575;
    if (yych != 'c')
      goto yy522;
  yy575:
    yych = *++p;
    if (yych == 'K')
      goto yy554;
    if (yych == 'k')
      goto yy554;
    goto yy522;
  yy576:
    yych = *++p;
    if (yych == 'Y')
      goto yy598;
    if (yych == 'y')
      goto yy598;
    goto yy522;
  yy577:
    yych = *++p;
    if (yych == 'R')
      goto yy592;
    if (yych == 'r')
      goto yy592;
    goto yy522;
  yy578:
    yych = *++p;
    if (yych == 'M')
      goto yy588;
    if (yych == 'm')
      goto yy588;
    goto yy522;
  yy579:
    yych = *++p;
    if (yych == 'U')
      goto yy585;
    if (yych == 'u')
      goto yy585;
    goto yy522;
  yy580:
    yych = *++p;
    if (yych == 'C')
      goto yy581;
    if (yych != 'c')
      goto yy522;
  yy581:
    yych = *++p;
    if (yych == 'T')
      goto yy582;
    if (yych != 't')
      goto yy522;
  yy582:
    yych = *++p;
    if (yych == 'I')
      goto yy583;
    if (yych != 'i')
      goto yy522;
  yy583:
    yych = *++p;
    if (yych == 'O')
      goto yy584;
    if (yych != 'o')
      goto yy522;
  yy584:
    yych = *++p;
    if (yych == 'N')
      goto yy554;
    if (yych == 'n')
      goto yy554;
    goto yy522;
  yy585:
    yych = *++p;
    if (yych == 'R')
      goto yy586;
    if (yych != 'r')
      goto yy522;
  yy586:
    yych = *++p;
    if (yych == 'C')
      goto yy587;
    if (yych != 'c')
      goto yy522;
  yy587:
    yych = *++p;
    if (yych == 'E')
      goto yy554;
    if (yych == 'e')
      goto yy554;
    goto yy522;
  yy588:
    yych = *++p;
    if (yych == 'M')
      goto yy589;
    if (yych != 'm')
      goto yy522;
  yy589:
    yych = *++p;
    if (yych == 'A')
      goto yy590;
    if (yych != 'a')
      goto yy522;
  yy590:
    yych = *++p;
    if (yych == 'R')
      goto yy591;
    if (yych != 'r')
      goto yy522;
  yy591:
    yych = *++p;
    if (yych == 'Y')
      goto yy554;
    if (yych == 'y')
      goto yy554;
    goto yy522;
  yy592:
    yych = *++p;
    if (yych == 'I')
      goto yy593;
    if (yych != 'i')
      goto yy522;
  yy593:
    yych = *++p;
    if (yych == 'P')
      goto yy594;
    if (yych != 'p')
      goto yy522;
  yy594:
    yych = *++p;
    if (yych == 'T')
      goto yy595;
    if (yych != 't')
      goto yy522;
  yy595:
    yych = *++p;
    if (yych <= 0x1F) {
      if (yych <= 0x08)
        goto yy522;
      if (yych >= 0x0E)
        goto yy522;
    } else {
      if (yych <= ' ')
        goto yy596;
      if (yych != '>')
        goto yy522;
    }
  yy596:
    ++p;
    { return 1; }
  yy598:
    yych = *++p;
    if (yych == 'L')
      goto yy599;
    if (yych != 'l')
      goto yy522;
  yy599:
    yych = *++p;
    if (yych == 'E')
      goto yy595;
    if (yych == 'e')
      goto yy595;
    goto yy522;
  yy600:
    yych = *++p;
    if (yych == 'T')
      goto yy601;
    if (yych != 't')
      goto yy522;
  yy601:
    yych = *++p;
    if (yych <= 'I') {
      if (yych == 'G')
        goto yy603;
      if (yych <= 'H')
        goto yy522;
    } else {
      if (yych <= 'g') {
        if (yych <= 'f')
          goto yy522;
        goto yy603;
      } else {
        if (yych != 'i')
          goto yy522;
      }
    }
    yych = *++p;
    if (yych == 'O')
      goto yy607;
    if (yych == 'o')
      goto yy607;
    goto yy522;
  yy603:
    yych = *++p;
    if (yych == 'R')
      goto yy604;
    if (yych != 'r')
      goto yy522;
  yy604:
    yych = *++p;
    if (yych == 'O')
      goto yy605;
    if (yych != 'o')
      goto yy522;
  yy605:
    yych = *++p;
    if (yych == 'U')
      goto yy606;
    if (yych != 'u')
      goto yy522;
  yy606:
    yych = *++p;
    if (yych == 'P')
      goto yy554;
    if (yych == 'p')
      goto yy554;
    goto yy522;
  yy607:
    yych = *++p;
    if (yych == 'N')
      goto yy554;
    if (yych == 'n')
      goto yy554;
    goto yy522;
  yy608:
    yych = *++p;
    if (yych == 'F')
      goto yy610;
    if (yych == 'f')
      goto yy610;
    goto yy522;
  yy609:
    yych = *++p;
    if (yych == 'V')
      goto yy554;
    if (yych == 'v')
      goto yy554;
    goto yy522;
  yy610:
    yych = *++p;
    if (yych == 'R')
      goto yy611;
    if (yych != 'r')
      goto yy522;
  yy611:
    yych = *++p;
    if (yych == 'A')
      goto yy612;
    if (yych != 'a')
      goto yy522;
  yy612:
    yych = *++p;
    if (yych == 'M')
      goto yy613;
    if (yych != 'm')
      goto yy522;
  yy613:
    yych = *++p;
    if (yych == 'E')
      goto yy614;
    if (yych != 'e')
      goto yy522;
  yy614:
    yych = *++p;
    if (yych == 'S')
      goto yy554;
    if (yych == 's')
      goto yy554;
    goto yy522;
  yy615:
    yych = *++p;
    if (yych <= 'T') {
      if (yych == 'N')
        goto yy618;
      if (yych <= 'S')
        goto yy522;
      goto yy619;
    } else {
      if (yych <= 'n') {
        if (yych <= 'm')
          goto yy522;
        goto yy618;
      } else {
        if (yych == 't')
          goto yy619;
        goto yy522;
      }
    }
  yy616:
    yych = *++p;
    if (yych == 'I')
      goto yy617;
    if (yych != 'i')
      goto yy522;
  yy617:
    yych = *++p;
    if (yych == 'N')
      goto yy554;
    if (yych == 'n')
      goto yy554;
    goto yy522;
  yy618:
    yych = *++p;
    if (yych == 'U')
      goto yy620;
    if (yych == 'u')
      goto yy620;
    goto yy522;
  yy619:
    yych = *++p;
    if (yych == 'A')
      goto yy554;
    if (yych == 'a')
      goto yy554;
    goto yy522;
  yy620:
    yych = *++p;
    if (yych <= '/') {
      if (yych <= 0x1F) {
        if (yych <= 0x08)
          goto yy522;
        if (yych <= '\r')
          goto yy555;
        goto yy522;
      } else {
        if (yych <= ' ')
          goto yy555;
        if (yych <= '.')
          goto yy522;
        goto yy557;
      }
    } else {
      if (yych <= 'H') {
        if (yych == '>')
          goto yy555;
        goto yy522;
      } else {
        if (yych <= 'I')
          goto yy621;
        if (yych != 'i')
          goto yy522;
      }
    }
  yy621:
    yych = *++p;
    if (yych == 'T')
      goto yy622;
    if (yych != 't')
      goto yy522;
  yy622:
    yych = *++p;
    if (yych == 'E')
      goto yy623;
    if (yych != 'e')
      goto yy522;
  yy623:
    yych = *++p;
    if (yych == 'M')
      goto yy554;
    if (yych == 'm')
      goto yy554;
    goto yy522;
  yy624:
    yych = *++p;
    if (yych <= '/') {
      if (yych <= 0x1F) {
        if (yych <= 0x08)
          goto yy522;
        if (yych <= '\r')
          goto yy555;
        goto yy522;
      } else {
        if (yych <= ' ')
          goto yy555;
        if (yych <= '.')
          goto yy522;
        goto yy557;
      }
    } else {
      if (yych <= 'M') {
        if (yych == '>')
          goto yy555;
        goto yy522;
      } else {
        if (yych <= 'N')
          goto yy629;
        if (yych == 'n')
          goto yy629;
        goto yy522;
      }
    }
  yy625:
    yych = *++p;
    if (yych == 'G')
      goto yy626;
    if (yych != 'g')
      goto yy522;
  yy626:
    yych = *++p;
    if (yych == 'E')
      goto yy627;
    if (yych != 'e')
      goto yy522;
  yy627:
    yych = *++p;
    if (yych == 'N')
      goto yy628;
    if (yych != 'n')
      goto yy522;
  yy628:
    yych = *++p;
    if (yych == 'D')
      goto yy554;
    if (yych == 'd')
      goto yy554;
    goto yy522;
  yy629:
    yych = *++p;
    if (yych == 'K')
      goto yy554;
    if (yych == 'k')
      goto yy554;
    goto yy522;
  yy630:
    yych = *++p;
    if (yych == 'R')
      goto yy631;
    if (yych != 'r')
      goto yy522;
  yy631:
    yych = *++p;
    if (yych == 'A')
      goto yy632;
    if (yych != 'a')
      goto yy522;
  yy632:
    yych = *++p;
    if (yych == 'M')
      goto yy633;
    if (yych != 'm')
      goto yy522;
  yy633:
    yych = *++p;
    if (yych == 'E')
      goto yy554;
    if (yych == 'e')
      goto yy554;
    goto yy522;
  yy634:
    yych = *++p;
    if (yych == 'M')
      goto yy639;
    if (yych == 'm')
      goto yy639;
    goto yy522;
  yy635:
    yych = *++p;
    if (yych == 'A')
      goto yy636;
    if (yych != 'a')
      goto yy522;
  yy636:
    yych = *++p;
    if (yych == 'D')
      goto yy637;
    if (yych != 'd')
      goto yy522;
  yy637:
    yych = *++p;
    if (yych <= '/') {
      if (yych <= 0x1F) {
        if (yych <= 0x08)
          goto yy522;
        if (yych <= '\r')
          goto yy555;
        goto yy522;
      } else {
        if (yych <= ' ')
          goto yy555;
        if (yych <= '.')
          goto yy522;
        goto yy557;
      }
    } else {
      if (yych <= 'D') {
        if (yych == '>')
          goto yy555;
        goto yy522;
      } else {
        if (yych <= 'E')
          goto yy638;
        if (yych != 'e')
          goto yy522;
      }
    }
  yy638:
    yych = *++p;
    if (yych == 'R')
      goto yy554;
    if (yych == 'r')
      goto yy554;
    goto yy522;
  yy639:
    yych = *++p;
    if (yych == 'L')
      goto yy554;
    if (yych == 'l')
      goto yy554;
    goto yy522;
  yy640:
    yych = *++p;
    if (yych == 'A')
      goto yy661;
    if (yych == 'a')
      goto yy661;
    goto yy522;
  yy641:
    yych = *++p;
    if (yych <= 'R') {
      if (yych == 'O')
        goto yy657;
      if (yych <= 'Q')
        goto yy522;
      goto yy658;
    } else {
      if (yych <= 'o') {
        if (yych <= 'n')
          goto yy522;
        goto yy657;
      } else {
        if (yych == 'r')
          goto yy658;
        goto yy522;
      }
    }
  yy642:
    yych = *++p;
    if (yych <= 'G') {
      if (yych == 'E')
        goto yy643;
      if (yych <= 'F')
        goto yy522;
      goto yy644;
    } else {
      if (yych <= 'e') {
        if (yych <= 'd')
          goto yy522;
      } else {
        if (yych == 'g')
          goto yy644;
        goto yy522;
      }
    }
  yy643:
    yych = *++p;
    if (yych == 'L')
      goto yy653;
    if (yych == 'l')
      goto yy653;
    goto yy522;
  yy644:
    yych = *++p;
    if (yych <= 'U') {
      if (yych == 'C')
        goto yy646;
      if (yych <= 'T')
        goto yy522;
    } else {
      if (yych <= 'c') {
        if (yych <= 'b')
          goto yy522;
        goto yy646;
      } else {
        if (yych != 'u')
          goto yy522;
      }
    }
    yych = *++p;
    if (yych == 'R')
      goto yy652;
    if (yych == 'r')
      goto yy652;
    goto yy522;
  yy646:
    yych = *++p;
    if (yych == 'A')
      goto yy647;
    if (yych != 'a')
      goto yy522;
  yy647:
    yych = *++p;
    if (yych == 'P')
      goto yy648;
    if (yych != 'p')
      goto yy522;
  yy648:
    yych = *++p;
    if (yych == 'T')
      goto yy649;
    if (yych != 't')
      goto yy522;
  yy649:
    yych = *++p;
    if (yych == 'I')
      goto yy650;
    if (yych != 'i')
      goto yy522;
  yy650:
    yych = *++p;
    if (yych == 'O')
      goto yy651;
    if (yych != 'o')
      goto yy522;
  yy651:
    yych = *++p;
    if (yych == 'N')
      goto yy554;
    if (yych == 'n')
      goto yy554;
    goto yy522;
  yy652:
    yych = *++p;
    if (yych == 'E')
      goto yy554;
    if (yych == 'e')
      goto yy554;
    goto yy522;
  yy653:
    yych = *++p;
    if (yych == 'D')
      goto yy654;
    if (yych != 'd')
      goto yy522;
  yy654:
    yych = *++p;
    if (yych == 'S')
      goto yy655;
    if (yych != 's')
      goto yy522;
  yy655:
    yych = *++p;
    if (yych == 'E')
      goto yy656;
    if (yych != 'e')
      goto yy522;
  yy656:
    yych = *++p;
    if (yych == 'T')
      goto yy554;
    if (yych == 't')
      goto yy554;
    goto yy522;
  yy657:
    yych = *++p;
    if (yych == 'T')
      goto yy659;
    if (yych == 't')
      goto yy659;
    goto yy522;
  yy658:
    yych = *++p;
    if (yych == 'M')
      goto yy554;
    if (yych == 'm')
      goto yy554;
    goto yy522;
  yy659:
    yych = *++p;
    if (yych == 'E')
      goto yy660;
    if (yych != 'e')
      goto yy522;
  yy660:
    yych = *++p;
    if (yych == 'R')
      goto yy554;
    if (yych == 'r')
      goto yy554;
    goto yy522;
  yy661:
    yych = *++p;
    if (yych == 'M')
      goto yy662;
    if (yych != 'm')
      goto yy522;
  yy662:
    yych = *++p;
    if (yych == 'E')
      goto yy663;
    if (yych != 'e')
      goto yy522;
  yy663:
    yych = *++p;
    if (yych <= '/') {
      if (yych <= 0x1F) {
        if (yych <= 0x08)
          goto yy522;
        if (yych <= '\r')
          goto yy555;
        goto yy522;
      } else {
        if (yych <= ' ')
          goto yy555;
        if (yych <= '.')
          goto yy522;
        goto yy557;
      }
    } else {
      if (yych <= 'R') {
        if (yych == '>')
          goto yy555;
        goto yy522;
      } else {
        if (yych <= 'S')
          goto yy664;
        if (yych != 's')
          goto yy522;
      }
    }
  yy664:
    yych = *++p;
    if (yych == 'E')
      goto yy665;
    if (yych != 'e')
      goto yy522;
  yy665:
    yych = *++p;
    if (yych == 'T')
      goto yy554;
    if (yych == 't')
      goto yy554;
    goto yy522;
  yy666:
    yych = *++p;
    if (yych <= 'V') {
      if (yych <= 'Q') {
        if (yych == 'A')
          goto yy672;
        goto yy522;
      } else {
        if (yych <= 'R')
          goto yy554;
        if (yych <= 'U')
          goto yy522;
        goto yy554;
      }
    } else {
      if (yych <= 'q') {
        if (yych == 'a')
          goto yy672;
        goto yy522;
      } else {
        if (yych <= 'r')
          goto yy554;
        if (yych == 'v')
          goto yy554;
        goto yy522;
      }
    }
  yy667:
    yych = *++p;
    if (yych == 'T')
      goto yy668;
    if (yych != 't')
      goto yy522;
  yy668:
    yych = *++p;
    if (yych == 'A')
      goto yy669;
    if (yych != 'a')
      goto yy522;
  yy669:
    yych = *++p;
    if (yych == 'I')
      goto yy670;
    if (yych != 'i')
      goto yy522;
  yy670:
    yych = *++p;
    if (yych == 'L')
      goto yy671;
    if (yych != 'l')
      goto yy522;
  yy671:
    yych = *++p;
    if (yych == 'S')
      goto yy554;
    if (yych == 's')
      goto yy554;
    goto yy522;
  yy672:
    yych = *++p;
    if (yych == 'L')
      goto yy673;
    if (yych != 'l')
      goto yy522;
  yy673:
    yych = *++p;
    if (yych == 'O')
      goto yy674;
    if (yych != 'o')
      goto yy522;
  yy674:
    yych = *++p;
    if (yych == 'G')
      goto yy554;
    if (yych == 'g')
      goto yy554;
    goto yy522;
  yy675:
    yych = *++p;
    if (yych == 'L')
      goto yy685;
    if (yych == 'l')
      goto yy685;
    goto yy522;
  yy676:
    yych = *++p;
    if (yych == 'N')
      goto yy682;
    if (yych == 'n')
      goto yy682;
    goto yy522;
  yy677:
    yych = *++p;
    if (yych == 'P')
      goto yy678;
    if (yych != 'p')
      goto yy522;
  yy678:
    yych = *++p;
    if (yych == 'T')
      goto yy679;
    if (yych != 't')
      goto yy522;
  yy679:
    yych = *++p;
    if (yych == 'I')
      goto yy680;
    if (yych != 'i')
      goto yy522;
  yy680:
    yych = *++p;
    if (yych == 'O')
      goto yy681;
    if (yych != 'o')
      goto yy522;
  yy681:
    yych = *++p;
    if (yych == 'N')
      goto yy554;
    if (yych == 'n')
      goto yy554;
    goto yy522;
  yy682:
    yych = *++p;
    if (yych == 'T')
      goto yy683;
    if (yych != 't')
      goto yy522;
  yy683:
    yych = *++p;
    if (yych == 'E')
      goto yy684;
    if (yych != 'e')
      goto yy522;
  yy684:
    yych = *++p;
    if (yych == 'R')
      goto yy554;
    if (yych == 'r')
      goto yy554;
    goto yy522;
  yy685:
    yych = *++p;
    if (yych <= '/') {
      if (yych <= 0x1F) {
        if (yych <= 0x08)
          goto yy522;
        if (yych <= '\r')
          goto yy555;
        goto yy522;
      } else {
        if (yych <= ' ')
          goto yy555;
        if (yych <= '.')
          goto yy522;
        goto yy557;
      }
    } else {
      if (yych <= 'F') {
        if (yych == '>')
          goto yy555;
        goto yy522;
      } else {
        if (yych <= 'G')
          goto yy686;
        if (yych != 'g')
          goto yy522;
      }
    }
  yy686:
    yych = *++p;
    if (yych == 'R')
      goto yy687;
    if (yych != 'r')
      goto yy522;
  yy687:
    yych = *++p;
    if (yych == 'O')
      goto yy688;
    if (yych != 'o')
      goto yy522;
  yy688:
    yych = *++p;
    if (yych == 'U')
      goto yy689;
    if (yych != 'u')
      goto yy522;
  yy689:
    yych = *++p;
    if (yych == 'P')
      goto yy554;
    if (yych == 'p')
      goto yy554;
    goto yy522;
  yy690:
    yych = *++p;
    if (yych == 'D')
      goto yy705;
    if (yych == 'd')
      goto yy705;
    goto yy522;
  yy691:
    yych = *++p;
    if (yych == 'O')
      goto yy698;
    if (yych == 'o')
      goto yy698;
    goto yy522;
  yy692:
    yych = *++p;
    if (yych == 'S')
      goto yy693;
    if (yych != 's')
      goto yy522;
  yy693:
    yych = *++p;
    if (yych == 'E')
      goto yy694;
    if (yych != 'e')
      goto yy522;
  yy694:
    yych = *++p;
    if (yych <= '/') {
      if (yych <= 0x1F) {
        if (yych <= 0x08)
          goto yy522;
        if (yych <= '\r')
          goto yy555;
        goto yy522;
      } else {
        if (yych <= ' ')
          goto yy555;
        if (yych <= '.')
          goto yy522;
        goto yy557;
      }
    } else {
      if (yych <= 'E') {
        if (yych == '>')
          goto yy555;
        goto yy522;
      } else {
        if (yych <= 'F')
          goto yy695;
        if (yych != 'f')
          goto yy522;
      }
    }
  yy695:
    yych = *++p;
    if (yych == 'O')
      goto yy696;
    if (yych != 'o')
      goto yy522;
  yy696:
    yych = *++p;
    if (yych == 'N')
      goto yy697;
    if (yych != 'n')
      goto yy522;
  yy697:
    yych = *++p;
    if (yych == 'T')
      goto yy554;
    if (yych == 't')
      goto yy554;
    goto yy522;
  yy698:
    yych = *++p;
    if (yych == 'C')
      goto yy699;
    if (yych != 'c')
      goto yy522;
  yy699:
    yych = *++p;
    if (yych == 'K')
      goto yy700;
    if (yych != 'k')
      goto yy522;
  yy700:
    yych = *++p;
    if (yych == 'Q')
      goto yy701;
    if (yych != 'q')
      goto yy522;
  yy701:
    yych = *++p;
    if (yych == 'U')
      goto yy702;
    if (yych != 'u')
      goto yy522;
  yy702:
    yych = *++p;
    if (yych == 'O')
      goto yy703;
    if (yych != 'o')
      goto yy522;
  yy703:
    yych = *++p;
    if (yych == 'T')
      goto yy704;
    if (yych != 't')
      goto yy522;
  yy704:
    yych = *++p;
    if (yych == 'E')
      goto yy554;
    if (yych == 'e')
      goto yy554;
    goto yy522;
  yy705:
    yych = *++p;
    if (yych == 'Y')
      goto yy554;
    if (yych == 'y')
      goto yy554;
    goto yy522;
  yy706:
    yych = *++p;
    if (yych == 'I')
      goto yy717;
    if (yych == 'i')
      goto yy717;
    goto yy522;
  yy707:
    yych = *++p;
    if (yych == 'T')
      goto yy713;
    if (yych == 't')
      goto yy713;
    goto yy522;
  yy708:
    yych = *++p;
    if (yych == 'D')
      goto yy709;
    if (yych != 'd')
      goto yy522;
  yy709:
    yych = *++p;
    if (yych == 'R')
      goto yy710;
    if (yych != 'r')
      goto yy522;
  yy710:
    yych = *++p;
    if (yych == 'E')
      goto yy711;
    if (yych != 'e')
      goto yy522;
  yy711:
    yych = *++p;
    if (yych == 'S')
      goto yy712;
    if (yych != 's')
      goto yy522;
  yy712:
    yych = *++p;
    if (yych == 'S')
      goto yy554;
    if (yych == 's')
      goto yy554;
    goto yy522;
  yy713:
    yych = *++p;
    if (yych == 'I')
      goto yy714;
    if (yych != 'i')
      goto yy522;
  yy714:
    yych = *++p;
    if (yych == 'C')
      goto yy715;
    if (yych != 'c')
      goto yy522;
  yy715:
    yych = *++p;
    if (yych == 'L')
      goto yy716;
    if (yych != 'l')
      goto yy522;
  yy716:
    yych = *++p;
    if (yych == 'E')
      goto yy554;
    if (yych == 'e')
      goto yy554;
    goto yy522;
  yy717:
    yych = *++p;
    if (yych == 'D')
      goto yy718;
    if (yych != 'd')
      goto yy522;
  yy718:
    yych = *++p;
    if (yych == 'E')
      goto yy554;
    if (yych == 'e')
      goto yy554;
    goto yy522;
  yy719:
    yych = *++p;
    if (yych == 'E')
      goto yy595;
    if (yych == 'e')
      goto yy595;
    goto yy522;
  yy720:
    yych = *++p;
    if (yych == 'R')
      goto yy721;
    if (yych != 'r')
      goto yy522;
  yy721:
    yych = *++p;
    if (yych == 'A')
      goto yy722;
    if (yych != 'a')
      goto yy522;
  yy722:
    yych = *++p;
    if (yych == 'M')
      goto yy554;
    if (yych == 'm')
      goto yy554;
    goto yy522;
  yy723:
    yych = *++p;
    if (yych <= '/') {
      if (yych <= 0x1F) {
        if (yych <= 0x08)
          goto yy522;
        if (yych <= '\r')
          goto yy555;
        goto yy522;
      } else {
        if (yych <= ' ')
          goto yy555;
        if (yych <= '.')
          goto yy522;
        goto yy557;
      }
    } else {
      if (yych <= '@') {
        if (yych == '>')
          goto yy555;
        goto yy522;
      } else {
        if (yych <= 'A')
          goto yy720;
        if (yych == 'a')
          goto yy720;
        goto yy522;
      }
    }
  yy724:
    ++p;
    if ((yych = *p) <= 'U') {
      if (yych <= 'N') {
        if (yych == 'E')
          goto yy580;
        goto yy522;
      } else {
        if (yych <= 'O')
          goto yy579;
        if (yych <= 'T')
          goto yy522;
        goto yy578;
      }
    } else {
      if (yych <= 'n') {
        if (yych == 'e')
          goto yy580;
        goto yy522;
      } else {
        if (yych <= 'o')
          goto yy579;
        if (yych == 'u')
          goto yy578;
        goto yy522;
      }
    }
  }
}

// Try to match an HTML block tag start line of type 7, returning
// 7 if successful, 0 if not.
bufsize_t _scan_html_block_start_7(const unsigned char *p) {
  const unsigned char *marker = NULL;

  {
    unsigned char yych;
    unsigned int yyaccept = 0;
    static const unsigned char yybm[] = {
        0,   224, 224, 224, 224, 224, 224, 224, 224, 198, 202, 194, 198, 194,
        224, 224, 224, 224, 224, 224, 224, 224, 224, 224, 224, 224, 224, 224,
        224, 224, 224, 224, 198, 224, 64,  224, 224, 224, 224, 128, 224, 224,
        224, 224, 224, 241, 240, 224, 241, 241, 241, 241, 241, 241, 241, 241,
        241, 241, 240, 224, 192, 192, 192, 224, 224, 241, 241, 241, 241, 241,
        241, 241, 241, 241, 241, 241, 241, 241, 241, 241, 241, 241, 241, 241,
        241, 241, 241, 241, 241, 241, 241, 224, 224, 224, 224, 240, 192, 241,
        241, 241, 241, 241, 241, 241, 241, 241, 241, 241, 241, 241, 241, 241,
        241, 241, 241, 241, 241, 241, 241, 241, 241, 241, 241, 224, 224, 224,
        224, 224, 0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,
    };
    yych = *p;
    if (yych == '<')
      goto yy729;
    ++p;
  yy728 : { return 0; }
  yy729:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= '@') {
      if (yych == '/')
        goto yy733;
      goto yy728;
    } else {
      if (yych <= 'Z')
        goto yy730;
      if (yych <= '`')
        goto yy728;
      if (yych >= '{')
        goto yy728;
    }
  yy730:
    ++p;
    yych = *p;
    if (yybm[0 + yych] & 1) {
      goto yy730;
    }
    if (yych <= ' ') {
      if (yych <= 0x08)
        goto yy732;
      if (yych <= '\r')
        goto yy744;
      if (yych >= ' ')
        goto yy744;
    } else {
      if (yych <= '/') {
        if (yych >= '/')
          goto yy746;
      } else {
        if (yych == '>')
          goto yy738;
      }
    }
  yy732:
    p = marker;
    if (yyaccept == 0) {
      goto yy728;
    } else {
      goto yy742;
    }
  yy733:
    yych = *++p;
    if (yych <= '@')
      goto yy732;
    if (yych <= 'Z')
      goto yy734;
    if (yych <= '`')
      goto yy732;
    if (yych >= '{')
      goto yy732;
  yy734:
    ++p;
    yych = *p;
    if (yybm[0 + yych] & 2) {
      goto yy736;
    }
    if (yych <= '=') {
      if (yych <= '-') {
        if (yych <= ',')
          goto yy732;
        goto yy734;
      } else {
        if (yych <= '/')
          goto yy732;
        if (yych <= '9')
          goto yy734;
        goto yy732;
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '>')
          goto yy738;
        if (yych <= '@')
          goto yy732;
        goto yy734;
      } else {
        if (yych <= '`')
          goto yy732;
        if (yych <= 'z')
          goto yy734;
        goto yy732;
      }
    }
  yy736:
    ++p;
    yych = *p;
    if (yybm[0 + yych] & 2) {
      goto yy736;
    }
    if (yych != '>')
      goto yy732;
  yy738:
    ++p;
    yych = *p;
    if (yybm[0 + yych] & 4) {
      goto yy738;
    }
    if (yych <= 0x08)
      goto yy732;
    if (yych <= '\n')
      goto yy740;
    if (yych <= '\v')
      goto yy732;
    if (yych <= '\r')
      goto yy743;
    goto yy732;
  yy740:
    yyaccept = 1;
    marker = ++p;
    yych = *p;
    if (yybm[0 + yych] & 4) {
      goto yy738;
    }
    if (yych <= 0x08)
      goto yy742;
    if (yych <= '\n')
      goto yy740;
    if (yych <= '\v')
      goto yy742;
    if (yych <= '\r')
      goto yy743;
  yy742 : { return 7; }
  yy743:
    yych = *++p;
    goto yy742;
  yy744:
    ++p;
    yych = *p;
    if (yych <= ':') {
      if (yych <= ' ') {
        if (yych <= 0x08)
          goto yy732;
        if (yych <= '\r')
          goto yy744;
        if (yych <= 0x1F)
          goto yy732;
        goto yy744;
      } else {
        if (yych == '/')
          goto yy746;
        if (yych <= '9')
          goto yy732;
        goto yy747;
      }
    } else {
      if (yych <= 'Z') {
        if (yych == '>')
          goto yy738;
        if (yych <= '@')
          goto yy732;
        goto yy747;
      } else {
        if (yych <= '_') {
          if (yych <= '^')
            goto yy732;
          goto yy747;
        } else {
          if (yych <= '`')
            goto yy732;
          if (yych <= 'z')
            goto yy747;
          goto yy732;
        }
      }
    }
  yy746:
    yych = *++p;
    if (yych == '>')
      goto yy738;
    goto yy732;
  yy747:
    ++p;
    yych = *p;
    if (yybm[0 + yych] & 16) {
      goto yy747;
    }
    if (yych <= ',') {
      if (yych <= '\r') {
        if (yych <= 0x08)
          goto yy732;
      } else {
        if (yych != ' ')
          goto yy732;
      }
    } else {
      if (yych <= '<') {
        if (yych <= '/')
          goto yy746;
        goto yy732;
      } else {
        if (yych <= '=')
          goto yy751;
        if (yych <= '>')
          goto yy738;
        goto yy732;
      }
    }
  yy749:
    ++p;
    yych = *p;
    if (yych <= '<') {
      if (yych <= ' ') {
        if (yych <= 0x08)
          goto yy732;
        if (yych <= '\r')
          goto yy749;
        if (yych <= 0x1F)
          goto yy732;
        goto yy749;
      } else {
        if (yych <= '/') {
          if (yych <= '.')
            goto yy732;
          goto yy746;
        } else {
          if (yych == ':')
            goto yy747;
          goto yy732;
        }
      }
    } else {
      if (yych <= 'Z') {
        if (yych <= '=')
          goto yy751;
        if (yych <= '>')
          goto yy738;
        if (yych <= '@')
          goto yy732;
        goto yy747;
      } else {
        if (yych <= '_') {
          if (yych <= '^')
            goto yy732;
          goto yy747;
        } else {
          if (yych <= '`')
            goto yy732;
          if (yych <= 'z')
            goto yy747;
          goto yy732;
        }
      }
    }
  yy751:
    ++p;
    yych = *p;
    if (yybm[0 + yych] & 32) {
      goto yy753;
    }
    if (yych <= 0xE0) {
      if (yych <= '"') {
        if (yych <= 0x00)
          goto yy732;
        if (yych >= '!')
          goto yy764;
      } else {
        if (yych <= '\'')
          goto yy762;
        if (yych <= 0xC1)
          goto yy732;
        if (yych <= 0xDF)
          goto yy755;
        goto yy756;
      }
    } else {
      if (yych <= 0xEF) {
        if (yych == 0xED)
          goto yy761;
        goto yy757;
      } else {
        if (yych <= 0xF0)
          goto yy758;
        if (yych <= 0xF3)
          goto yy759;
        if (yych <= 0xF4)
          goto yy760;
        goto yy732;
      }
    }
    ++p;
    yych = *p;
    if (yybm[0 + yych] & 32) {
      goto yy753;
    }
    if (yych <= 0xDF) {
      if (yych <= '\'') {
        if (yych <= 0x00)
          goto yy732;
        if (yych <= ' ')
          goto yy787;
        if (yych <= '"')
          goto yy764;
        goto yy762;
      } else {
        if (yych == '>')
          goto yy738;
        if (yych <= 0xC1)
          goto yy732;
        goto yy755;
      }
    } else {
      if (yych <= 0xEF) {
        if (yych <= 0xE0)
          goto yy756;
        if (yych == 0xED)
          goto yy761;
        goto yy757;
      } else {
        if (yych <= 0xF0)
          goto yy758;
        if (yych <= 0xF3)
          goto yy759;
        if (yych <= 0xF4)
          goto yy760;
        goto yy732;
      }
    }
  yy753:
    ++p;
    yych = *p;
    if (yybm[0 + yych] & 32) {
      goto yy753;
    }
    if (yych <= 0xE0) {
      if (yych <= '=') {
        if (yych <= 0x00)
          goto yy732;
        if (yych <= ' ')
          goto yy781;
        goto yy732;
      } else {
        if (yych <= '>')
          goto yy738;
        if (yych <= 0xC1)
          goto yy732;
        if (yych >= 0xE0)
          goto yy756;
      }
    } else {
      if (yych <= 0xEF) {
        if (yych == 0xED)
          goto yy761;
        goto yy757;
      } else {
        if (yych <= 0xF0)
          goto yy758;
        if (yych <= 0xF3)
          goto yy759;
        if (yych <= 0xF4)
          goto yy760;
        goto yy732;
      }
    }
  yy755:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy732;
    if (yych <= 0xBF)
      goto yy753;
    goto yy732;
  yy756:
    ++p;
    yych = *p;
    if (yych <= 0x9F)
      goto yy732;
    if (yych <= 0xBF)
      goto yy755;
    goto yy732;
  yy757:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy732;
    if (yych <= 0xBF)
      goto yy755;
    goto yy732;
  yy758:
    ++p;
    yych = *p;
    if (yych <= 0x8F)
      goto yy732;
    if (yych <= 0xBF)
      goto yy757;
    goto yy732;
  yy759:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy732;
    if (yych <= 0xBF)
      goto yy757;
    goto yy732;
  yy760:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy732;
    if (yych <= 0x8F)
      goto yy757;
    goto yy732;
  yy761:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy732;
    if (yych <= 0x9F)
      goto yy755;
    goto yy732;
  yy762:
    ++p;
    yych = *p;
    if (yybm[0 + yych] & 64) {
      goto yy762;
    }
    if (yych <= 0xEC) {
      if (yych <= 0xC1) {
        if (yych <= 0x00)
          goto yy732;
        if (yych <= '\'')
          goto yy773;
        goto yy732;
      } else {
        if (yych <= 0xDF)
          goto yy774;
        if (yych <= 0xE0)
          goto yy775;
        goto yy776;
      }
    } else {
      if (yych <= 0xF0) {
        if (yych <= 0xED)
          goto yy780;
        if (yych <= 0xEF)
          goto yy776;
        goto yy777;
      } else {
        if (yych <= 0xF3)
          goto yy778;
        if (yych <= 0xF4)
          goto yy779;
        goto yy732;
      }
    }
  yy764:
    ++p;
    yych = *p;
    if (yybm[0 + yych] & 128) {
      goto yy764;
    }
    if (yych <= 0xEC) {
      if (yych <= 0xC1) {
        if (yych <= 0x00)
          goto yy732;
        if (yych <= '"')
          goto yy773;
        goto yy732;
      } else {
        if (yych <= 0xDF)
          goto yy766;
        if (yych <= 0xE0)
          goto yy767;
        goto yy768;
      }
    } else {
      if (yych <= 0xF0) {
        if (yych <= 0xED)
          goto yy772;
        if (yych <= 0xEF)
          goto yy768;
        goto yy769;
      } else {
        if (yych <= 0xF3)
          goto yy770;
        if (yych <= 0xF4)
          goto yy771;
        goto yy732;
      }
    }
  yy766:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy732;
    if (yych <= 0xBF)
      goto yy764;
    goto yy732;
  yy767:
    ++p;
    yych = *p;
    if (yych <= 0x9F)
      goto yy732;
    if (yych <= 0xBF)
      goto yy766;
    goto yy732;
  yy768:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy732;
    if (yych <= 0xBF)
      goto yy766;
    goto yy732;
  yy769:
    ++p;
    yych = *p;
    if (yych <= 0x8F)
      goto yy732;
    if (yych <= 0xBF)
      goto yy768;
    goto yy732;
  yy770:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy732;
    if (yych <= 0xBF)
      goto yy768;
    goto yy732;
  yy771:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy732;
    if (yych <= 0x8F)
      goto yy768;
    goto yy732;
  yy772:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy732;
    if (yych <= 0x9F)
      goto yy766;
    goto yy732;
  yy773:
    ++p;
    yych = *p;
    if (yych <= ' ') {
      if (yych <= 0x08)
        goto yy732;
      if (yych <= '\r')
        goto yy744;
      if (yych <= 0x1F)
        goto yy732;
      goto yy744;
    } else {
      if (yych <= '/') {
        if (yych <= '.')
          goto yy732;
        goto yy746;
      } else {
        if (yych == '>')
          goto yy738;
        goto yy732;
      }
    }
  yy774:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy732;
    if (yych <= 0xBF)
      goto yy762;
    goto yy732;
  yy775:
    ++p;
    yych = *p;
    if (yych <= 0x9F)
      goto yy732;
    if (yych <= 0xBF)
      goto yy774;
    goto yy732;
  yy776:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy732;
    if (yych <= 0xBF)
      goto yy774;
    goto yy732;
  yy777:
    ++p;
    yych = *p;
    if (yych <= 0x8F)
      goto yy732;
    if (yych <= 0xBF)
      goto yy776;
    goto yy732;
  yy778:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy732;
    if (yych <= 0xBF)
      goto yy776;
    goto yy732;
  yy779:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy732;
    if (yych <= 0x8F)
      goto yy776;
    goto yy732;
  yy780:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy732;
    if (yych <= 0x9F)
      goto yy774;
    goto yy732;
  yy781:
    ++p;
    yych = *p;
    if (yych <= '@') {
      if (yych <= '"') {
        if (yych <= '\r') {
          if (yych <= 0x00)
            goto yy732;
          if (yych <= 0x08)
            goto yy753;
          goto yy781;
        } else {
          if (yych == ' ')
            goto yy781;
          if (yych <= '!')
            goto yy753;
          goto yy732;
        }
      } else {
        if (yych <= ':') {
          if (yych == '\'')
            goto yy732;
          if (yych <= '9')
            goto yy753;
        } else {
          if (yych <= ';')
            goto yy753;
          if (yych <= '=')
            goto yy732;
          if (yych <= '>')
            goto yy738;
          goto yy753;
        }
      }
    } else {
      if (yych <= 0xDF) {
        if (yych <= '`') {
          if (yych <= 'Z')
            goto yy783;
          if (yych <= '^')
            goto yy753;
          if (yych >= '`')
            goto yy732;
        } else {
          if (yych <= 'z')
            goto yy783;
          if (yych <= 0x7F)
            goto yy753;
          if (yych <= 0xC1)
            goto yy732;
          goto yy755;
        }
      } else {
        if (yych <= 0xEF) {
          if (yych <= 0xE0)
            goto yy756;
          if (yych == 0xED)
            goto yy761;
          goto yy757;
        } else {
          if (yych <= 0xF0)
            goto yy758;
          if (yych <= 0xF3)
            goto yy759;
          if (yych <= 0xF4)
            goto yy760;
          goto yy732;
        }
      }
    }
  yy783:
    ++p;
    yych = *p;
    if (yych <= '>') {
      if (yych <= '&') {
        if (yych <= 0x1F) {
          if (yych <= 0x00)
            goto yy732;
          if (yych <= 0x08)
            goto yy753;
          if (yych >= 0x0E)
            goto yy753;
        } else {
          if (yych <= ' ')
            goto yy785;
          if (yych == '"')
            goto yy732;
          goto yy753;
        }
      } else {
        if (yych <= '/') {
          if (yych <= '\'')
            goto yy732;
          if (yych <= ',')
            goto yy753;
          if (yych <= '.')
            goto yy783;
          goto yy753;
        } else {
          if (yych <= ';') {
            if (yych <= ':')
              goto yy783;
            goto yy753;
          } else {
            if (yych <= '<')
              goto yy732;
            if (yych <= '=')
              goto yy751;
            goto yy738;
          }
        }
      }
    } else {
      if (yych <= 0xC1) {
        if (yych <= '_') {
          if (yych <= '@')
            goto yy753;
          if (yych <= 'Z')
            goto yy783;
          if (yych <= '^')
            goto yy753;
          goto yy783;
        } else {
          if (yych <= '`')
            goto yy732;
          if (yych <= 'z')
            goto yy783;
          if (yych <= 0x7F)
            goto yy753;
          goto yy732;
        }
      } else {
        if (yych <= 0xED) {
          if (yych <= 0xDF)
            goto yy755;
          if (yych <= 0xE0)
            goto yy756;
          if (yych <= 0xEC)
            goto yy757;
          goto yy761;
        } else {
          if (yych <= 0xF0) {
            if (yych <= 0xEF)
              goto yy757;
            goto yy758;
          } else {
            if (yych <= 0xF3)
              goto yy759;
            if (yych <= 0xF4)
              goto yy760;
            goto yy732;
          }
        }
      }
    }
  yy785:
    ++p;
    yych = *p;
    if (yych <= '@') {
      if (yych <= '&') {
        if (yych <= 0x1F) {
          if (yych <= 0x00)
            goto yy732;
          if (yych <= 0x08)
            goto yy753;
          if (yych <= '\r')
            goto yy785;
          goto yy753;
        } else {
          if (yych <= ' ')
            goto yy785;
          if (yych == '"')
            goto yy732;
          goto yy753;
        }
      } else {
        if (yych <= ';') {
          if (yych <= '\'')
            goto yy732;
          if (yych == ':')
            goto yy783;
          goto yy753;
        } else {
          if (yych <= '<')
            goto yy732;
          if (yych <= '=')
            goto yy751;
          if (yych <= '>')
            goto yy738;
          goto yy753;
        }
      }
    } else {
      if (yych <= 0xDF) {
        if (yych <= '`') {
          if (yych <= 'Z')
            goto yy783;
          if (yych <= '^')
            goto yy753;
          if (yych <= '_')
            goto yy783;
          goto yy732;
        } else {
          if (yych <= 'z')
            goto yy783;
          if (yych <= 0x7F)
            goto yy753;
          if (yych <= 0xC1)
            goto yy732;
          goto yy755;
        }
      } else {
        if (yych <= 0xEF) {
          if (yych <= 0xE0)
            goto yy756;
          if (yych == 0xED)
            goto yy761;
          goto yy757;
        } else {
          if (yych <= 0xF0)
            goto yy758;
          if (yych <= 0xF3)
            goto yy759;
          if (yych <= 0xF4)
            goto yy760;
          goto yy732;
        }
      }
    }
  yy787:
    ++p;
    yych = *p;
    if (yych <= '@') {
      if (yych <= '"') {
        if (yych <= '\r') {
          if (yych <= 0x00)
            goto yy732;
          if (yych <= 0x08)
            goto yy753;
          goto yy787;
        } else {
          if (yych == ' ')
            goto yy787;
          if (yych <= '!')
            goto yy753;
          goto yy764;
        }
      } else {
        if (yych <= ':') {
          if (yych == '\'')
            goto yy762;
          if (yych <= '9')
            goto yy753;
          goto yy783;
        } else {
          if (yych <= ';')
            goto yy753;
          if (yych <= '=')
            goto yy732;
          if (yych <= '>')
            goto yy738;
          goto yy753;
        }
      }
    } else {
      if (yych <= 0xDF) {
        if (yych <= '`') {
          if (yych <= 'Z')
            goto yy783;
          if (yych <= '^')
            goto yy753;
          if (yych <= '_')
            goto yy783;
          goto yy732;
        } else {
          if (yych <= 'z')
            goto yy783;
          if (yych <= 0x7F)
            goto yy753;
          if (yych <= 0xC1)
            goto yy732;
          goto yy755;
        }
      } else {
        if (yych <= 0xEF) {
          if (yych <= 0xE0)
            goto yy756;
          if (yych == 0xED)
            goto yy761;
          goto yy757;
        } else {
          if (yych <= 0xF0)
            goto yy758;
          if (yych <= 0xF3)
            goto yy759;
          if (yych <= 0xF4)
            goto yy760;
          goto yy732;
        }
      }
    }
  }
}

// Try to match an HTML block end line of type 1
bufsize_t _scan_html_block_end_1(const unsigned char *p) {
  const unsigned char *marker = NULL;
  const unsigned char *start = p;

  {
    unsigned char yych;
    unsigned int yyaccept = 0;
    static const unsigned char yybm[] = {
        0,  64, 64, 64, 64, 64, 64,  64, 64, 64, 0,  64, 64, 64, 64, 64, 64, 64,
        64, 64, 64, 64, 64, 64, 64,  64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64,
        64, 64, 64, 64, 64, 64, 64,  64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64,
        64, 64, 64, 64, 64, 64, 128, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64,
        64, 64, 64, 64, 64, 64, 64,  64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64,
        64, 64, 64, 64, 64, 64, 64,  64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64,
        64, 64, 64, 64, 64, 64, 64,  64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64,
        64, 64, 0,  0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,
    };
    yych = *p;
    if (yych <= 0xDF) {
      if (yych <= ';') {
        if (yych <= 0x00)
          goto yy791;
        if (yych != '\n')
          goto yy793;
      } else {
        if (yych <= '<')
          goto yy794;
        if (yych <= 0x7F)
          goto yy793;
        if (yych >= 0xC2)
          goto yy795;
      }
    } else {
      if (yych <= 0xEF) {
        if (yych <= 0xE0)
          goto yy796;
        if (yych == 0xED)
          goto yy798;
        goto yy797;
      } else {
        if (yych <= 0xF0)
          goto yy799;
        if (yych <= 0xF3)
          goto yy800;
        if (yych <= 0xF4)
          goto yy801;
      }
    }
  yy791:
    ++p;
  yy792 : { return 0; }
  yy793:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= '\n') {
      if (yych <= 0x00)
        goto yy792;
      if (yych <= '\t')
        goto yy806;
      goto yy792;
    } else {
      if (yych <= 0x7F)
        goto yy806;
      if (yych <= 0xC1)
        goto yy792;
      if (yych <= 0xF4)
        goto yy806;
      goto yy792;
    }
  yy794:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= '.') {
      if (yych <= 0x00)
        goto yy792;
      if (yych == '\n')
        goto yy792;
      goto yy806;
    } else {
      if (yych <= 0x7F) {
        if (yych <= '/')
          goto yy814;
        goto yy806;
      } else {
        if (yych <= 0xC1)
          goto yy792;
        if (yych <= 0xF4)
          goto yy806;
        goto yy792;
      }
    }
  yy795:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x7F)
      goto yy792;
    if (yych <= 0xBF)
      goto yy805;
    goto yy792;
  yy796:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x9F)
      goto yy792;
    if (yych <= 0xBF)
      goto yy804;
    goto yy792;
  yy797:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x7F)
      goto yy792;
    if (yych <= 0xBF)
      goto yy804;
    goto yy792;
  yy798:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x7F)
      goto yy792;
    if (yych <= 0x9F)
      goto yy804;
    goto yy792;
  yy799:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x8F)
      goto yy792;
    if (yych <= 0xBF)
      goto yy802;
    goto yy792;
  yy800:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x7F)
      goto yy792;
    if (yych <= 0xBF)
      goto yy802;
    goto yy792;
  yy801:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x7F)
      goto yy792;
    if (yych >= 0x90)
      goto yy792;
  yy802:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy803;
    if (yych <= 0xBF)
      goto yy804;
  yy803:
    p = marker;
    if (yyaccept == 0) {
      goto yy792;
    } else {
      goto yy820;
    }
  yy804:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy803;
    if (yych >= 0xC0)
      goto yy803;
  yy805:
    ++p;
    yych = *p;
  yy806:
    if (yybm[0 + yych] & 64) {
      goto yy805;
    }
    if (yych <= 0xEC) {
      if (yych <= 0xC1) {
        if (yych <= '\n')
          goto yy803;
        if (yych >= '=')
          goto yy803;
      } else {
        if (yych <= 0xDF)
          goto yy804;
        if (yych <= 0xE0)
          goto yy809;
        goto yy802;
      }
    } else {
      if (yych <= 0xF0) {
        if (yych <= 0xED)
          goto yy813;
        if (yych <= 0xEF)
          goto yy802;
        goto yy810;
      } else {
        if (yych <= 0xF3)
          goto yy811;
        if (yych <= 0xF4)
          goto yy812;
        goto yy803;
      }
    }
  yy807:
    ++p;
    yych = *p;
    if (yybm[0 + yych] & 128) {
      goto yy807;
    }
    if (yych <= 0xDF) {
      if (yych <= '.') {
        if (yych <= 0x00)
          goto yy803;
        if (yych == '\n')
          goto yy803;
        goto yy805;
      } else {
        if (yych <= '/')
          goto yy814;
        if (yych <= 0x7F)
          goto yy805;
        if (yych <= 0xC1)
          goto yy803;
        goto yy804;
      }
    } else {
      if (yych <= 0xEF) {
        if (yych <= 0xE0)
          goto yy809;
        if (yych == 0xED)
          goto yy813;
        goto yy802;
      } else {
        if (yych <= 0xF0)
          goto yy810;
        if (yych <= 0xF3)
          goto yy811;
        if (yych <= 0xF4)
          goto yy812;
        goto yy803;
      }
    }
  yy809:
    ++p;
    yych = *p;
    if (yych <= 0x9F)
      goto yy803;
    if (yych <= 0xBF)
      goto yy804;
    goto yy803;
  yy810:
    ++p;
    yych = *p;
    if (yych <= 0x8F)
      goto yy803;
    if (yych <= 0xBF)
      goto yy802;
    goto yy803;
  yy811:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy803;
    if (yych <= 0xBF)
      goto yy802;
    goto yy803;
  yy812:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy803;
    if (yych <= 0x8F)
      goto yy802;
    goto yy803;
  yy813:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy803;
    if (yych <= 0x9F)
      goto yy804;
    goto yy803;
  yy814:
    ++p;
    yych = *p;
    if (yybm[0 + yych] & 128) {
      goto yy807;
    }
    if (yych <= 's') {
      if (yych <= 'P') {
        if (yych <= '\t') {
          if (yych <= 0x00)
            goto yy803;
          goto yy805;
        } else {
          if (yych <= '\n')
            goto yy803;
          if (yych <= 'O')
            goto yy805;
          goto yy816;
        }
      } else {
        if (yych <= 'o') {
          if (yych != 'S')
            goto yy805;
        } else {
          if (yych <= 'p')
            goto yy816;
          if (yych <= 'r')
            goto yy805;
        }
      }
    } else {
      if (yych <= 0xEC) {
        if (yych <= 0xC1) {
          if (yych <= 0x7F)
            goto yy805;
          goto yy803;
        } else {
          if (yych <= 0xDF)
            goto yy804;
          if (yych <= 0xE0)
            goto yy809;
          goto yy802;
        }
      } else {
        if (yych <= 0xF0) {
          if (yych <= 0xED)
            goto yy813;
          if (yych <= 0xEF)
            goto yy802;
          goto yy810;
        } else {
          if (yych <= 0xF3)
            goto yy811;
          if (yych <= 0xF4)
            goto yy812;
          goto yy803;
        }
      }
    }
    ++p;
    yych = *p;
    if (yybm[0 + yych] & 128) {
      goto yy807;
    }
    if (yych <= 't') {
      if (yych <= 'C') {
        if (yych <= '\t') {
          if (yych <= 0x00)
            goto yy803;
          goto yy805;
        } else {
          if (yych <= '\n')
            goto yy803;
          if (yych <= 'B')
            goto yy805;
          goto yy821;
        }
      } else {
        if (yych <= 'b') {
          if (yych == 'T')
            goto yy822;
          goto yy805;
        } else {
          if (yych <= 'c')
            goto yy821;
          if (yych <= 's')
            goto yy805;
          goto yy822;
        }
      }
    } else {
      if (yych <= 0xEC) {
        if (yych <= 0xC1) {
          if (yych <= 0x7F)
            goto yy805;
          goto yy803;
        } else {
          if (yych <= 0xDF)
            goto yy804;
          if (yych <= 0xE0)
            goto yy809;
          goto yy802;
        }
      } else {
        if (yych <= 0xF0) {
          if (yych <= 0xED)
            goto yy813;
          if (yych <= 0xEF)
            goto yy802;
          goto yy810;
        } else {
          if (yych <= 0xF3)
            goto yy811;
          if (yych <= 0xF4)
            goto yy812;
          goto yy803;
        }
      }
    }
  yy816:
    ++p;
    yych = *p;
    if (yybm[0 + yych] & 128) {
      goto yy807;
    }
    if (yych <= 0xC1) {
      if (yych <= 'Q') {
        if (yych <= 0x00)
          goto yy803;
        if (yych == '\n')
          goto yy803;
        goto yy805;
      } else {
        if (yych <= 'q') {
          if (yych >= 'S')
            goto yy805;
        } else {
          if (yych <= 'r')
            goto yy817;
          if (yych <= 0x7F)
            goto yy805;
          goto yy803;
        }
      }
    } else {
      if (yych <= 0xED) {
        if (yych <= 0xDF)
          goto yy804;
        if (yych <= 0xE0)
          goto yy809;
        if (yych <= 0xEC)
          goto yy802;
        goto yy813;
      } else {
        if (yych <= 0xF0) {
          if (yych <= 0xEF)
            goto yy802;
          goto yy810;
        } else {
          if (yych <= 0xF3)
            goto yy811;
          if (yych <= 0xF4)
            goto yy812;
          goto yy803;
        }
      }
    }
  yy817:
    ++p;
    yych = *p;
    if (yybm[0 + yych] & 128) {
      goto yy807;
    }
    if (yych <= 0xC1) {
      if (yych <= 'D') {
        if (yych <= 0x00)
          goto yy803;
        if (yych == '\n')
          goto yy803;
        goto yy805;
      } else {
        if (yych <= 'd') {
          if (yych >= 'F')
            goto yy805;
        } else {
          if (yych <= 'e')
            goto yy818;
          if (yych <= 0x7F)
            goto yy805;
          goto yy803;
        }
      }
    } else {
      if (yych <= 0xED) {
        if (yych <= 0xDF)
          goto yy804;
        if (yych <= 0xE0)
          goto yy809;
        if (yych <= 0xEC)
          goto yy802;
        goto yy813;
      } else {
        if (yych <= 0xF0) {
          if (yych <= 0xEF)
            goto yy802;
          goto yy810;
        } else {
          if (yych <= 0xF3)
            goto yy811;
          if (yych <= 0xF4)
            goto yy812;
          goto yy803;
        }
      }
    }
  yy818:
    ++p;
    yych = *p;
    if (yybm[0 + yych] & 128) {
      goto yy807;
    }
    if (yych <= 0xDF) {
      if (yych <= '=') {
        if (yych <= 0x00)
          goto yy803;
        if (yych == '\n')
          goto yy803;
        goto yy805;
      } else {
        if (yych <= '>')
          goto yy819;
        if (yych <= 0x7F)
          goto yy805;
        if (yych <= 0xC1)
          goto yy803;
        goto yy804;
      }
    } else {
      if (yych <= 0xEF) {
        if (yych <= 0xE0)
          goto yy809;
        if (yych == 0xED)
          goto yy813;
        goto yy802;
      } else {
        if (yych <= 0xF0)
          goto yy810;
        if (yych <= 0xF3)
          goto yy811;
        if (yych <= 0xF4)
          goto yy812;
        goto yy803;
      }
    }
  yy819:
    yyaccept = 1;
    marker = ++p;
    yych = *p;
    if (yybm[0 + yych] & 64) {
      goto yy805;
    }
    if (yych <= 0xEC) {
      if (yych <= 0xC1) {
        if (yych <= '\n')
          goto yy820;
        if (yych <= '<')
          goto yy807;
      } else {
        if (yych <= 0xDF)
          goto yy804;
        if (yych <= 0xE0)
          goto yy809;
        goto yy802;
      }
    } else {
      if (yych <= 0xF0) {
        if (yych <= 0xED)
          goto yy813;
        if (yych <= 0xEF)
          goto yy802;
        goto yy810;
      } else {
        if (yych <= 0xF3)
          goto yy811;
        if (yych <= 0xF4)
          goto yy812;
      }
    }
  yy820 : { return (bufsize_t)(p - start); }
  yy821:
    ++p;
    yych = *p;
    if (yybm[0 + yych] & 128) {
      goto yy807;
    }
    if (yych <= 0xC1) {
      if (yych <= 'Q') {
        if (yych <= 0x00)
          goto yy803;
        if (yych == '\n')
          goto yy803;
        goto yy805;
      } else {
        if (yych <= 'q') {
          if (yych <= 'R')
            goto yy825;
          goto yy805;
        } else {
          if (yych <= 'r')
            goto yy825;
          if (yych <= 0x7F)
            goto yy805;
          goto yy803;
        }
      }
    } else {
      if (yych <= 0xED) {
        if (yych <= 0xDF)
          goto yy804;
        if (yych <= 0xE0)
          goto yy809;
        if (yych <= 0xEC)
          goto yy802;
        goto yy813;
      } else {
        if (yych <= 0xF0) {
          if (yych <= 0xEF)
            goto yy802;
          goto yy810;
        } else {
          if (yych <= 0xF3)
            goto yy811;
          if (yych <= 0xF4)
            goto yy812;
          goto yy803;
        }
      }
    }
  yy822:
    ++p;
    yych = *p;
    if (yybm[0 + yych] & 128) {
      goto yy807;
    }
    if (yych <= 0xC1) {
      if (yych <= 'X') {
        if (yych <= 0x00)
          goto yy803;
        if (yych == '\n')
          goto yy803;
        goto yy805;
      } else {
        if (yych <= 'x') {
          if (yych >= 'Z')
            goto yy805;
        } else {
          if (yych <= 'y')
            goto yy823;
          if (yych <= 0x7F)
            goto yy805;
          goto yy803;
        }
      }
    } else {
      if (yych <= 0xED) {
        if (yych <= 0xDF)
          goto yy804;
        if (yych <= 0xE0)
          goto yy809;
        if (yych <= 0xEC)
          goto yy802;
        goto yy813;
      } else {
        if (yych <= 0xF0) {
          if (yych <= 0xEF)
            goto yy802;
          goto yy810;
        } else {
          if (yych <= 0xF3)
            goto yy811;
          if (yych <= 0xF4)
            goto yy812;
          goto yy803;
        }
      }
    }
  yy823:
    ++p;
    yych = *p;
    if (yybm[0 + yych] & 128) {
      goto yy807;
    }
    if (yych <= 0xC1) {
      if (yych <= 'K') {
        if (yych <= 0x00)
          goto yy803;
        if (yych == '\n')
          goto yy803;
        goto yy805;
      } else {
        if (yych <= 'k') {
          if (yych >= 'M')
            goto yy805;
        } else {
          if (yych <= 'l')
            goto yy824;
          if (yych <= 0x7F)
            goto yy805;
          goto yy803;
        }
      }
    } else {
      if (yych <= 0xED) {
        if (yych <= 0xDF)
          goto yy804;
        if (yych <= 0xE0)
          goto yy809;
        if (yych <= 0xEC)
          goto yy802;
        goto yy813;
      } else {
        if (yych <= 0xF0) {
          if (yych <= 0xEF)
            goto yy802;
          goto yy810;
        } else {
          if (yych <= 0xF3)
            goto yy811;
          if (yych <= 0xF4)
            goto yy812;
          goto yy803;
        }
      }
    }
  yy824:
    ++p;
    yych = *p;
    if (yybm[0 + yych] & 128) {
      goto yy807;
    }
    if (yych <= 0xC1) {
      if (yych <= 'D') {
        if (yych <= 0x00)
          goto yy803;
        if (yych == '\n')
          goto yy803;
        goto yy805;
      } else {
        if (yych <= 'd') {
          if (yych <= 'E')
            goto yy818;
          goto yy805;
        } else {
          if (yych <= 'e')
            goto yy818;
          if (yych <= 0x7F)
            goto yy805;
          goto yy803;
        }
      }
    } else {
      if (yych <= 0xED) {
        if (yych <= 0xDF)
          goto yy804;
        if (yych <= 0xE0)
          goto yy809;
        if (yych <= 0xEC)
          goto yy802;
        goto yy813;
      } else {
        if (yych <= 0xF0) {
          if (yych <= 0xEF)
            goto yy802;
          goto yy810;
        } else {
          if (yych <= 0xF3)
            goto yy811;
          if (yych <= 0xF4)
            goto yy812;
          goto yy803;
        }
      }
    }
  yy825:
    ++p;
    yych = *p;
    if (yybm[0 + yych] & 128) {
      goto yy807;
    }
    if (yych <= 0xC1) {
      if (yych <= 'H') {
        if (yych <= 0x00)
          goto yy803;
        if (yych == '\n')
          goto yy803;
        goto yy805;
      } else {
        if (yych <= 'h') {
          if (yych >= 'J')
            goto yy805;
        } else {
          if (yych <= 'i')
            goto yy826;
          if (yych <= 0x7F)
            goto yy805;
          goto yy803;
        }
      }
    } else {
      if (yych <= 0xED) {
        if (yych <= 0xDF)
          goto yy804;
        if (yych <= 0xE0)
          goto yy809;
        if (yych <= 0xEC)
          goto yy802;
        goto yy813;
      } else {
        if (yych <= 0xF0) {
          if (yych <= 0xEF)
            goto yy802;
          goto yy810;
        } else {
          if (yych <= 0xF3)
            goto yy811;
          if (yych <= 0xF4)
            goto yy812;
          goto yy803;
        }
      }
    }
  yy826:
    ++p;
    yych = *p;
    if (yybm[0 + yych] & 128) {
      goto yy807;
    }
    if (yych <= 0xC1) {
      if (yych <= 'O') {
        if (yych <= 0x00)
          goto yy803;
        if (yych == '\n')
          goto yy803;
        goto yy805;
      } else {
        if (yych <= 'o') {
          if (yych >= 'Q')
            goto yy805;
        } else {
          if (yych <= 'p')
            goto yy827;
          if (yych <= 0x7F)
            goto yy805;
          goto yy803;
        }
      }
    } else {
      if (yych <= 0xED) {
        if (yych <= 0xDF)
          goto yy804;
        if (yych <= 0xE0)
          goto yy809;
        if (yych <= 0xEC)
          goto yy802;
        goto yy813;
      } else {
        if (yych <= 0xF0) {
          if (yych <= 0xEF)
            goto yy802;
          goto yy810;
        } else {
          if (yych <= 0xF3)
            goto yy811;
          if (yych <= 0xF4)
            goto yy812;
          goto yy803;
        }
      }
    }
  yy827:
    ++p;
    yych = *p;
    if (yybm[0 + yych] & 128) {
      goto yy807;
    }
    if (yych <= 0xC1) {
      if (yych <= 'S') {
        if (yych <= 0x00)
          goto yy803;
        if (yych == '\n')
          goto yy803;
        goto yy805;
      } else {
        if (yych <= 's') {
          if (yych <= 'T')
            goto yy818;
          goto yy805;
        } else {
          if (yych <= 't')
            goto yy818;
          if (yych <= 0x7F)
            goto yy805;
          goto yy803;
        }
      }
    } else {
      if (yych <= 0xED) {
        if (yych <= 0xDF)
          goto yy804;
        if (yych <= 0xE0)
          goto yy809;
        if (yych <= 0xEC)
          goto yy802;
        goto yy813;
      } else {
        if (yych <= 0xF0) {
          if (yych <= 0xEF)
            goto yy802;
          goto yy810;
        } else {
          if (yych <= 0xF3)
            goto yy811;
          if (yych <= 0xF4)
            goto yy812;
          goto yy803;
        }
      }
    }
  }
}

// Try to match an HTML block end line of type 2
bufsize_t _scan_html_block_end_2(const unsigned char *p) {
  const unsigned char *marker = NULL;
  const unsigned char *start = p;

  {
    unsigned char yych;
    unsigned int yyaccept = 0;
    static const unsigned char yybm[] = {
        0,  64, 64, 64, 64, 64, 64, 64, 64, 64,  0,  64, 64, 64, 64, 64, 64, 64,
        64, 64, 64, 64, 64, 64, 64, 64, 64, 64,  64, 64, 64, 64, 64, 64, 64, 64,
        64, 64, 64, 64, 64, 64, 64, 64, 64, 128, 64, 64, 64, 64, 64, 64, 64, 64,
        64, 64, 64, 64, 64, 64, 64, 64, 64, 64,  64, 64, 64, 64, 64, 64, 64, 64,
        64, 64, 64, 64, 64, 64, 64, 64, 64, 64,  64, 64, 64, 64, 64, 64, 64, 64,
        64, 64, 64, 64, 64, 64, 64, 64, 64, 64,  64, 64, 64, 64, 64, 64, 64, 64,
        64, 64, 64, 64, 64, 64, 64, 64, 64, 64,  64, 64, 64, 64, 64, 64, 64, 64,
        64, 64, 0,  0,  0,  0,  0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,  0,  0,  0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,  0,  0,  0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,  0,  0,  0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,  0,  0,  0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,  0,  0,  0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,  0,  0,  0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,
    };
    yych = *p;
    if (yych <= 0xDF) {
      if (yych <= ',') {
        if (yych <= 0x00)
          goto yy830;
        if (yych != '\n')
          goto yy832;
      } else {
        if (yych <= '-')
          goto yy833;
        if (yych <= 0x7F)
          goto yy832;
        if (yych >= 0xC2)
          goto yy834;
      }
    } else {
      if (yych <= 0xEF) {
        if (yych <= 0xE0)
          goto yy835;
        if (yych == 0xED)
          goto yy837;
        goto yy836;
      } else {
        if (yych <= 0xF0)
          goto yy838;
        if (yych <= 0xF3)
          goto yy839;
        if (yych <= 0xF4)
          goto yy840;
      }
    }
  yy830:
    ++p;
  yy831 : { return 0; }
  yy832:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= '\n') {
      if (yych <= 0x00)
        goto yy831;
      if (yych <= '\t')
        goto yy845;
      goto yy831;
    } else {
      if (yych <= 0x7F)
        goto yy845;
      if (yych <= 0xC1)
        goto yy831;
      if (yych <= 0xF4)
        goto yy845;
      goto yy831;
    }
  yy833:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yybm[0 + yych] & 128) {
      goto yy852;
    }
    if (yych <= '\n') {
      if (yych <= 0x00)
        goto yy831;
      if (yych <= '\t')
        goto yy845;
      goto yy831;
    } else {
      if (yych <= 0x7F)
        goto yy845;
      if (yych <= 0xC1)
        goto yy831;
      if (yych <= 0xF4)
        goto yy845;
      goto yy831;
    }
  yy834:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x7F)
      goto yy831;
    if (yych <= 0xBF)
      goto yy844;
    goto yy831;
  yy835:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x9F)
      goto yy831;
    if (yych <= 0xBF)
      goto yy843;
    goto yy831;
  yy836:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x7F)
      goto yy831;
    if (yych <= 0xBF)
      goto yy843;
    goto yy831;
  yy837:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x7F)
      goto yy831;
    if (yych <= 0x9F)
      goto yy843;
    goto yy831;
  yy838:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x8F)
      goto yy831;
    if (yych <= 0xBF)
      goto yy841;
    goto yy831;
  yy839:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x7F)
      goto yy831;
    if (yych <= 0xBF)
      goto yy841;
    goto yy831;
  yy840:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x7F)
      goto yy831;
    if (yych >= 0x90)
      goto yy831;
  yy841:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy842;
    if (yych <= 0xBF)
      goto yy843;
  yy842:
    p = marker;
    if (yyaccept == 0) {
      goto yy831;
    } else {
      goto yy855;
    }
  yy843:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy842;
    if (yych >= 0xC0)
      goto yy842;
  yy844:
    ++p;
    yych = *p;
  yy845:
    if (yybm[0 + yych] & 64) {
      goto yy844;
    }
    if (yych <= 0xEC) {
      if (yych <= 0xC1) {
        if (yych <= '\n')
          goto yy842;
        if (yych >= '.')
          goto yy842;
      } else {
        if (yych <= 0xDF)
          goto yy843;
        if (yych <= 0xE0)
          goto yy847;
        goto yy841;
      }
    } else {
      if (yych <= 0xF0) {
        if (yych <= 0xED)
          goto yy851;
        if (yych <= 0xEF)
          goto yy841;
        goto yy848;
      } else {
        if (yych <= 0xF3)
          goto yy849;
        if (yych <= 0xF4)
          goto yy850;
        goto yy842;
      }
    }
  yy846:
    ++p;
    yych = *p;
    if (yybm[0 + yych] & 64) {
      goto yy844;
    }
    if (yych <= 0xEC) {
      if (yych <= 0xC1) {
        if (yych <= '\n')
          goto yy842;
        if (yych <= '-')
          goto yy852;
        goto yy842;
      } else {
        if (yych <= 0xDF)
          goto yy843;
        if (yych >= 0xE1)
          goto yy841;
      }
    } else {
      if (yych <= 0xF0) {
        if (yych <= 0xED)
          goto yy851;
        if (yych <= 0xEF)
          goto yy841;
        goto yy848;
      } else {
        if (yych <= 0xF3)
          goto yy849;
        if (yych <= 0xF4)
          goto yy850;
        goto yy842;
      }
    }
  yy847:
    ++p;
    yych = *p;
    if (yych <= 0x9F)
      goto yy842;
    if (yych <= 0xBF)
      goto yy843;
    goto yy842;
  yy848:
    ++p;
    yych = *p;
    if (yych <= 0x8F)
      goto yy842;
    if (yych <= 0xBF)
      goto yy841;
    goto yy842;
  yy849:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy842;
    if (yych <= 0xBF)
      goto yy841;
    goto yy842;
  yy850:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy842;
    if (yych <= 0x8F)
      goto yy841;
    goto yy842;
  yy851:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy842;
    if (yych <= 0x9F)
      goto yy843;
    goto yy842;
  yy852:
    ++p;
    yych = *p;
    if (yybm[0 + yych] & 128) {
      goto yy852;
    }
    if (yych <= 0xDF) {
      if (yych <= '=') {
        if (yych <= 0x00)
          goto yy842;
        if (yych == '\n')
          goto yy842;
        goto yy844;
      } else {
        if (yych <= '>')
          goto yy854;
        if (yych <= 0x7F)
          goto yy844;
        if (yych <= 0xC1)
          goto yy842;
        goto yy843;
      }
    } else {
      if (yych <= 0xEF) {
        if (yych <= 0xE0)
          goto yy847;
        if (yych == 0xED)
          goto yy851;
        goto yy841;
      } else {
        if (yych <= 0xF0)
          goto yy848;
        if (yych <= 0xF3)
          goto yy849;
        if (yych <= 0xF4)
          goto yy850;
        goto yy842;
      }
    }
  yy854:
    yyaccept = 1;
    marker = ++p;
    yych = *p;
    if (yybm[0 + yych] & 64) {
      goto yy844;
    }
    if (yych <= 0xEC) {
      if (yych <= 0xC1) {
        if (yych <= '\n')
          goto yy855;
        if (yych <= '-')
          goto yy846;
      } else {
        if (yych <= 0xDF)
          goto yy843;
        if (yych <= 0xE0)
          goto yy847;
        goto yy841;
      }
    } else {
      if (yych <= 0xF0) {
        if (yych <= 0xED)
          goto yy851;
        if (yych <= 0xEF)
          goto yy841;
        goto yy848;
      } else {
        if (yych <= 0xF3)
          goto yy849;
        if (yych <= 0xF4)
          goto yy850;
      }
    }
  yy855 : { return (bufsize_t)(p - start); }
  }
}

// Try to match an HTML block end line of type 3
bufsize_t _scan_html_block_end_3(const unsigned char *p) {
  const unsigned char *marker = NULL;
  const unsigned char *start = p;

  {
    unsigned char yych;
    unsigned int yyaccept = 0;
    static const unsigned char yybm[] = {
        0,  64, 64, 64, 64, 64, 64, 64, 64, 64,  0,  64, 64, 64, 64, 64, 64, 64,
        64, 64, 64, 64, 64, 64, 64, 64, 64, 64,  64, 64, 64, 64, 64, 64, 64, 64,
        64, 64, 64, 64, 64, 64, 64, 64, 64, 64,  64, 64, 64, 64, 64, 64, 64, 64,
        64, 64, 64, 64, 64, 64, 64, 64, 64, 128, 64, 64, 64, 64, 64, 64, 64, 64,
        64, 64, 64, 64, 64, 64, 64, 64, 64, 64,  64, 64, 64, 64, 64, 64, 64, 64,
        64, 64, 64, 64, 64, 64, 64, 64, 64, 64,  64, 64, 64, 64, 64, 64, 64, 64,
        64, 64, 64, 64, 64, 64, 64, 64, 64, 64,  64, 64, 64, 64, 64, 64, 64, 64,
        64, 64, 0,  0,  0,  0,  0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,  0,  0,  0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,  0,  0,  0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,  0,  0,  0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,  0,  0,  0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,  0,  0,  0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,  0,  0,  0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,
    };
    yych = *p;
    if (yych <= 0xDF) {
      if (yych <= '>') {
        if (yych <= 0x00)
          goto yy858;
        if (yych != '\n')
          goto yy860;
      } else {
        if (yych <= '?')
          goto yy861;
        if (yych <= 0x7F)
          goto yy860;
        if (yych >= 0xC2)
          goto yy862;
      }
    } else {
      if (yych <= 0xEF) {
        if (yych <= 0xE0)
          goto yy863;
        if (yych == 0xED)
          goto yy865;
        goto yy864;
      } else {
        if (yych <= 0xF0)
          goto yy866;
        if (yych <= 0xF3)
          goto yy867;
        if (yych <= 0xF4)
          goto yy868;
      }
    }
  yy858:
    ++p;
  yy859 : { return 0; }
  yy860:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= '\n') {
      if (yych <= 0x00)
        goto yy859;
      if (yych <= '\t')
        goto yy873;
      goto yy859;
    } else {
      if (yych <= 0x7F)
        goto yy873;
      if (yych <= 0xC1)
        goto yy859;
      if (yych <= 0xF4)
        goto yy873;
      goto yy859;
    }
  yy861:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= '=') {
      if (yych <= 0x00)
        goto yy859;
      if (yych == '\n')
        goto yy859;
      goto yy873;
    } else {
      if (yych <= 0x7F) {
        if (yych <= '>')
          goto yy881;
        goto yy873;
      } else {
        if (yych <= 0xC1)
          goto yy859;
        if (yych <= 0xF4)
          goto yy873;
        goto yy859;
      }
    }
  yy862:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x7F)
      goto yy859;
    if (yych <= 0xBF)
      goto yy872;
    goto yy859;
  yy863:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x9F)
      goto yy859;
    if (yych <= 0xBF)
      goto yy871;
    goto yy859;
  yy864:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x7F)
      goto yy859;
    if (yych <= 0xBF)
      goto yy871;
    goto yy859;
  yy865:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x7F)
      goto yy859;
    if (yych <= 0x9F)
      goto yy871;
    goto yy859;
  yy866:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x8F)
      goto yy859;
    if (yych <= 0xBF)
      goto yy869;
    goto yy859;
  yy867:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x7F)
      goto yy859;
    if (yych <= 0xBF)
      goto yy869;
    goto yy859;
  yy868:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x7F)
      goto yy859;
    if (yych >= 0x90)
      goto yy859;
  yy869:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy870;
    if (yych <= 0xBF)
      goto yy871;
  yy870:
    p = marker;
    if (yyaccept == 0) {
      goto yy859;
    } else {
      goto yy882;
    }
  yy871:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy870;
    if (yych >= 0xC0)
      goto yy870;
  yy872:
    ++p;
    yych = *p;
  yy873:
    if (yybm[0 + yych] & 64) {
      goto yy872;
    }
    if (yych <= 0xEC) {
      if (yych <= 0xC1) {
        if (yych <= '\n')
          goto yy870;
        if (yych >= '@')
          goto yy870;
      } else {
        if (yych <= 0xDF)
          goto yy871;
        if (yych <= 0xE0)
          goto yy876;
        goto yy869;
      }
    } else {
      if (yych <= 0xF0) {
        if (yych <= 0xED)
          goto yy880;
        if (yych <= 0xEF)
          goto yy869;
        goto yy877;
      } else {
        if (yych <= 0xF3)
          goto yy878;
        if (yych <= 0xF4)
          goto yy879;
        goto yy870;
      }
    }
  yy874:
    ++p;
    yych = *p;
    if (yybm[0 + yych] & 128) {
      goto yy874;
    }
    if (yych <= 0xDF) {
      if (yych <= '=') {
        if (yych <= 0x00)
          goto yy870;
        if (yych == '\n')
          goto yy870;
        goto yy872;
      } else {
        if (yych <= '>')
          goto yy881;
        if (yych <= 0x7F)
          goto yy872;
        if (yych <= 0xC1)
          goto yy870;
        goto yy871;
      }
    } else {
      if (yych <= 0xEF) {
        if (yych <= 0xE0)
          goto yy876;
        if (yych == 0xED)
          goto yy880;
        goto yy869;
      } else {
        if (yych <= 0xF0)
          goto yy877;
        if (yych <= 0xF3)
          goto yy878;
        if (yych <= 0xF4)
          goto yy879;
        goto yy870;
      }
    }
  yy876:
    ++p;
    yych = *p;
    if (yych <= 0x9F)
      goto yy870;
    if (yych <= 0xBF)
      goto yy871;
    goto yy870;
  yy877:
    ++p;
    yych = *p;
    if (yych <= 0x8F)
      goto yy870;
    if (yych <= 0xBF)
      goto yy869;
    goto yy870;
  yy878:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy870;
    if (yych <= 0xBF)
      goto yy869;
    goto yy870;
  yy879:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy870;
    if (yych <= 0x8F)
      goto yy869;
    goto yy870;
  yy880:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy870;
    if (yych <= 0x9F)
      goto yy871;
    goto yy870;
  yy881:
    yyaccept = 1;
    marker = ++p;
    yych = *p;
    if (yybm[0 + yych] & 64) {
      goto yy872;
    }
    if (yych <= 0xEC) {
      if (yych <= 0xC1) {
        if (yych <= '\n')
          goto yy882;
        if (yych <= '?')
          goto yy874;
      } else {
        if (yych <= 0xDF)
          goto yy871;
        if (yych <= 0xE0)
          goto yy876;
        goto yy869;
      }
    } else {
      if (yych <= 0xF0) {
        if (yych <= 0xED)
          goto yy880;
        if (yych <= 0xEF)
          goto yy869;
        goto yy877;
      } else {
        if (yych <= 0xF3)
          goto yy878;
        if (yych <= 0xF4)
          goto yy879;
      }
    }
  yy882 : { return (bufsize_t)(p - start); }
  }
}

// Try to match an HTML block end line of type 4
bufsize_t _scan_html_block_end_4(const unsigned char *p) {
  const unsigned char *marker = NULL;
  const unsigned char *start = p;

  {
    unsigned char yych;
    unsigned int yyaccept = 0;
    static const unsigned char yybm[] = {
        0,  64, 64, 64, 64, 64, 64, 64, 64,  64, 0,  64, 64, 64, 64, 64, 64, 64,
        64, 64, 64, 64, 64, 64, 64, 64, 64,  64, 64, 64, 64, 64, 64, 64, 64, 64,
        64, 64, 64, 64, 64, 64, 64, 64, 64,  64, 64, 64, 64, 64, 64, 64, 64, 64,
        64, 64, 64, 64, 64, 64, 64, 64, 128, 64, 64, 64, 64, 64, 64, 64, 64, 64,
        64, 64, 64, 64, 64, 64, 64, 64, 64,  64, 64, 64, 64, 64, 64, 64, 64, 64,
        64, 64, 64, 64, 64, 64, 64, 64, 64,  64, 64, 64, 64, 64, 64, 64, 64, 64,
        64, 64, 64, 64, 64, 64, 64, 64, 64,  64, 64, 64, 64, 64, 64, 64, 64, 64,
        64, 64, 0,  0,  0,  0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,  0,  0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,  0,  0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,  0,  0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,  0,  0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,  0,  0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,  0,  0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,
    };
    yych = *p;
    if (yych <= 0xDF) {
      if (yych <= '=') {
        if (yych <= 0x00)
          goto yy885;
        if (yych != '\n')
          goto yy887;
      } else {
        if (yych <= '>')
          goto yy888;
        if (yych <= 0x7F)
          goto yy887;
        if (yych >= 0xC2)
          goto yy890;
      }
    } else {
      if (yych <= 0xEF) {
        if (yych <= 0xE0)
          goto yy891;
        if (yych == 0xED)
          goto yy893;
        goto yy892;
      } else {
        if (yych <= 0xF0)
          goto yy894;
        if (yych <= 0xF3)
          goto yy895;
        if (yych <= 0xF4)
          goto yy896;
      }
    }
  yy885:
    ++p;
  yy886 : { return 0; }
  yy887:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= '\n') {
      if (yych <= 0x00)
        goto yy886;
      if (yych <= '\t')
        goto yy901;
      goto yy886;
    } else {
      if (yych <= 0x7F)
        goto yy901;
      if (yych <= 0xC1)
        goto yy886;
      if (yych <= 0xF4)
        goto yy901;
      goto yy886;
    }
  yy888:
    yyaccept = 1;
    yych = *(marker = ++p);
    if (yych <= '\n') {
      if (yych <= 0x00)
        goto yy889;
      if (yych <= '\t')
        goto yy901;
    } else {
      if (yych <= 0x7F)
        goto yy901;
      if (yych <= 0xC1)
        goto yy889;
      if (yych <= 0xF4)
        goto yy901;
    }
  yy889 : { return (bufsize_t)(p - start); }
  yy890:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x7F)
      goto yy886;
    if (yych <= 0xBF)
      goto yy900;
    goto yy886;
  yy891:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x9F)
      goto yy886;
    if (yych <= 0xBF)
      goto yy899;
    goto yy886;
  yy892:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x7F)
      goto yy886;
    if (yych <= 0xBF)
      goto yy899;
    goto yy886;
  yy893:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x7F)
      goto yy886;
    if (yych <= 0x9F)
      goto yy899;
    goto yy886;
  yy894:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x8F)
      goto yy886;
    if (yych <= 0xBF)
      goto yy897;
    goto yy886;
  yy895:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x7F)
      goto yy886;
    if (yych <= 0xBF)
      goto yy897;
    goto yy886;
  yy896:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x7F)
      goto yy886;
    if (yych >= 0x90)
      goto yy886;
  yy897:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy898;
    if (yych <= 0xBF)
      goto yy899;
  yy898:
    p = marker;
    if (yyaccept == 0) {
      goto yy886;
    } else {
      goto yy889;
    }
  yy899:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy898;
    if (yych >= 0xC0)
      goto yy898;
  yy900:
    ++p;
    yych = *p;
  yy901:
    if (yybm[0 + yych] & 64) {
      goto yy900;
    }
    if (yych <= 0xEC) {
      if (yych <= 0xC1) {
        if (yych <= '\n')
          goto yy898;
        if (yych >= '?')
          goto yy898;
      } else {
        if (yych <= 0xDF)
          goto yy899;
        if (yych <= 0xE0)
          goto yy904;
        goto yy897;
      }
    } else {
      if (yych <= 0xF0) {
        if (yych <= 0xED)
          goto yy908;
        if (yych <= 0xEF)
          goto yy897;
        goto yy905;
      } else {
        if (yych <= 0xF3)
          goto yy906;
        if (yych <= 0xF4)
          goto yy907;
        goto yy898;
      }
    }
  yy902:
    yyaccept = 1;
    marker = ++p;
    yych = *p;
    if (yybm[0 + yych] & 64) {
      goto yy900;
    }
    if (yych <= 0xEC) {
      if (yych <= 0xC1) {
        if (yych <= '\n')
          goto yy889;
        if (yych <= '>')
          goto yy902;
        goto yy889;
      } else {
        if (yych <= 0xDF)
          goto yy899;
        if (yych >= 0xE1)
          goto yy897;
      }
    } else {
      if (yych <= 0xF0) {
        if (yych <= 0xED)
          goto yy908;
        if (yych <= 0xEF)
          goto yy897;
        goto yy905;
      } else {
        if (yych <= 0xF3)
          goto yy906;
        if (yych <= 0xF4)
          goto yy907;
        goto yy889;
      }
    }
  yy904:
    ++p;
    yych = *p;
    if (yych <= 0x9F)
      goto yy898;
    if (yych <= 0xBF)
      goto yy899;
    goto yy898;
  yy905:
    ++p;
    yych = *p;
    if (yych <= 0x8F)
      goto yy898;
    if (yych <= 0xBF)
      goto yy897;
    goto yy898;
  yy906:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy898;
    if (yych <= 0xBF)
      goto yy897;
    goto yy898;
  yy907:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy898;
    if (yych <= 0x8F)
      goto yy897;
    goto yy898;
  yy908:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy898;
    if (yych <= 0x9F)
      goto yy899;
    goto yy898;
  }
}

// Try to match an HTML block end line of type 5
bufsize_t _scan_html_block_end_5(const unsigned char *p) {
  const unsigned char *marker = NULL;
  const unsigned char *start = p;

  {
    unsigned char yych;
    unsigned int yyaccept = 0;
    static const unsigned char yybm[] = {
        0,  64, 64, 64,  64, 64, 64, 64, 64, 64, 0,  64, 64, 64, 64, 64, 64, 64,
        64, 64, 64, 64,  64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64,
        64, 64, 64, 64,  64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64,
        64, 64, 64, 64,  64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64,
        64, 64, 64, 64,  64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64,
        64, 64, 64, 128, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64,
        64, 64, 64, 64,  64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64,
        64, 64, 0,  0,   0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,   0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,
        0,  0,  0,  0,
    };
    yych = *p;
    if (yych <= 0xDF) {
      if (yych <= '\\') {
        if (yych <= 0x00)
          goto yy911;
        if (yych != '\n')
          goto yy913;
      } else {
        if (yych <= ']')
          goto yy914;
        if (yych <= 0x7F)
          goto yy913;
        if (yych >= 0xC2)
          goto yy915;
      }
    } else {
      if (yych <= 0xEF) {
        if (yych <= 0xE0)
          goto yy916;
        if (yych == 0xED)
          goto yy918;
        goto yy917;
      } else {
        if (yych <= 0xF0)
          goto yy919;
        if (yych <= 0xF3)
          goto yy920;
        if (yych <= 0xF4)
          goto yy921;
      }
    }
  yy911:
    ++p;
  yy912 : { return 0; }
  yy913:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= '\n') {
      if (yych <= 0x00)
        goto yy912;
      if (yych <= '\t')
        goto yy926;
      goto yy912;
    } else {
      if (yych <= 0x7F)
        goto yy926;
      if (yych <= 0xC1)
        goto yy912;
      if (yych <= 0xF4)
        goto yy926;
      goto yy912;
    }
  yy914:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yybm[0 + yych] & 128) {
      goto yy933;
    }
    if (yych <= '\n') {
      if (yych <= 0x00)
        goto yy912;
      if (yych <= '\t')
        goto yy926;
      goto yy912;
    } else {
      if (yych <= 0x7F)
        goto yy926;
      if (yych <= 0xC1)
        goto yy912;
      if (yych <= 0xF4)
        goto yy926;
      goto yy912;
    }
  yy915:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x7F)
      goto yy912;
    if (yych <= 0xBF)
      goto yy925;
    goto yy912;
  yy916:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x9F)
      goto yy912;
    if (yych <= 0xBF)
      goto yy924;
    goto yy912;
  yy917:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x7F)
      goto yy912;
    if (yych <= 0xBF)
      goto yy924;
    goto yy912;
  yy918:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x7F)
      goto yy912;
    if (yych <= 0x9F)
      goto yy924;
    goto yy912;
  yy919:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x8F)
      goto yy912;
    if (yych <= 0xBF)
      goto yy922;
    goto yy912;
  yy920:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x7F)
      goto yy912;
    if (yych <= 0xBF)
      goto yy922;
    goto yy912;
  yy921:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x7F)
      goto yy912;
    if (yych >= 0x90)
      goto yy912;
  yy922:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy923;
    if (yych <= 0xBF)
      goto yy924;
  yy923:
    p = marker;
    if (yyaccept == 0) {
      goto yy912;
    } else {
      goto yy936;
    }
  yy924:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy923;
    if (yych >= 0xC0)
      goto yy923;
  yy925:
    ++p;
    yych = *p;
  yy926:
    if (yybm[0 + yych] & 64) {
      goto yy925;
    }
    if (yych <= 0xEC) {
      if (yych <= 0xC1) {
        if (yych <= '\n')
          goto yy923;
        if (yych >= '^')
          goto yy923;
      } else {
        if (yych <= 0xDF)
          goto yy924;
        if (yych <= 0xE0)
          goto yy928;
        goto yy922;
      }
    } else {
      if (yych <= 0xF0) {
        if (yych <= 0xED)
          goto yy932;
        if (yych <= 0xEF)
          goto yy922;
        goto yy929;
      } else {
        if (yych <= 0xF3)
          goto yy930;
        if (yych <= 0xF4)
          goto yy931;
        goto yy923;
      }
    }
  yy927:
    ++p;
    yych = *p;
    if (yybm[0 + yych] & 64) {
      goto yy925;
    }
    if (yych <= 0xEC) {
      if (yych <= 0xC1) {
        if (yych <= '\n')
          goto yy923;
        if (yych <= ']')
          goto yy933;
        goto yy923;
      } else {
        if (yych <= 0xDF)
          goto yy924;
        if (yych >= 0xE1)
          goto yy922;
      }
    } else {
      if (yych <= 0xF0) {
        if (yych <= 0xED)
          goto yy932;
        if (yych <= 0xEF)
          goto yy922;
        goto yy929;
      } else {
        if (yych <= 0xF3)
          goto yy930;
        if (yych <= 0xF4)
          goto yy931;
        goto yy923;
      }
    }
  yy928:
    ++p;
    yych = *p;
    if (yych <= 0x9F)
      goto yy923;
    if (yych <= 0xBF)
      goto yy924;
    goto yy923;
  yy929:
    ++p;
    yych = *p;
    if (yych <= 0x8F)
      goto yy923;
    if (yych <= 0xBF)
      goto yy922;
    goto yy923;
  yy930:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy923;
    if (yych <= 0xBF)
      goto yy922;
    goto yy923;
  yy931:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy923;
    if (yych <= 0x8F)
      goto yy922;
    goto yy923;
  yy932:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy923;
    if (yych <= 0x9F)
      goto yy924;
    goto yy923;
  yy933:
    ++p;
    yych = *p;
    if (yybm[0 + yych] & 128) {
      goto yy933;
    }
    if (yych <= 0xDF) {
      if (yych <= '=') {
        if (yych <= 0x00)
          goto yy923;
        if (yych == '\n')
          goto yy923;
        goto yy925;
      } else {
        if (yych <= '>')
          goto yy935;
        if (yych <= 0x7F)
          goto yy925;
        if (yych <= 0xC1)
          goto yy923;
        goto yy924;
      }
    } else {
      if (yych <= 0xEF) {
        if (yych <= 0xE0)
          goto yy928;
        if (yych == 0xED)
          goto yy932;
        goto yy922;
      } else {
        if (yych <= 0xF0)
          goto yy929;
        if (yych <= 0xF3)
          goto yy930;
        if (yych <= 0xF4)
          goto yy931;
        goto yy923;
      }
    }
  yy935:
    yyaccept = 1;
    marker = ++p;
    yych = *p;
    if (yybm[0 + yych] & 64) {
      goto yy925;
    }
    if (yych <= 0xEC) {
      if (yych <= 0xC1) {
        if (yych <= '\n')
          goto yy936;
        if (yych <= ']')
          goto yy927;
      } else {
        if (yych <= 0xDF)
          goto yy924;
        if (yych <= 0xE0)
          goto yy928;
        goto yy922;
      }
    } else {
      if (yych <= 0xF0) {
        if (yych <= 0xED)
          goto yy932;
        if (yych <= 0xEF)
          goto yy922;
        goto yy929;
      } else {
        if (yych <= 0xF3)
          goto yy930;
        if (yych <= 0xF4)
          goto yy931;
      }
    }
  yy936 : { return (bufsize_t)(p - start); }
  }
}

// Try to match a link title (in single quotes, in double quotes, or
// in parentheses), returning number of chars matched.  Allow one
// level of internal nesting (quotes within quotes).
bufsize_t _scan_link_title(const unsigned char *p) {
  const unsigned char *marker = NULL;
  const unsigned char *start = p;

  {
    unsigned char yych;
    unsigned int yyaccept = 0;
    static const unsigned char yybm[] = {
        0,   224, 224, 224, 224, 224, 224, 224, 224, 224, 224, 224, 224, 224,
        224, 224, 224, 224, 224, 224, 224, 224, 224, 224, 224, 224, 224, 224,
        224, 224, 224, 224, 224, 224, 96,  224, 224, 224, 224, 160, 224, 192,
        224, 224, 224, 224, 224, 224, 224, 224, 224, 224, 224, 224, 224, 224,
        224, 224, 224, 224, 224, 224, 224, 224, 224, 224, 224, 224, 224, 224,
        224, 224, 224, 224, 224, 224, 224, 224, 224, 224, 224, 224, 224, 224,
        224, 224, 224, 224, 224, 224, 224, 224, 16,  224, 224, 224, 224, 224,
        224, 224, 224, 224, 224, 224, 224, 224, 224, 224, 224, 224, 224, 224,
        224, 224, 224, 224, 224, 224, 224, 224, 224, 224, 224, 224, 224, 224,
        224, 224, 0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,
    };
    yych = *p;
    if (yych <= '&') {
      if (yych == '"')
        goto yy941;
    } else {
      if (yych <= '\'')
        goto yy942;
      if (yych <= '(')
        goto yy943;
    }
    ++p;
  yy940 : { return 0; }
  yy941:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x00)
      goto yy940;
    if (yych <= 0x7F)
      goto yy976;
    if (yych <= 0xC1)
      goto yy940;
    if (yych <= 0xF4)
      goto yy976;
    goto yy940;
  yy942:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x00)
      goto yy940;
    if (yych <= 0x7F)
      goto yy962;
    if (yych <= 0xC1)
      goto yy940;
    if (yych <= 0xF4)
      goto yy962;
    goto yy940;
  yy943:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych <= 0x00)
      goto yy940;
    if (yych <= 0x7F)
      goto yy948;
    if (yych <= 0xC1)
      goto yy940;
    if (yych <= 0xF4)
      goto yy948;
    goto yy940;
  yy944:
    ++p;
    yych = *p;
    if (yybm[0 + yych] & 32) {
      goto yy947;
    }
    if (yych <= 0xE0) {
      if (yych <= '\\') {
        if (yych <= 0x00)
          goto yy946;
        if (yych <= ')')
          goto yy958;
        goto yy944;
      } else {
        if (yych <= 0xC1)
          goto yy946;
        if (yych <= 0xDF)
          goto yy949;
        goto yy950;
      }
    } else {
      if (yych <= 0xEF) {
        if (yych == 0xED)
          goto yy955;
        goto yy951;
      } else {
        if (yych <= 0xF0)
          goto yy952;
        if (yych <= 0xF3)
          goto yy953;
        if (yych <= 0xF4)
          goto yy954;
      }
    }
  yy946:
    p = marker;
    if (yyaccept <= 1) {
      if (yyaccept == 0) {
        goto yy940;
      } else {
        goto yy957;
      }
    } else {
      if (yyaccept == 2) {
        goto yy971;
      } else {
        goto yy985;
      }
    }
  yy947:
    ++p;
    yych = *p;
  yy948:
    if (yybm[0 + yych] & 32) {
      goto yy947;
    }
    if (yych <= 0xE0) {
      if (yych <= '\\') {
        if (yych <= 0x00)
          goto yy946;
        if (yych <= ')')
          goto yy956;
        goto yy944;
      } else {
        if (yych <= 0xC1)
          goto yy946;
        if (yych >= 0xE0)
          goto yy950;
      }
    } else {
      if (yych <= 0xEF) {
        if (yych == 0xED)
          goto yy955;
        goto yy951;
      } else {
        if (yych <= 0xF0)
          goto yy952;
        if (yych <= 0xF3)
          goto yy953;
        if (yych <= 0xF4)
          goto yy954;
        goto yy946;
      }
    }
  yy949:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy946;
    if (yych <= 0xBF)
      goto yy947;
    goto yy946;
  yy950:
    ++p;
    yych = *p;
    if (yych <= 0x9F)
      goto yy946;
    if (yych <= 0xBF)
      goto yy949;
    goto yy946;
  yy951:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy946;
    if (yych <= 0xBF)
      goto yy949;
    goto yy946;
  yy952:
    ++p;
    yych = *p;
    if (yych <= 0x8F)
      goto yy946;
    if (yych <= 0xBF)
      goto yy951;
    goto yy946;
  yy953:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy946;
    if (yych <= 0xBF)
      goto yy951;
    goto yy946;
  yy954:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy946;
    if (yych <= 0x8F)
      goto yy951;
    goto yy946;
  yy955:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy946;
    if (yych <= 0x9F)
      goto yy949;
    goto yy946;
  yy956:
    ++p;
  yy957 : { return (bufsize_t)(p - start); }
  yy958:
    yyaccept = 1;
    marker = ++p;
    yych = *p;
    if (yybm[0 + yych] & 32) {
      goto yy947;
    }
    if (yych <= 0xE0) {
      if (yych <= '\\') {
        if (yych <= 0x00)
          goto yy957;
        if (yych <= ')')
          goto yy956;
        goto yy944;
      } else {
        if (yych <= 0xC1)
          goto yy957;
        if (yych <= 0xDF)
          goto yy949;
        goto yy950;
      }
    } else {
      if (yych <= 0xEF) {
        if (yych == 0xED)
          goto yy955;
        goto yy951;
      } else {
        if (yych <= 0xF0)
          goto yy952;
        if (yych <= 0xF3)
          goto yy953;
        if (yych <= 0xF4)
          goto yy954;
        goto yy957;
      }
    }
  yy959:
    ++p;
    yych = *p;
    if (yybm[0 + yych] & 64) {
      goto yy961;
    }
    if (yych <= 0xE0) {
      if (yych <= '\\') {
        if (yych <= 0x00)
          goto yy946;
        if (yych <= '\'')
          goto yy972;
        goto yy959;
      } else {
        if (yych <= 0xC1)
          goto yy946;
        if (yych <= 0xDF)
          goto yy963;
        goto yy964;
      }
    } else {
      if (yych <= 0xEF) {
        if (yych == 0xED)
          goto yy969;
        goto yy965;
      } else {
        if (yych <= 0xF0)
          goto yy966;
        if (yych <= 0xF3)
          goto yy967;
        if (yych <= 0xF4)
          goto yy968;
        goto yy946;
      }
    }
  yy961:
    ++p;
    yych = *p;
  yy962:
    if (yybm[0 + yych] & 64) {
      goto yy961;
    }
    if (yych <= 0xE0) {
      if (yych <= '\\') {
        if (yych <= 0x00)
          goto yy946;
        if (yych <= '\'')
          goto yy970;
        goto yy959;
      } else {
        if (yych <= 0xC1)
          goto yy946;
        if (yych >= 0xE0)
          goto yy964;
      }
    } else {
      if (yych <= 0xEF) {
        if (yych == 0xED)
          goto yy969;
        goto yy965;
      } else {
        if (yych <= 0xF0)
          goto yy966;
        if (yych <= 0xF3)
          goto yy967;
        if (yych <= 0xF4)
          goto yy968;
        goto yy946;
      }
    }
  yy963:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy946;
    if (yych <= 0xBF)
      goto yy961;
    goto yy946;
  yy964:
    ++p;
    yych = *p;
    if (yych <= 0x9F)
      goto yy946;
    if (yych <= 0xBF)
      goto yy963;
    goto yy946;
  yy965:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy946;
    if (yych <= 0xBF)
      goto yy963;
    goto yy946;
  yy966:
    ++p;
    yych = *p;
    if (yych <= 0x8F)
      goto yy946;
    if (yych <= 0xBF)
      goto yy965;
    goto yy946;
  yy967:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy946;
    if (yych <= 0xBF)
      goto yy965;
    goto yy946;
  yy968:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy946;
    if (yych <= 0x8F)
      goto yy965;
    goto yy946;
  yy969:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy946;
    if (yych <= 0x9F)
      goto yy963;
    goto yy946;
  yy970:
    ++p;
  yy971 : { return (bufsize_t)(p - start); }
  yy972:
    yyaccept = 2;
    marker = ++p;
    yych = *p;
    if (yybm[0 + yych] & 64) {
      goto yy961;
    }
    if (yych <= 0xE0) {
      if (yych <= '\\') {
        if (yych <= 0x00)
          goto yy971;
        if (yych <= '\'')
          goto yy970;
        goto yy959;
      } else {
        if (yych <= 0xC1)
          goto yy971;
        if (yych <= 0xDF)
          goto yy963;
        goto yy964;
      }
    } else {
      if (yych <= 0xEF) {
        if (yych == 0xED)
          goto yy969;
        goto yy965;
      } else {
        if (yych <= 0xF0)
          goto yy966;
        if (yych <= 0xF3)
          goto yy967;
        if (yych <= 0xF4)
          goto yy968;
        goto yy971;
      }
    }
  yy973:
    ++p;
    yych = *p;
    if (yybm[0 + yych] & 128) {
      goto yy975;
    }
    if (yych <= 0xE0) {
      if (yych <= '\\') {
        if (yych <= 0x00)
          goto yy946;
        if (yych <= '"')
          goto yy986;
        goto yy973;
      } else {
        if (yych <= 0xC1)
          goto yy946;
        if (yych <= 0xDF)
          goto yy977;
        goto yy978;
      }
    } else {
      if (yych <= 0xEF) {
        if (yych == 0xED)
          goto yy983;
        goto yy979;
      } else {
        if (yych <= 0xF0)
          goto yy980;
        if (yych <= 0xF3)
          goto yy981;
        if (yych <= 0xF4)
          goto yy982;
        goto yy946;
      }
    }
  yy975:
    ++p;
    yych = *p;
  yy976:
    if (yybm[0 + yych] & 128) {
      goto yy975;
    }
    if (yych <= 0xE0) {
      if (yych <= '\\') {
        if (yych <= 0x00)
          goto yy946;
        if (yych <= '"')
          goto yy984;
        goto yy973;
      } else {
        if (yych <= 0xC1)
          goto yy946;
        if (yych >= 0xE0)
          goto yy978;
      }
    } else {
      if (yych <= 0xEF) {
        if (yych == 0xED)
          goto yy983;
        goto yy979;
      } else {
        if (yych <= 0xF0)
          goto yy980;
        if (yych <= 0xF3)
          goto yy981;
        if (yych <= 0xF4)
          goto yy982;
        goto yy946;
      }
    }
  yy977:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy946;
    if (yych <= 0xBF)
      goto yy975;
    goto yy946;
  yy978:
    ++p;
    yych = *p;
    if (yych <= 0x9F)
      goto yy946;
    if (yych <= 0xBF)
      goto yy977;
    goto yy946;
  yy979:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy946;
    if (yych <= 0xBF)
      goto yy977;
    goto yy946;
  yy980:
    ++p;
    yych = *p;
    if (yych <= 0x8F)
      goto yy946;
    if (yych <= 0xBF)
      goto yy979;
    goto yy946;
  yy981:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy946;
    if (yych <= 0xBF)
      goto yy979;
    goto yy946;
  yy982:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy946;
    if (yych <= 0x8F)
      goto yy979;
    goto yy946;
  yy983:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy946;
    if (yych <= 0x9F)
      goto yy977;
    goto yy946;
  yy984:
    ++p;
  yy985 : { return (bufsize_t)(p - start); }
  yy986:
    yyaccept = 3;
    marker = ++p;
    yych = *p;
    if (yybm[0 + yych] & 128) {
      goto yy975;
    }
    if (yych <= 0xE0) {
      if (yych <= '\\') {
        if (yych <= 0x00)
          goto yy985;
        if (yych <= '"')
          goto yy984;
        goto yy973;
      } else {
        if (yych <= 0xC1)
          goto yy985;
        if (yych <= 0xDF)
          goto yy977;
        goto yy978;
      }
    } else {
      if (yych <= 0xEF) {
        if (yych == 0xED)
          goto yy983;
        goto yy979;
      } else {
        if (yych <= 0xF0)
          goto yy980;
        if (yych <= 0xF3)
          goto yy981;
        if (yych <= 0xF4)
          goto yy982;
        goto yy985;
      }
    }
  }
}

// Match space characters, including newlines.
bufsize_t _scan_spacechars(const unsigned char *p) {
  const unsigned char *start = p;

  {
    unsigned char yych;
    static const unsigned char yybm[] = {
        0, 0, 0, 0, 0, 0, 0, 0, 0, 128, 128, 128, 128, 128, 0, 0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0,   0,   0,   128, 0,   0, 0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0,   0,   0,   0,   0,   0, 0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0,   0,   0,   0,   0,   0, 0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0,   0,   0,   0,   0,   0, 0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0,   0,   0,   0,   0,   0, 0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0,   0,   0,   0,   0,   0, 0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0,   0,   0,   0,   0,   0, 0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0,   0,   0,   0,   0,   0, 0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0,   0,   0,   0,   0,   0, 0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0,   0,   0,   0,   0,   0, 0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0,   0,   0,   0,   0,   0, 0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0,   0,   0,   0,   0,   0, 0,
    };
    yych = *p;
    if (yych <= 0x08)
      goto yy989;
    if (yych <= '\r')
      goto yy991;
    if (yych == ' ')
      goto yy991;
  yy989:
    ++p;
    { return 0; }
  yy991:
    ++p;
    yych = *p;
    goto yy994;
  yy992 : { return (bufsize_t)(p - start); }
  yy993:
    ++p;
    yych = *p;
  yy994:
    if (yybm[0 + yych] & 128) {
      goto yy993;
    }
    goto yy992;
  }
}

// Match ATX heading start.
bufsize_t _scan_atx_heading_start(const unsigned char *p) {
  const unsigned char *marker = NULL;
  const unsigned char *start = p;

  {
    unsigned char yych;
    static const unsigned char yybm[] = {
        0, 0, 0, 0, 0, 0, 0, 0, 0, 128, 0,   0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0,   128, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0,   0,   0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0,   0,   0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0,   0,   0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0,   0,   0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0,   0,   0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0,   0,   0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0,   0,   0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0,   0,   0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0,   0,   0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0,   0,   0, 0, 0,
    };
    yych = *p;
    if (yych == '#')
      goto yy999;
    ++p;
  yy998 : { return 0; }
  yy999:
    yych = *(marker = ++p);
    if (yybm[0 + yych] & 128) {
      goto yy1002;
    }
    if (yych <= '\f') {
      if (yych <= 0x08)
        goto yy998;
      if (yych >= '\v')
        goto yy998;
    } else {
      if (yych <= '\r')
        goto yy1000;
      if (yych == '#')
        goto yy1004;
      goto yy998;
    }
  yy1000:
    ++p;
  yy1001 : { return (bufsize_t)(p - start); }
  yy1002:
    ++p;
    yych = *p;
    if (yybm[0 + yych] & 128) {
      goto yy1002;
    }
    goto yy1001;
  yy1004:
    yych = *++p;
    if (yybm[0 + yych] & 128) {
      goto yy1002;
    }
    if (yych <= '\f') {
      if (yych <= 0x08)
        goto yy1005;
      if (yych <= '\n')
        goto yy1000;
    } else {
      if (yych <= '\r')
        goto yy1000;
      if (yych == '#')
        goto yy1006;
    }
  yy1005:
    p = marker;
    goto yy998;
  yy1006:
    yych = *++p;
    if (yybm[0 + yych] & 128) {
      goto yy1002;
    }
    if (yych <= '\f') {
      if (yych <= 0x08)
        goto yy1005;
      if (yych <= '\n')
        goto yy1000;
      goto yy1005;
    } else {
      if (yych <= '\r')
        goto yy1000;
      if (yych != '#')
        goto yy1005;
    }
    yych = *++p;
    if (yybm[0 + yych] & 128) {
      goto yy1002;
    }
    if (yych <= '\f') {
      if (yych <= 0x08)
        goto yy1005;
      if (yych <= '\n')
        goto yy1000;
      goto yy1005;
    } else {
      if (yych <= '\r')
        goto yy1000;
      if (yych != '#')
        goto yy1005;
    }
    yych = *++p;
    if (yybm[0 + yych] & 128) {
      goto yy1002;
    }
    if (yych <= '\f') {
      if (yych <= 0x08)
        goto yy1005;
      if (yych <= '\n')
        goto yy1000;
      goto yy1005;
    } else {
      if (yych <= '\r')
        goto yy1000;
      if (yych != '#')
        goto yy1005;
    }
    ++p;
    if (yybm[0 + (yych = *p)] & 128) {
      goto yy1002;
    }
    if (yych <= 0x08)
      goto yy1005;
    if (yych <= '\n')
      goto yy1000;
    if (yych == '\r')
      goto yy1000;
    goto yy1005;
  }
}

// Match setext heading line.  Return 1 for level-1 heading,
// 2 for level-2, 0 for no match.
bufsize_t _scan_setext_heading_line(const unsigned char *p) {
  const unsigned char *marker = NULL;

  {
    unsigned char yych;
    static const unsigned char yybm[] = {
        0, 0,   0, 0, 0, 0, 0, 0, 0, 32, 0,  0, 0, 0, 0, 0, 0, 0,  0, 0, 0, 0,
        0, 0,   0, 0, 0, 0, 0, 0, 0, 0,  32, 0, 0, 0, 0, 0, 0, 0,  0, 0, 0, 0,
        0, 128, 0, 0, 0, 0, 0, 0, 0, 0,  0,  0, 0, 0, 0, 0, 0, 64, 0, 0, 0, 0,
        0, 0,   0, 0, 0, 0, 0, 0, 0, 0,  0,  0, 0, 0, 0, 0, 0, 0,  0, 0, 0, 0,
        0, 0,   0, 0, 0, 0, 0, 0, 0, 0,  0,  0, 0, 0, 0, 0, 0, 0,  0, 0, 0, 0,
        0, 0,   0, 0, 0, 0, 0, 0, 0, 0,  0,  0, 0, 0, 0, 0, 0, 0,  0, 0, 0, 0,
        0, 0,   0, 0, 0, 0, 0, 0, 0, 0,  0,  0, 0, 0, 0, 0, 0, 0,  0, 0, 0, 0,
        0, 0,   0, 0, 0, 0, 0, 0, 0, 0,  0,  0, 0, 0, 0, 0, 0, 0,  0, 0, 0, 0,
        0, 0,   0, 0, 0, 0, 0, 0, 0, 0,  0,  0, 0, 0, 0, 0, 0, 0,  0, 0, 0, 0,
        0, 0,   0, 0, 0, 0, 0, 0, 0, 0,  0,  0, 0, 0, 0, 0, 0, 0,  0, 0, 0, 0,
        0, 0,   0, 0, 0, 0, 0, 0, 0, 0,  0,  0, 0, 0, 0, 0, 0, 0,  0, 0, 0, 0,
        0, 0,   0, 0, 0, 0, 0, 0, 0, 0,  0,  0, 0, 0,
    };
    yych = *p;
    if (yych == '-')
      goto yy1014;
    if (yych == '=')
      goto yy1015;
    ++p;
  yy1013 : { return 0; }
  yy1014:
    yych = *(marker = ++p);
    if (yybm[0 + yych] & 128) {
      goto yy1027;
    }
    if (yych <= '\f') {
      if (yych <= 0x08)
        goto yy1013;
      if (yych <= '\n')
        goto yy1024;
      goto yy1013;
    } else {
      if (yych <= '\r')
        goto yy1024;
      if (yych == ' ')
        goto yy1024;
      goto yy1013;
    }
  yy1015:
    yych = *(marker = ++p);
    if (yybm[0 + yych] & 64) {
      goto yy1021;
    }
    if (yych <= '\f') {
      if (yych <= 0x08)
        goto yy1013;
      if (yych <= '\n')
        goto yy1017;
      goto yy1013;
    } else {
      if (yych <= '\r')
        goto yy1017;
      if (yych == ' ')
        goto yy1017;
      goto yy1013;
    }
  yy1016:
    ++p;
    yych = *p;
  yy1017:
    if (yybm[0 + yych] & 32) {
      goto yy1016;
    }
    if (yych <= 0x08)
      goto yy1018;
    if (yych <= '\n')
      goto yy1019;
    if (yych == '\r')
      goto yy1019;
  yy1018:
    p = marker;
    goto yy1013;
  yy1019:
    ++p;
    { return 1; }
  yy1021:
    ++p;
    yych = *p;
    if (yybm[0 + yych] & 32) {
      goto yy1016;
    }
    if (yych <= '\f') {
      if (yych <= 0x08)
        goto yy1018;
      if (yych <= '\n')
        goto yy1019;
      goto yy1018;
    } else {
      if (yych <= '\r')
        goto yy1019;
      if (yych == '=')
        goto yy1021;
      goto yy1018;
    }
  yy1023:
    ++p;
    yych = *p;
  yy1024:
    if (yych <= '\f') {
      if (yych <= 0x08)
        goto yy1018;
      if (yych <= '\t')
        goto yy1023;
      if (yych >= '\v')
        goto yy1018;
    } else {
      if (yych <= '\r')
        goto yy1025;
      if (yych == ' ')
        goto yy1023;
      goto yy1018;
    }
  yy1025:
    ++p;
    { return 2; }
  yy1027:
    ++p;
    yych = *p;
    if (yybm[0 + yych] & 128) {
      goto yy1027;
    }
    if (yych <= '\f') {
      if (yych <= 0x08)
        goto yy1018;
      if (yych <= '\t')
        goto yy1023;
      if (yych <= '\n')
        goto yy1025;
      goto yy1018;
    } else {
      if (yych <= '\r')
        goto yy1025;
      if (yych == ' ')
        goto yy1023;
      goto yy1018;
    }
  }
}

// Scan a thematic break line: "...three or more hyphens, asterisks,
// or underscores on a line by themselves. If you wish, you may use
// spaces between the hyphens or asterisks."
bufsize_t _scan_thematic_break(const unsigned char *p) {
  const unsigned char *marker = NULL;
  const unsigned char *start = p;

  {
    unsigned char yych;
    static const unsigned char yybm[] = {
        0, 0, 0,   0, 0, 0,  0, 0, 0, 240, 0, 0, 0,   0, 0, 0,  0, 0, 0, 0,
        0, 0, 0,   0, 0, 0,  0, 0, 0, 0,   0, 0, 240, 0, 0, 0,  0, 0, 0, 0,
        0, 0, 128, 0, 0, 64, 0, 0, 0, 0,   0, 0, 0,   0, 0, 0,  0, 0, 0, 0,
        0, 0, 0,   0, 0, 0,  0, 0, 0, 0,   0, 0, 0,   0, 0, 0,  0, 0, 0, 0,
        0, 0, 0,   0, 0, 0,  0, 0, 0, 0,   0, 0, 0,   0, 0, 32, 0, 0, 0, 0,
        0, 0, 0,   0, 0, 0,  0, 0, 0, 0,   0, 0, 0,   0, 0, 0,  0, 0, 0, 0,
        0, 0, 0,   0, 0, 0,  0, 0, 0, 0,   0, 0, 0,   0, 0, 0,  0, 0, 0, 0,
        0, 0, 0,   0, 0, 0,  0, 0, 0, 0,   0, 0, 0,   0, 0, 0,  0, 0, 0, 0,
        0, 0, 0,   0, 0, 0,  0, 0, 0, 0,   0, 0, 0,   0, 0, 0,  0, 0, 0, 0,
        0, 0, 0,   0, 0, 0,  0, 0, 0, 0,   0, 0, 0,   0, 0, 0,  0, 0, 0, 0,
        0, 0, 0,   0, 0, 0,  0, 0, 0, 0,   0, 0, 0,   0, 0, 0,  0, 0, 0, 0,
        0, 0, 0,   0, 0, 0,  0, 0, 0, 0,   0, 0, 0,   0, 0, 0,  0, 0, 0, 0,
        0, 0, 0,   0, 0, 0,  0, 0, 0, 0,   0, 0, 0,   0, 0, 0,
    };
    yych = *p;
    if (yych <= ',') {
      if (yych == '*')
        goto yy1033;
    } else {
      if (yych <= '-')
        goto yy1034;
      if (yych == '_')
        goto yy1035;
    }
    ++p;
  yy1032 : { return 0; }
  yy1033:
    yych = *(marker = ++p);
    if (yych <= 0x1F) {
      if (yych == '\t')
        goto yy1057;
      goto yy1032;
    } else {
      if (yych <= ' ')
        goto yy1057;
      if (yych == '*')
        goto yy1059;
      goto yy1032;
    }
  yy1034:
    yych = *(marker = ++p);
    if (yych <= 0x1F) {
      if (yych == '\t')
        goto yy1047;
      goto yy1032;
    } else {
      if (yych <= ' ')
        goto yy1047;
      if (yych == '-')
        goto yy1049;
      goto yy1032;
    }
  yy1035:
    yych = *(marker = ++p);
    if (yybm[0 + yych] & 16) {
      goto yy1036;
    }
    if (yych == '_')
      goto yy1039;
    goto yy1032;
  yy1036:
    ++p;
    yych = *p;
    if (yybm[0 + yych] & 16) {
      goto yy1036;
    }
    if (yych == '_')
      goto yy1039;
  yy1038:
    p = marker;
    goto yy1032;
  yy1039:
    ++p;
    yych = *p;
    if (yych <= 0x1F) {
      if (yych == '\t')
        goto yy1039;
      goto yy1038;
    } else {
      if (yych <= ' ')
        goto yy1039;
      if (yych != '_')
        goto yy1038;
    }
  yy1041:
    ++p;
    yych = *p;
    if (yych <= '\r') {
      if (yych <= '\t') {
        if (yych <= 0x08)
          goto yy1038;
        goto yy1041;
      } else {
        if (yych <= '\n')
          goto yy1043;
        if (yych <= '\f')
          goto yy1038;
      }
    } else {
      if (yych <= ' ') {
        if (yych <= 0x1F)
          goto yy1038;
        goto yy1041;
      } else {
        if (yych == '_')
          goto yy1045;
        goto yy1038;
      }
    }
  yy1043:
    ++p;
    { return (bufsize_t)(p - start); }
  yy1045:
    ++p;
    yych = *p;
    if (yybm[0 + yych] & 32) {
      goto yy1045;
    }
    if (yych <= 0x08)
      goto yy1038;
    if (yych <= '\n')
      goto yy1043;
    if (yych == '\r')
      goto yy1043;
    goto yy1038;
  yy1047:
    ++p;
    yych = *p;
    if (yych <= 0x1F) {
      if (yych == '\t')
        goto yy1047;
      goto yy1038;
    } else {
      if (yych <= ' ')
        goto yy1047;
      if (yych != '-')
        goto yy1038;
    }
  yy1049:
    ++p;
    yych = *p;
    if (yych <= 0x1F) {
      if (yych == '\t')
        goto yy1049;
      goto yy1038;
    } else {
      if (yych <= ' ')
        goto yy1049;
      if (yych != '-')
        goto yy1038;
    }
  yy1051:
    ++p;
    yych = *p;
    if (yych <= '\r') {
      if (yych <= '\t') {
        if (yych <= 0x08)
          goto yy1038;
        goto yy1051;
      } else {
        if (yych <= '\n')
          goto yy1053;
        if (yych <= '\f')
          goto yy1038;
      }
    } else {
      if (yych <= ' ') {
        if (yych <= 0x1F)
          goto yy1038;
        goto yy1051;
      } else {
        if (yych == '-')
          goto yy1055;
        goto yy1038;
      }
    }
  yy1053:
    ++p;
    { return (bufsize_t)(p - start); }
  yy1055:
    ++p;
    yych = *p;
    if (yybm[0 + yych] & 64) {
      goto yy1055;
    }
    if (yych <= 0x08)
      goto yy1038;
    if (yych <= '\n')
      goto yy1053;
    if (yych == '\r')
      goto yy1053;
    goto yy1038;
  yy1057:
    ++p;
    yych = *p;
    if (yych <= 0x1F) {
      if (yych == '\t')
        goto yy1057;
      goto yy1038;
    } else {
      if (yych <= ' ')
        goto yy1057;
      if (yych != '*')
        goto yy1038;
    }
  yy1059:
    ++p;
    yych = *p;
    if (yych <= 0x1F) {
      if (yych == '\t')
        goto yy1059;
      goto yy1038;
    } else {
      if (yych <= ' ')
        goto yy1059;
      if (yych != '*')
        goto yy1038;
    }
  yy1061:
    ++p;
    yych = *p;
    if (yych <= '\r') {
      if (yych <= '\t') {
        if (yych <= 0x08)
          goto yy1038;
        goto yy1061;
      } else {
        if (yych <= '\n')
          goto yy1063;
        if (yych <= '\f')
          goto yy1038;
      }
    } else {
      if (yych <= ' ') {
        if (yych <= 0x1F)
          goto yy1038;
        goto yy1061;
      } else {
        if (yych == '*')
          goto yy1065;
        goto yy1038;
      }
    }
  yy1063:
    ++p;
    { return (bufsize_t)(p - start); }
  yy1065:
    ++p;
    yych = *p;
    if (yybm[0 + yych] & 128) {
      goto yy1065;
    }
    if (yych <= 0x08)
      goto yy1038;
    if (yych <= '\n')
      goto yy1063;
    if (yych == '\r')
      goto yy1063;
    goto yy1038;
  }
}

// Scan an opening code fence.
bufsize_t _scan_open_code_fence(const unsigned char *p) {
  const unsigned char *marker = NULL;
  const unsigned char *start = p;

  {
    unsigned char yych;
    static const unsigned char yybm[] = {
        0,   160, 160, 160, 160, 160, 160, 160, 160, 160, 0,   160, 160, 0,
        160, 160, 160, 160, 160, 160, 160, 160, 160, 160, 160, 160, 160, 160,
        160, 160, 160, 160, 160, 160, 160, 160, 160, 160, 160, 160, 160, 160,
        160, 160, 160, 160, 160, 160, 160, 160, 160, 160, 160, 160, 160, 160,
        160, 160, 160, 160, 160, 160, 160, 160, 160, 160, 160, 160, 160, 160,
        160, 160, 160, 160, 160, 160, 160, 160, 160, 160, 160, 160, 160, 160,
        160, 160, 160, 160, 160, 160, 160, 160, 160, 160, 160, 160, 96,  160,
        160, 160, 160, 160, 160, 160, 160, 160, 160, 160, 160, 160, 160, 160,
        160, 160, 160, 160, 160, 160, 160, 160, 160, 160, 160, 160, 160, 160,
        144, 160, 0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
        0,   0,   0,   0,
    };
    yych = *p;
    if (yych == '`')
      goto yy1071;
    if (yych == '~')
      goto yy1072;
    ++p;
  yy1070 : { return 0; }
  yy1071:
    yych = *(marker = ++p);
    if (yych == '`')
      goto yy1088;
    goto yy1070;
  yy1072:
    yych = *(marker = ++p);
    if (yych != '~')
      goto yy1070;
    yych = *++p;
    if (yybm[0 + yych] & 16) {
      goto yy1075;
    }
  yy1074:
    p = marker;
    goto yy1070;
  yy1075:
    ++p;
    yych = *p;
    marker = p;
    if (yybm[0 + yych] & 32) {
      goto yy1077;
    }
    if (yych <= 0xE0) {
      if (yych <= '~') {
        if (yych <= 0x00)
          goto yy1074;
        if (yych <= '\r')
          goto yy1086;
        goto yy1075;
      } else {
        if (yych <= 0xC1)
          goto yy1074;
        if (yych <= 0xDF)
          goto yy1079;
        goto yy1080;
      }
    } else {
      if (yych <= 0xEF) {
        if (yych == 0xED)
          goto yy1085;
        goto yy1081;
      } else {
        if (yych <= 0xF0)
          goto yy1082;
        if (yych <= 0xF3)
          goto yy1083;
        if (yych <= 0xF4)
          goto yy1084;
        goto yy1074;
      }
    }
  yy1077:
    ++p;
    yych = *p;
    if (yybm[0 + yych] & 32) {
      goto yy1077;
    }
    if (yych <= 0xEC) {
      if (yych <= 0xC1) {
        if (yych <= 0x00)
          goto yy1074;
        if (yych <= '\r')
          goto yy1086;
        goto yy1074;
      } else {
        if (yych <= 0xDF)
          goto yy1079;
        if (yych <= 0xE0)
          goto yy1080;
        goto yy1081;
      }
    } else {
      if (yych <= 0xF0) {
        if (yych <= 0xED)
          goto yy1085;
        if (yych <= 0xEF)
          goto yy1081;
        goto yy1082;
      } else {
        if (yych <= 0xF3)
          goto yy1083;
        if (yych <= 0xF4)
          goto yy1084;
        goto yy1074;
      }
    }
  yy1079:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy1074;
    if (yych <= 0xBF)
      goto yy1077;
    goto yy1074;
  yy1080:
    ++p;
    yych = *p;
    if (yych <= 0x9F)
      goto yy1074;
    if (yych <= 0xBF)
      goto yy1079;
    goto yy1074;
  yy1081:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy1074;
    if (yych <= 0xBF)
      goto yy1079;
    goto yy1074;
  yy1082:
    ++p;
    yych = *p;
    if (yych <= 0x8F)
      goto yy1074;
    if (yych <= 0xBF)
      goto yy1081;
    goto yy1074;
  yy1083:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy1074;
    if (yych <= 0xBF)
      goto yy1081;
    goto yy1074;
  yy1084:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy1074;
    if (yych <= 0x8F)
      goto yy1081;
    goto yy1074;
  yy1085:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy1074;
    if (yych <= 0x9F)
      goto yy1079;
    goto yy1074;
  yy1086:
    ++p;
    p = marker;
    { return (bufsize_t)(p - start); }
  yy1088:
    yych = *++p;
    if (yybm[0 + yych] & 64) {
      goto yy1089;
    }
    goto yy1074;
  yy1089:
    ++p;
    yych = *p;
    marker = p;
    if (yybm[0 + yych] & 128) {
      goto yy1091;
    }
    if (yych <= 0xE0) {
      if (yych <= '`') {
        if (yych <= 0x00)
          goto yy1074;
        if (yych <= '\r')
          goto yy1100;
        goto yy1089;
      } else {
        if (yych <= 0xC1)
          goto yy1074;
        if (yych <= 0xDF)
          goto yy1093;
        goto yy1094;
      }
    } else {
      if (yych <= 0xEF) {
        if (yych == 0xED)
          goto yy1099;
        goto yy1095;
      } else {
        if (yych <= 0xF0)
          goto yy1096;
        if (yych <= 0xF3)
          goto yy1097;
        if (yych <= 0xF4)
          goto yy1098;
        goto yy1074;
      }
    }
  yy1091:
    ++p;
    yych = *p;
    if (yybm[0 + yych] & 128) {
      goto yy1091;
    }
    if (yych <= 0xEC) {
      if (yych <= 0xC1) {
        if (yych <= 0x00)
          goto yy1074;
        if (yych <= '\r')
          goto yy1100;
        goto yy1074;
      } else {
        if (yych <= 0xDF)
          goto yy1093;
        if (yych <= 0xE0)
          goto yy1094;
        goto yy1095;
      }
    } else {
      if (yych <= 0xF0) {
        if (yych <= 0xED)
          goto yy1099;
        if (yych <= 0xEF)
          goto yy1095;
        goto yy1096;
      } else {
        if (yych <= 0xF3)
          goto yy1097;
        if (yych <= 0xF4)
          goto yy1098;
        goto yy1074;
      }
    }
  yy1093:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy1074;
    if (yych <= 0xBF)
      goto yy1091;
    goto yy1074;
  yy1094:
    ++p;
    yych = *p;
    if (yych <= 0x9F)
      goto yy1074;
    if (yych <= 0xBF)
      goto yy1093;
    goto yy1074;
  yy1095:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy1074;
    if (yych <= 0xBF)
      goto yy1093;
    goto yy1074;
  yy1096:
    ++p;
    yych = *p;
    if (yych <= 0x8F)
      goto yy1074;
    if (yych <= 0xBF)
      goto yy1095;
    goto yy1074;
  yy1097:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy1074;
    if (yych <= 0xBF)
      goto yy1095;
    goto yy1074;
  yy1098:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy1074;
    if (yych <= 0x8F)
      goto yy1095;
    goto yy1074;
  yy1099:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy1074;
    if (yych <= 0x9F)
      goto yy1093;
    goto yy1074;
  yy1100:
    ++p;
    p = marker;
    { return (bufsize_t)(p - start); }
  }
}

// Scan a closing code fence with length at least len.
bufsize_t _scan_close_code_fence(const unsigned char *p) {
  const unsigned char *marker = NULL;
  const unsigned char *start = p;

  {
    unsigned char yych;
    static const unsigned char yybm[] = {
        0, 0, 0, 0, 0, 0, 0, 0, 0,   64, 0,  0, 0, 0, 0, 0, 0,  0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0,   0,  64, 0, 0, 0, 0, 0, 0,  0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0,   0,  0,  0, 0, 0, 0, 0, 0,  0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0,   0,  0,  0, 0, 0, 0, 0, 0,  0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 128, 0,  0,  0, 0, 0, 0, 0, 0,  0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0,   0,  0,  0, 0, 0, 0, 0, 32, 0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0,   0,  0,  0, 0, 0, 0, 0, 0,  0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0,   0,  0,  0, 0, 0, 0, 0, 0,  0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0,   0,  0,  0, 0, 0, 0, 0, 0,  0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0,   0,  0,  0, 0, 0, 0, 0, 0,  0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0,   0,  0,  0, 0, 0, 0, 0, 0,  0, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0,   0,  0,  0, 0, 0,
    };
    yych = *p;
    if (yych == '`')
      goto yy1106;
    if (yych == '~')
      goto yy1107;
    ++p;
  yy1105 : { return 0; }
  yy1106:
    yych = *(marker = ++p);
    if (yych == '`')
      goto yy1116;
    goto yy1105;
  yy1107:
    yych = *(marker = ++p);
    if (yych != '~')
      goto yy1105;
    yych = *++p;
    if (yybm[0 + yych] & 32) {
      goto yy1110;
    }
  yy1109:
    p = marker;
    goto yy1105;
  yy1110:
    ++p;
    yych = *p;
    marker = p;
    if (yybm[0 + yych] & 64) {
      goto yy1112;
    }
    if (yych <= '\f') {
      if (yych <= 0x08)
        goto yy1109;
      if (yych <= '\n')
        goto yy1114;
      goto yy1109;
    } else {
      if (yych <= '\r')
        goto yy1114;
      if (yych == '~')
        goto yy1110;
      goto yy1109;
    }
  yy1112:
    ++p;
    yych = *p;
    if (yybm[0 + yych] & 64) {
      goto yy1112;
    }
    if (yych <= 0x08)
      goto yy1109;
    if (yych <= '\n')
      goto yy1114;
    if (yych != '\r')
      goto yy1109;
  yy1114:
    ++p;
    p = marker;
    { return (bufsize_t)(p - start); }
  yy1116:
    yych = *++p;
    if (yybm[0 + yych] & 128) {
      goto yy1117;
    }
    goto yy1109;
  yy1117:
    ++p;
    yych = *p;
    marker = p;
    if (yybm[0 + yych] & 128) {
      goto yy1117;
    }
    if (yych <= '\f') {
      if (yych <= 0x08)
        goto yy1109;
      if (yych <= '\t')
        goto yy1119;
      if (yych <= '\n')
        goto yy1121;
      goto yy1109;
    } else {
      if (yych <= '\r')
        goto yy1121;
      if (yych != ' ')
        goto yy1109;
    }
  yy1119:
    ++p;
    yych = *p;
    if (yych <= '\f') {
      if (yych <= 0x08)
        goto yy1109;
      if (yych <= '\t')
        goto yy1119;
      if (yych >= '\v')
        goto yy1109;
    } else {
      if (yych <= '\r')
        goto yy1121;
      if (yych == ' ')
        goto yy1119;
      goto yy1109;
    }
  yy1121:
    ++p;
    p = marker;
    { return (bufsize_t)(p - start); }
  }
}

// Scans an entity.
// Returns number of chars matched.
bufsize_t _scan_entity(const unsigned char *p) {
  const unsigned char *marker = NULL;
  const unsigned char *start = p;

  {
    unsigned char yych;
    yych = *p;
    if (yych == '&')
      goto yy1127;
    ++p;
  yy1126 : { return 0; }
  yy1127:
    yych = *(marker = ++p);
    if (yych <= '@') {
      if (yych != '#')
        goto yy1126;
    } else {
      if (yych <= 'Z')
        goto yy1130;
      if (yych <= '`')
        goto yy1126;
      if (yych <= 'z')
        goto yy1130;
      goto yy1126;
    }
    yych = *++p;
    if (yych <= 'W') {
      if (yych <= '/')
        goto yy1129;
      if (yych <= '9')
        goto yy1165;
    } else {
      if (yych <= 'X')
        goto yy1164;
      if (yych == 'x')
        goto yy1164;
    }
  yy1129:
    p = marker;
    goto yy1126;
  yy1130:
    yych = *++p;
    if (yych <= '@') {
      if (yych <= '/')
        goto yy1129;
      if (yych >= ':')
        goto yy1129;
    } else {
      if (yych <= 'Z')
        goto yy1131;
      if (yych <= '`')
        goto yy1129;
      if (yych >= '{')
        goto yy1129;
    }
  yy1131:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy1129;
      if (yych <= '9')
        goto yy1134;
      if (yych <= ':')
        goto yy1129;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy1129;
        goto yy1134;
      } else {
        if (yych <= '`')
          goto yy1129;
        if (yych <= 'z')
          goto yy1134;
        goto yy1129;
      }
    }
  yy1132:
    ++p;
    { return (bufsize_t)(p - start); }
  yy1134:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy1129;
      if (yych <= '9')
        goto yy1135;
      if (yych <= ':')
        goto yy1129;
      goto yy1132;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy1129;
      } else {
        if (yych <= '`')
          goto yy1129;
        if (yych >= '{')
          goto yy1129;
      }
    }
  yy1135:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy1129;
      if (yych <= '9')
        goto yy1136;
      if (yych <= ':')
        goto yy1129;
      goto yy1132;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy1129;
      } else {
        if (yych <= '`')
          goto yy1129;
        if (yych >= '{')
          goto yy1129;
      }
    }
  yy1136:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy1129;
      if (yych <= '9')
        goto yy1137;
      if (yych <= ':')
        goto yy1129;
      goto yy1132;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy1129;
      } else {
        if (yych <= '`')
          goto yy1129;
        if (yych >= '{')
          goto yy1129;
      }
    }
  yy1137:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy1129;
      if (yych <= '9')
        goto yy1138;
      if (yych <= ':')
        goto yy1129;
      goto yy1132;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy1129;
      } else {
        if (yych <= '`')
          goto yy1129;
        if (yych >= '{')
          goto yy1129;
      }
    }
  yy1138:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy1129;
      if (yych <= '9')
        goto yy1139;
      if (yych <= ':')
        goto yy1129;
      goto yy1132;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy1129;
      } else {
        if (yych <= '`')
          goto yy1129;
        if (yych >= '{')
          goto yy1129;
      }
    }
  yy1139:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy1129;
      if (yych <= '9')
        goto yy1140;
      if (yych <= ':')
        goto yy1129;
      goto yy1132;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy1129;
      } else {
        if (yych <= '`')
          goto yy1129;
        if (yych >= '{')
          goto yy1129;
      }
    }
  yy1140:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy1129;
      if (yych <= '9')
        goto yy1141;
      if (yych <= ':')
        goto yy1129;
      goto yy1132;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy1129;
      } else {
        if (yych <= '`')
          goto yy1129;
        if (yych >= '{')
          goto yy1129;
      }
    }
  yy1141:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy1129;
      if (yych <= '9')
        goto yy1142;
      if (yych <= ':')
        goto yy1129;
      goto yy1132;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy1129;
      } else {
        if (yych <= '`')
          goto yy1129;
        if (yych >= '{')
          goto yy1129;
      }
    }
  yy1142:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy1129;
      if (yych <= '9')
        goto yy1143;
      if (yych <= ':')
        goto yy1129;
      goto yy1132;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy1129;
      } else {
        if (yych <= '`')
          goto yy1129;
        if (yych >= '{')
          goto yy1129;
      }
    }
  yy1143:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy1129;
      if (yych <= '9')
        goto yy1144;
      if (yych <= ':')
        goto yy1129;
      goto yy1132;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy1129;
      } else {
        if (yych <= '`')
          goto yy1129;
        if (yych >= '{')
          goto yy1129;
      }
    }
  yy1144:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy1129;
      if (yych <= '9')
        goto yy1145;
      if (yych <= ':')
        goto yy1129;
      goto yy1132;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy1129;
      } else {
        if (yych <= '`')
          goto yy1129;
        if (yych >= '{')
          goto yy1129;
      }
    }
  yy1145:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy1129;
      if (yych <= '9')
        goto yy1146;
      if (yych <= ':')
        goto yy1129;
      goto yy1132;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy1129;
      } else {
        if (yych <= '`')
          goto yy1129;
        if (yych >= '{')
          goto yy1129;
      }
    }
  yy1146:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy1129;
      if (yych <= '9')
        goto yy1147;
      if (yych <= ':')
        goto yy1129;
      goto yy1132;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy1129;
      } else {
        if (yych <= '`')
          goto yy1129;
        if (yych >= '{')
          goto yy1129;
      }
    }
  yy1147:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy1129;
      if (yych <= '9')
        goto yy1148;
      if (yych <= ':')
        goto yy1129;
      goto yy1132;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy1129;
      } else {
        if (yych <= '`')
          goto yy1129;
        if (yych >= '{')
          goto yy1129;
      }
    }
  yy1148:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy1129;
      if (yych <= '9')
        goto yy1149;
      if (yych <= ':')
        goto yy1129;
      goto yy1132;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy1129;
      } else {
        if (yych <= '`')
          goto yy1129;
        if (yych >= '{')
          goto yy1129;
      }
    }
  yy1149:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy1129;
      if (yych <= '9')
        goto yy1150;
      if (yych <= ':')
        goto yy1129;
      goto yy1132;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy1129;
      } else {
        if (yych <= '`')
          goto yy1129;
        if (yych >= '{')
          goto yy1129;
      }
    }
  yy1150:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy1129;
      if (yych <= '9')
        goto yy1151;
      if (yych <= ':')
        goto yy1129;
      goto yy1132;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy1129;
      } else {
        if (yych <= '`')
          goto yy1129;
        if (yych >= '{')
          goto yy1129;
      }
    }
  yy1151:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy1129;
      if (yych <= '9')
        goto yy1152;
      if (yych <= ':')
        goto yy1129;
      goto yy1132;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy1129;
      } else {
        if (yych <= '`')
          goto yy1129;
        if (yych >= '{')
          goto yy1129;
      }
    }
  yy1152:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy1129;
      if (yych <= '9')
        goto yy1153;
      if (yych <= ':')
        goto yy1129;
      goto yy1132;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy1129;
      } else {
        if (yych <= '`')
          goto yy1129;
        if (yych >= '{')
          goto yy1129;
      }
    }
  yy1153:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy1129;
      if (yych <= '9')
        goto yy1154;
      if (yych <= ':')
        goto yy1129;
      goto yy1132;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy1129;
      } else {
        if (yych <= '`')
          goto yy1129;
        if (yych >= '{')
          goto yy1129;
      }
    }
  yy1154:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy1129;
      if (yych <= '9')
        goto yy1155;
      if (yych <= ':')
        goto yy1129;
      goto yy1132;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy1129;
      } else {
        if (yych <= '`')
          goto yy1129;
        if (yych >= '{')
          goto yy1129;
      }
    }
  yy1155:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy1129;
      if (yych <= '9')
        goto yy1156;
      if (yych <= ':')
        goto yy1129;
      goto yy1132;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy1129;
      } else {
        if (yych <= '`')
          goto yy1129;
        if (yych >= '{')
          goto yy1129;
      }
    }
  yy1156:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy1129;
      if (yych <= '9')
        goto yy1157;
      if (yych <= ':')
        goto yy1129;
      goto yy1132;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy1129;
      } else {
        if (yych <= '`')
          goto yy1129;
        if (yych >= '{')
          goto yy1129;
      }
    }
  yy1157:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy1129;
      if (yych <= '9')
        goto yy1158;
      if (yych <= ':')
        goto yy1129;
      goto yy1132;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy1129;
      } else {
        if (yych <= '`')
          goto yy1129;
        if (yych >= '{')
          goto yy1129;
      }
    }
  yy1158:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy1129;
      if (yych <= '9')
        goto yy1159;
      if (yych <= ':')
        goto yy1129;
      goto yy1132;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy1129;
      } else {
        if (yych <= '`')
          goto yy1129;
        if (yych >= '{')
          goto yy1129;
      }
    }
  yy1159:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy1129;
      if (yych <= '9')
        goto yy1160;
      if (yych <= ':')
        goto yy1129;
      goto yy1132;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy1129;
      } else {
        if (yych <= '`')
          goto yy1129;
        if (yych >= '{')
          goto yy1129;
      }
    }
  yy1160:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy1129;
      if (yych <= '9')
        goto yy1161;
      if (yych <= ':')
        goto yy1129;
      goto yy1132;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy1129;
      } else {
        if (yych <= '`')
          goto yy1129;
        if (yych >= '{')
          goto yy1129;
      }
    }
  yy1161:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy1129;
      if (yych <= '9')
        goto yy1162;
      if (yych <= ':')
        goto yy1129;
      goto yy1132;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy1129;
      } else {
        if (yych <= '`')
          goto yy1129;
        if (yych >= '{')
          goto yy1129;
      }
    }
  yy1162:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy1129;
      if (yych <= '9')
        goto yy1163;
      if (yych <= ':')
        goto yy1129;
      goto yy1132;
    } else {
      if (yych <= 'Z') {
        if (yych <= '@')
          goto yy1129;
      } else {
        if (yych <= '`')
          goto yy1129;
        if (yych >= '{')
          goto yy1129;
      }
    }
  yy1163:
    yych = *++p;
    if (yych == ';')
      goto yy1132;
    goto yy1129;
  yy1164:
    yych = *++p;
    if (yych <= '@') {
      if (yych <= '/')
        goto yy1129;
      if (yych <= '9')
        goto yy1172;
      goto yy1129;
    } else {
      if (yych <= 'F')
        goto yy1172;
      if (yych <= '`')
        goto yy1129;
      if (yych <= 'f')
        goto yy1172;
      goto yy1129;
    }
  yy1165:
    yych = *++p;
    if (yych <= '/')
      goto yy1129;
    if (yych <= '9')
      goto yy1166;
    if (yych == ';')
      goto yy1132;
    goto yy1129;
  yy1166:
    yych = *++p;
    if (yych <= '/')
      goto yy1129;
    if (yych <= '9')
      goto yy1167;
    if (yych == ';')
      goto yy1132;
    goto yy1129;
  yy1167:
    yych = *++p;
    if (yych <= '/')
      goto yy1129;
    if (yych <= '9')
      goto yy1168;
    if (yych == ';')
      goto yy1132;
    goto yy1129;
  yy1168:
    yych = *++p;
    if (yych <= '/')
      goto yy1129;
    if (yych <= '9')
      goto yy1169;
    if (yych == ';')
      goto yy1132;
    goto yy1129;
  yy1169:
    yych = *++p;
    if (yych <= '/')
      goto yy1129;
    if (yych <= '9')
      goto yy1170;
    if (yych == ';')
      goto yy1132;
    goto yy1129;
  yy1170:
    yych = *++p;
    if (yych <= '/')
      goto yy1129;
    if (yych <= '9')
      goto yy1171;
    if (yych == ';')
      goto yy1132;
    goto yy1129;
  yy1171:
    yych = *++p;
    if (yych <= '/')
      goto yy1129;
    if (yych <= '9')
      goto yy1163;
    if (yych == ';')
      goto yy1132;
    goto yy1129;
  yy1172:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy1129;
      if (yych <= '9')
        goto yy1173;
      if (yych <= ':')
        goto yy1129;
      goto yy1132;
    } else {
      if (yych <= 'F') {
        if (yych <= '@')
          goto yy1129;
      } else {
        if (yych <= '`')
          goto yy1129;
        if (yych >= 'g')
          goto yy1129;
      }
    }
  yy1173:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy1129;
      if (yych <= '9')
        goto yy1174;
      if (yych <= ':')
        goto yy1129;
      goto yy1132;
    } else {
      if (yych <= 'F') {
        if (yych <= '@')
          goto yy1129;
      } else {
        if (yych <= '`')
          goto yy1129;
        if (yych >= 'g')
          goto yy1129;
      }
    }
  yy1174:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy1129;
      if (yych <= '9')
        goto yy1175;
      if (yych <= ':')
        goto yy1129;
      goto yy1132;
    } else {
      if (yych <= 'F') {
        if (yych <= '@')
          goto yy1129;
      } else {
        if (yych <= '`')
          goto yy1129;
        if (yych >= 'g')
          goto yy1129;
      }
    }
  yy1175:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy1129;
      if (yych <= '9')
        goto yy1176;
      if (yych <= ':')
        goto yy1129;
      goto yy1132;
    } else {
      if (yych <= 'F') {
        if (yych <= '@')
          goto yy1129;
      } else {
        if (yych <= '`')
          goto yy1129;
        if (yych >= 'g')
          goto yy1129;
      }
    }
  yy1176:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy1129;
      if (yych <= '9')
        goto yy1177;
      if (yych <= ':')
        goto yy1129;
      goto yy1132;
    } else {
      if (yych <= 'F') {
        if (yych <= '@')
          goto yy1129;
      } else {
        if (yych <= '`')
          goto yy1129;
        if (yych >= 'g')
          goto yy1129;
      }
    }
  yy1177:
    yych = *++p;
    if (yych <= ';') {
      if (yych <= '/')
        goto yy1129;
      if (yych <= '9')
        goto yy1178;
      if (yych <= ':')
        goto yy1129;
      goto yy1132;
    } else {
      if (yych <= 'F') {
        if (yych <= '@')
          goto yy1129;
      } else {
        if (yych <= '`')
          goto yy1129;
        if (yych >= 'g')
          goto yy1129;
      }
    }
  yy1178:
    ++p;
    if ((yych = *p) <= ';') {
      if (yych <= '/')
        goto yy1129;
      if (yych <= '9')
        goto yy1163;
      if (yych <= ':')
        goto yy1129;
      goto yy1132;
    } else {
      if (yych <= 'F') {
        if (yych <= '@')
          goto yy1129;
        goto yy1163;
      } else {
        if (yych <= '`')
          goto yy1129;
        if (yych <= 'f')
          goto yy1163;
        goto yy1129;
      }
    }
  }
}

// Returns positive value if a URL begins in a way that is potentially
// dangerous, with javascript:, vbscript:, file:, or data:, otherwise 0.
bufsize_t _scan_dangerous_url(const unsigned char *p) {
  const unsigned char *marker = NULL;
  const unsigned char *start = p;

  {
    unsigned char yych;
    unsigned int yyaccept = 0;
    yych = *p;
    if (yych <= 'V') {
      if (yych <= 'F') {
        if (yych == 'D')
          goto yy1183;
        if (yych >= 'F')
          goto yy1184;
      } else {
        if (yych == 'J')
          goto yy1185;
        if (yych >= 'V')
          goto yy1186;
      }
    } else {
      if (yych <= 'f') {
        if (yych == 'd')
          goto yy1183;
        if (yych >= 'f')
          goto yy1184;
      } else {
        if (yych <= 'j') {
          if (yych >= 'j')
            goto yy1185;
        } else {
          if (yych == 'v')
            goto yy1186;
        }
      }
    }
    ++p;
  yy1182 : { return 0; }
  yy1183:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych == 'A')
      goto yy1209;
    if (yych == 'a')
      goto yy1209;
    goto yy1182;
  yy1184:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych == 'I')
      goto yy1206;
    if (yych == 'i')
      goto yy1206;
    goto yy1182;
  yy1185:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych == 'A')
      goto yy1197;
    if (yych == 'a')
      goto yy1197;
    goto yy1182;
  yy1186:
    yyaccept = 0;
    yych = *(marker = ++p);
    if (yych == 'B')
      goto yy1187;
    if (yych != 'b')
      goto yy1182;
  yy1187:
    yych = *++p;
    if (yych == 'S')
      goto yy1189;
    if (yych == 's')
      goto yy1189;
  yy1188:
    p = marker;
    if (yyaccept == 0) {
      goto yy1182;
    } else {
      goto yy1196;
    }
  yy1189:
    yych = *++p;
    if (yych == 'C')
      goto yy1190;
    if (yych != 'c')
      goto yy1188;
  yy1190:
    yych = *++p;
    if (yych == 'R')
      goto yy1191;
    if (yych != 'r')
      goto yy1188;
  yy1191:
    yych = *++p;
    if (yych == 'I')
      goto yy1192;
    if (yych != 'i')
      goto yy1188;
  yy1192:
    yych = *++p;
    if (yych == 'P')
      goto yy1193;
    if (yych != 'p')
      goto yy1188;
  yy1193:
    yych = *++p;
    if (yych == 'T')
      goto yy1194;
    if (yych != 't')
      goto yy1188;
  yy1194:
    yych = *++p;
    if (yych != ':')
      goto yy1188;
  yy1195:
    ++p;
  yy1196 : { return (bufsize_t)(p - start); }
  yy1197:
    yych = *++p;
    if (yych == 'V')
      goto yy1198;
    if (yych != 'v')
      goto yy1188;
  yy1198:
    yych = *++p;
    if (yych == 'A')
      goto yy1199;
    if (yych != 'a')
      goto yy1188;
  yy1199:
    yych = *++p;
    if (yych == 'S')
      goto yy1200;
    if (yych != 's')
      goto yy1188;
  yy1200:
    yych = *++p;
    if (yych == 'C')
      goto yy1201;
    if (yych != 'c')
      goto yy1188;
  yy1201:
    yych = *++p;
    if (yych == 'R')
      goto yy1202;
    if (yych != 'r')
      goto yy1188;
  yy1202:
    yych = *++p;
    if (yych == 'I')
      goto yy1203;
    if (yych != 'i')
      goto yy1188;
  yy1203:
    yych = *++p;
    if (yych == 'P')
      goto yy1204;
    if (yych != 'p')
      goto yy1188;
  yy1204:
    yych = *++p;
    if (yych == 'T')
      goto yy1205;
    if (yych != 't')
      goto yy1188;
  yy1205:
    yych = *++p;
    if (yych == ':')
      goto yy1195;
    goto yy1188;
  yy1206:
    yych = *++p;
    if (yych == 'L')
      goto yy1207;
    if (yych != 'l')
      goto yy1188;
  yy1207:
    yych = *++p;
    if (yych == 'E')
      goto yy1208;
    if (yych != 'e')
      goto yy1188;
  yy1208:
    yych = *++p;
    if (yych == ':')
      goto yy1195;
    goto yy1188;
  yy1209:
    yych = *++p;
    if (yych == 'T')
      goto yy1210;
    if (yych != 't')
      goto yy1188;
  yy1210:
    yych = *++p;
    if (yych == 'A')
      goto yy1211;
    if (yych != 'a')
      goto yy1188;
  yy1211:
    yych = *++p;
    if (yych != ':')
      goto yy1188;
    yyaccept = 1;
    yych = *(marker = ++p);
    if (yych == 'I')
      goto yy1213;
    if (yych != 'i')
      goto yy1196;
  yy1213:
    yych = *++p;
    if (yych == 'M')
      goto yy1214;
    if (yych != 'm')
      goto yy1188;
  yy1214:
    yych = *++p;
    if (yych == 'A')
      goto yy1215;
    if (yych != 'a')
      goto yy1188;
  yy1215:
    yych = *++p;
    if (yych == 'G')
      goto yy1216;
    if (yych != 'g')
      goto yy1188;
  yy1216:
    yych = *++p;
    if (yych == 'E')
      goto yy1217;
    if (yych != 'e')
      goto yy1188;
  yy1217:
    yych = *++p;
    if (yych != '/')
      goto yy1188;
    yych = *++p;
    if (yych <= 'W') {
      if (yych <= 'J') {
        if (yych == 'G')
          goto yy1220;
        if (yych <= 'I')
          goto yy1188;
        goto yy1221;
      } else {
        if (yych == 'P')
          goto yy1219;
        if (yych <= 'V')
          goto yy1188;
        goto yy1222;
      }
    } else {
      if (yych <= 'j') {
        if (yych == 'g')
          goto yy1220;
        if (yych <= 'i')
          goto yy1188;
        goto yy1221;
      } else {
        if (yych <= 'p') {
          if (yych <= 'o')
            goto yy1188;
        } else {
          if (yych == 'w')
            goto yy1222;
          goto yy1188;
        }
      }
    }
  yy1219:
    yych = *++p;
    if (yych == 'N')
      goto yy1230;
    if (yych == 'n')
      goto yy1230;
    goto yy1188;
  yy1220:
    yych = *++p;
    if (yych == 'I')
      goto yy1229;
    if (yych == 'i')
      goto yy1229;
    goto yy1188;
  yy1221:
    yych = *++p;
    if (yych == 'P')
      goto yy1227;
    if (yych == 'p')
      goto yy1227;
    goto yy1188;
  yy1222:
    yych = *++p;
    if (yych == 'E')
      goto yy1223;
    if (yych != 'e')
      goto yy1188;
  yy1223:
    yych = *++p;
    if (yych == 'B')
      goto yy1224;
    if (yych != 'b')
      goto yy1188;
  yy1224:
    yych = *++p;
    if (yych == 'P')
      goto yy1225;
    if (yych != 'p')
      goto yy1188;
  yy1225:
    ++p;
    { return 0; }
  yy1227:
    yych = *++p;
    if (yych == 'E')
      goto yy1228;
    if (yych != 'e')
      goto yy1188;
  yy1228:
    yych = *++p;
    if (yych == 'G')
      goto yy1225;
    if (yych == 'g')
      goto yy1225;
    goto yy1188;
  yy1229:
    yych = *++p;
    if (yych == 'F')
      goto yy1225;
    if (yych == 'f')
      goto yy1225;
    goto yy1188;
  yy1230:
    ++p;
    if ((yych = *p) == 'G')
      goto yy1225;
    if (yych == 'g')
      goto yy1225;
    goto yy1188;
  }
}

// Scans a footnote definition opening.
bufsize_t _scan_footnote_definition(const unsigned char *p) {
  const unsigned char *marker = NULL;
  const unsigned char *start = p;

  {
    unsigned char yych;
    static const unsigned char yybm[] = {
        0,   64, 64, 64, 64, 64, 64, 64, 64, 128, 0,  64, 64, 0,  64, 64,
        64,  64, 64, 64, 64, 64, 64, 64, 64, 64,  64, 64, 64, 64, 64, 64,
        128, 64, 64, 64, 64, 64, 64, 64, 64, 64,  64, 64, 64, 64, 64, 64,
        64,  64, 64, 64, 64, 64, 64, 64, 64, 64,  64, 64, 64, 64, 64, 64,
        64,  64, 64, 64, 64, 64, 64, 64, 64, 64,  64, 64, 64, 64, 64, 64,
        64,  64, 64, 64, 64, 64, 64, 64, 64, 64,  64, 64, 64, 0,  64, 64,
        64,  64, 64, 64, 64, 64, 64, 64, 64, 64,  64, 64, 64, 64, 64, 64,
        64,  64, 64, 64, 64, 64, 64, 64, 64, 64,  64, 64, 64, 64, 64, 64,
        0,   0,  0,  0,  0,  0,  0,  0,  0,  0,   0,  0,  0,  0,  0,  0,
        0,   0,  0,  0,  0,  0,  0,  0,  0,  0,   0,  0,  0,  0,  0,  0,
        0,   0,  0,  0,  0,  0,  0,  0,  0,  0,   0,  0,  0,  0,  0,  0,
        0,   0,  0,  0,  0,  0,  0,  0,  0,  0,   0,  0,  0,  0,  0,  0,
        0,   0,  0,  0,  0,  0,  0,  0,  0,  0,   0,  0,  0,  0,  0,  0,
        0,   0,  0,  0,  0,  0,  0,  0,  0,  0,   0,  0,  0,  0,  0,  0,
        0,   0,  0,  0,  0,  0,  0,  0,  0,  0,   0,  0,  0,  0,  0,  0,
        0,   0,  0,  0,  0,  0,  0,  0,  0,  0,   0,  0,  0,  0,  0,  0,
    };
    yych = *p;
    if (yych == '[')
      goto yy1235;
    ++p;
  yy1234 : { return 0; }
  yy1235:
    yych = *(marker = ++p);
    if (yych != '^')
      goto yy1234;
    yych = *++p;
    if (yych != ']')
      goto yy1239;
  yy1237:
    p = marker;
    goto yy1234;
  yy1238:
    ++p;
    yych = *p;
  yy1239:
    if (yybm[0 + yych] & 64) {
      goto yy1238;
    }
    if (yych <= 0xEC) {
      if (yych <= 0xC1) {
        if (yych <= ' ')
          goto yy1237;
        if (yych <= ']')
          goto yy1247;
        goto yy1237;
      } else {
        if (yych <= 0xDF)
          goto yy1240;
        if (yych <= 0xE0)
          goto yy1241;
        goto yy1242;
      }
    } else {
      if (yych <= 0xF0) {
        if (yych <= 0xED)
          goto yy1246;
        if (yych <= 0xEF)
          goto yy1242;
        goto yy1243;
      } else {
        if (yych <= 0xF3)
          goto yy1244;
        if (yych <= 0xF4)
          goto yy1245;
        goto yy1237;
      }
    }
  yy1240:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy1237;
    if (yych <= 0xBF)
      goto yy1238;
    goto yy1237;
  yy1241:
    ++p;
    yych = *p;
    if (yych <= 0x9F)
      goto yy1237;
    if (yych <= 0xBF)
      goto yy1240;
    goto yy1237;
  yy1242:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy1237;
    if (yych <= 0xBF)
      goto yy1240;
    goto yy1237;
  yy1243:
    ++p;
    yych = *p;
    if (yych <= 0x8F)
      goto yy1237;
    if (yych <= 0xBF)
      goto yy1242;
    goto yy1237;
  yy1244:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy1237;
    if (yych <= 0xBF)
      goto yy1242;
    goto yy1237;
  yy1245:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy1237;
    if (yych <= 0x8F)
      goto yy1242;
    goto yy1237;
  yy1246:
    ++p;
    yych = *p;
    if (yych <= 0x7F)
      goto yy1237;
    if (yych <= 0x9F)
      goto yy1240;
    goto yy1237;
  yy1247:
    yych = *++p;
    if (yych != ':')
      goto yy1237;
  yy1248:
    ++p;
    yych = *p;
    if (yybm[0 + yych] & 128) {
      goto yy1248;
    }
    { return (bufsize_t)(p - start); }
  }
}
